@@ -1,5 +1,5 @@
 //    HOTELDRUID
-//    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+//    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 //
 //    This program is free software: you can redistribute it and/or modify
 //    it under the terms of the GNU Affero General Public License as published by
@@ -66,6 +66,26 @@ return n_vett
 }
 
 
+
+function agg_colore_sel (ncol) {
+var sel = document.getElementById('colsel'+ncol);
+var colsel = sel.options[sel.selectedIndex].value;
+document.getElementById('coltxt'+ncol).value = colsel;
+sel.style.backgroundColor = colsel;
+}
+
+
+
+function agg_colore_sel_txt (ncol) {
+var sel = document.getElementById('colsel'+ncol);
+var colsel = document.getElementById('coltxt'+ncol).value;
+var colre1 = new RegExp('^#[0-9a-f]{3,3}$','i');
+var colre2 = new RegExp('^#[0-9a-f]{6,6}$','i');
+if (colre1.test(colsel) || colre2.test(colsel)) sel.style.backgroundColor = colsel;
+}
+
+
+
 // punto_vendita.php functions
 
 function aggiungi_linea_pv (id,nome,molt,val,calcolab,moltiplicab) {
@@ -703,7 +723,8 @@ pren_end = '';
 function formatta_cognome (cognome,colonne,freccia) {
 var cognome_f  = cognome;
 var cognome_opt = '';
-var lung_cognome = cognome.length;
+if (cognome === undefined) var lung_cognome = 0;
+else var lung_cognome = cognome.length;
 var lung_freccia = 0;
 if (freccia) lung_freccia = 3;
 var lung_non_ridotta = (7+agg_tronca)*colonne - lung_freccia;
@@ -751,7 +772,8 @@ var ddata = 'dini';
 }
 else {
 var idg_agg = loop+'d'+(id_fine_tab + 1);
-var ddata = 'dfine';
+if (allinea_tab_mesi != 'SI') var ddata = 'dfine';
+else ddata = 'dini';
 }
 
 var xmlhttp = new XMLHttpRequest();
@@ -815,7 +837,7 @@ else cas_canc = 1;
 if (caselle[cas_canc].colSpan <= 2) {
 righe[n1].removeChild(caselle[cas_canc]);
 if (direz == 'sx') cas_canc = cas_canc - 1;
-if (righe[n1].className == 'rd_r') caselle[cas_canc].colSpan = 1;
+if (righe[n1].className == 'rd_r' && allinea_tab_mesi != 'SI') caselle[cas_canc].colSpan = 1;
 }
 else {
 caselle[cas_canc].colSpan = caselle[cas_canc].colSpan - 2;
@@ -895,7 +917,7 @@ var ncas = document.createElement('TD');
 ncas.innerHTML = '&nbsp;';
 ncas.colSpan = 2;
 if (righe[n1].className == 'rd_r') {
-ncas.colSpan = 1;
+if (allinea_tab_mesi != 'SI') ncas.colSpan = 1;
 if (direz == 'sx') {
 caselle[cas_agg].colSpan = 2;
 if (gjs == '31' || gjs == '30' || gjs == '29' || gjs == '28') ncas.style.backgroundColor = colore_date_altre;
@@ -903,7 +925,7 @@ else ncas.style.backgroundColor = caselle[cas_agg].style.backgroundColor;
 }
 else {
 caselle[(cas_agg - 1)].colSpan = 2;
-if (gjs == '01') ncas.style.backgroundColor = colore_date_altre;
+if ((allinea_tab_mesi != 'SI' && gjs == '01') || (allinea_tab_mesi == 'SI' && gjs == '02')) ncas.style.backgroundColor = colore_date_altre;
 else ncas.style.backgroundColor = caselle[(cas_agg - 1)].style.backgroundColor;
 }
 var dagg = g_agg_xml[ncol].getElementsByTagName(ddata);
