@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -22,6 +22,7 @@
 
 $pag = "crea_modelli.php";
 $titolo = "HotelDruid: Crea Pagine Web";
+$base_js = 1;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -489,14 +490,14 @@ echo "".mex("Assegnare gli appartamenti in base alla tariffa scelta con la regol
 </select><br><br>";
 */
 
-echo "".mex("Motivazioni della regola di assegnazone 1 da tenere in conto",$pag).":<br>
+echo "".mex("Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto",$pag).":<br>
 <table style=\"margin-left: auto; margin-right: auto;\" border=\"1\" cellspacing=\"0\" cellpadding=\"4\">";
 $celle = 1;
 $num_colonne = 3;
 $tableregole_modello = $PHPR_TAB_PRE."regole".$anno_modello;
-$regole = esegui_query("select * from $tableregole_modello where app_agenzia != '' order by app_agenzia");
+$regole = esegui_query("select * from $tableregole_modello where app_agenzia != '' and (motivazione2 != 'x' or motivazione2 is NULL) order by app_agenzia");
 $num_regole = numlin_query($regole);
-$motivazioni_presenti = "";
+unset($motivazioni_presenti);
 $num_motivazioni = 0;
 for ($num1 = 0 ; $num1 < $num_regole ; $num1 = $num1 + 1) {
 if ($celle == 1) echo "<tr>";
@@ -513,7 +514,7 @@ $var_motivazione = "var_mot_".$num_motivazioni;
 $num_motivazioni++;
 if (!$considera_motivazioni_regola1["array_esistente"] or strtoupper($considera_motivazioni_regola1[$motivazione]) == $SI) $checked = " checked";
 else $checked = "";
-echo "<td><input type=\"checkbox\" name=\"$var_motivazione\" value=\"$motivazione\"$checked> $motivazione_vedi</td>";
+echo "<td><label><input type=\"checkbox\" name=\"$var_motivazione\" value=\"$motivazione\"$checked> $motivazione_vedi</label></td>";
 if ($celle == $num_colonne) {
 echo "</tr>";
 $celle = 0;
@@ -526,7 +527,8 @@ for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
 echo "</tr>";
 } # fine if ($celle != 1)
 elseif ($num_regole == 0) echo "<tr><td style=\"width: 250px;\">&nbsp;</td></tr>";
-echo "</table>";
+echo "</table>
+<div style=\"font-size: smaller; text-align: center;\">(".mex("le regole 1 di chiusura vengono sempre applicate",$pag).")</div>";
 if (!$mostra_frase_alternativa_regola1 or strtoupper($mostra_frase_alternativa_regola1) == $NO) { $check_NO = " checked"; $check_SI = ""; }
 else { $check_SI = " checked"; $check_NO = ""; }
 if ($fr_alternativa_regola1) $val = htmlspecialchars($fr_alternativa_regola1);
@@ -1180,8 +1182,8 @@ for ($num2 = 1 ; $num2 <= $num_colori ; $num2++) {
 $colore_corr = $colori_tema[$num2]['default'];
 if ($sel and ${"colore_tema_".$num2}) $colore_corr = ${"colore_tema_".$num2};
 $js_opz_tema .= "".mex("Colore del tema",$pag)." \"".$template_theme_name[$num1]."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
- <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltema$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_col_tema_txt($num2)\">\\
-<select id=\"colsel$num2\" onchange=\"agg_col_tema($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
+ <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltxt$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_colore_sel_txt($num2)\">\\
+<select id=\"colsel$num2\" onchange=\"agg_colore_sel($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
 } # fine for $num2
 $valori_tema = $template_theme_values[$num1];
 $num_valori = count($valori_tema);
@@ -1243,12 +1245,6 @@ options_colori = '<option value=\"#ffffff\" style=\"background-color: #ffffff;\"
 <option value=\"#999999\" style=\"background-color: #999999;\">&nbsp;<\/option>\\
 <option value=\"#000000\" style=\"background-color: #000000;\">&nbsp;<\/option>\\
 ';
-function agg_col_tema (ncol) {
-var sel = document.getElementById('colsel'+ncol);
-var colsel = sel.options[sel.selectedIndex].value;
-document.getElementById('coltema'+ncol).value = colsel;
-sel.style.backgroundColor = colsel;
-}
 function agg_tema_sel () {
 var tema_sel = document.getElementById('tema_sel').selectedIndex;
 tema_sel = document.getElementById('tema_sel').options[tema_sel].value;
@@ -1269,13 +1265,6 @@ txt_html_nota.innerHTML = '';
 opz_tema.innerHTML = '';
 }
 }
-function agg_col_tema_txt (ncol) {
-var sel = document.getElementById('colsel'+ncol);
-var colsel = document.getElementById('coltema'+ncol).value;
-var colre1 = new RegExp('^#[0-9a-f]{3,3}$','i');
-var colre2 = new RegExp('^#[0-9a-f]{6,6}$','i');
-if (colre1.test(colsel) || colre2.test(colsel)) sel.style.backgroundColor = colsel;
-}
 agg_tema_sel();
 -->
 </script>
