@@ -66,6 +66,7 @@ $mostra_form_iniziale = "NO";
 $insappartamenti = "";
 
 allunga_tempo_limite();
+if ($tipo_db == "mysql" and @function_exists('mysqli_connect')) $tipo_db = "mysqli";
 $carica_estensione == "NO";
 if (($tipo_db == "postgresql" and !@function_exists('pg_connect')) or ($tipo_db == "mysql" and !@function_exists('mysql_connect'))) $carica_estensione == "SI";
 if ($tipo_db == "sqlite") {
@@ -73,6 +74,7 @@ if (!@class_exists('SQLite3')) $carica_estensione == "SI";
 } # fine if ($tipo_db == "sqlite")
 if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") {
 $tipo_db = C_CREADB_TIPODB;
+if ($tipo_db == "mysql" and @function_exists('mysqli_connect')) $tipo_db = "mysqli";
 $database_phprdb = C_CREADB_NOMEDB;
 $database_esistente = C_CREADB_DB_ESISTENTE;
 $host_phprdb = C_CREADB_HOST;
@@ -83,7 +85,8 @@ if (C_CREADB_ESTENSIONE) $carica_estensione = C_CREADB_ESTENSIONE;
 $tempdatabase = C_CREADB_TEMPDB;
 $prefisso_tab = C_CREADB_PREFISSO_TAB;
 } # fine if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO")
-if (!$numappartamenti or controlla_num_pos($numappartamenti) == "NO") $numappartamenti = 5;
+if (!controlla_num_pos($numletti) == "NO") $numletti = 0;
+if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO") $numappartamenti = 5;
 
 if (defined('C_EXT_DB_DATA_PATH') and C_EXT_DB_DATA_PATH) {
 $HOTELD_DB_TYPE = "";
@@ -94,7 +97,10 @@ $HOTELD_DB_USER = "";
 $HOTELD_DB_PASS = "";
 $HOTELD_TAB_PRE = "";
 include(C_EXT_DB_DATA_PATH);
-if ($HOTELD_DB_TYPE) $tipo_db = $HOTELD_DB_TYPE;
+if ($HOTELD_DB_TYPE) {
+$tipo_db = $HOTELD_DB_TYPE;
+if ($tipo_db == "mysql" and @function_exists('mysqli_connect')) $tipo_db = "mysqli";
+} # fine if ($HOTELD_DB_TYPE)
 if ($HOTELD_DB_NAME) $database_phprdb = $HOTELD_DB_NAME;
 if ($HOTELD_DB_HOST) $host_phprdb = $HOTELD_DB_HOST;
 if (strcmp($HOTELD_DB_PORT,"")) $port_phprdb = $HOTELD_DB_PORT;
@@ -122,6 +128,17 @@ if (!$query_db) $numconnessione = $query_db;
 } # fine if ($numconnessione and $database_esistente == "SI")
 $encoding = "";
 } # fine if ($tipo_db == "mysql")
+if ($tipo_db == "mysqli") {
+if ($carica_estensione == "SI") dl("mysqli.so");
+$numconnessione = mysqli_connect($host_phprdb,$user_phprdb,$password_phprdb,"",$port_phprdb);
+@mysqli_query($numconnessione,"SET NAMES 'utf8'");
+@mysqli_query($numconnessione,"SET default_storage_engine=MYISAM");
+if ($numconnessione and $database_esistente == "SI") {
+$query_db = mysqli_select_db($numconnessione,$database_phprdb);
+if (!$query_db) $numconnessione = $query_db;
+} # fine if ($numconnessione and $database_esistente == "SI")
+$encoding = "";
+} # fine if ($tipo_db == "mysqli")
 if ($tipo_db == "sqlite") {
 if ($carica_estensione == "SI") dl("sqlite.so");
 $database_phprdb = str_replace("..","",$database_phprdb);
@@ -132,6 +149,7 @@ $database_esistente = "SI";
 if ($numconnessione) {
 include("./includes/funzioni_$tipo_db.php");
 if ($database_esistente == "NO") {
+$link_mysqli = $numconnessione;
 $query = esegui_query("create database $database_phprdb $encoding");
 if ($query) echo mex2("Database creato",$pag,$lingua)."!<br>";
 } # fine if ($database_esistente == "NO")
@@ -144,11 +162,19 @@ $collation_db = "";
 if ($tipo_db == "postgresql") {
 $numconnessione = pg_connect("dbname=$database_phprdb host=$host_phprdb port=$port_phprdb user=$user_phprdb password=$password_phprdb ");
 } # fine if ($tipo_db == "postgresql")
+if ($tipo_db == "mysql" or $tipo_db == "mysqli") {
 if ($tipo_db == "mysql") {
 $numconnessione = mysql_connect("$host_phprdb:$port_phprdb", "$user_phprdb", "$password_phprdb");
 @mysql_query("SET NAMES 'utf8'");
 @mysql_query("SET default_storage_engine=MYISAM");
 mysql_select_db($database_phprdb);
+} # fine if ($tipo_db == "mysql")
+if ($tipo_db == "mysqli") {
+$numconnessione = mysqli_connect($host_phprdb,$user_phprdb,$password_phprdb,$database_phprdb,$port_phprdb);
+$link_mysqli = $numconnessione;
+@mysqli_query($numconnessione,"SET NAMES 'utf8'");
+@mysqli_query($numconnessione,"SET default_storage_engine=MYISAM");
+} # fine if ($tipo_db == "mysqli")
 $character_set = esegui_query("SHOW VARIABLES LIKE 'character_set_database'");
 $collation = esegui_query("SHOW VARIABLES LIKE 'collation_database'");
 if (numlin_query($character_set) == 1 and numlin_query($collation) == 1) {
@@ -156,14 +182,14 @@ $character_set_db = risul_query($character_set,0,"Value");
 $collation_db = risul_query($collation,0,"Value");
 if ($character_set_db != "utf8" or $collation_db != "utf8_general_ci") esegui_query("alter database $database_phprdb default character set 'utf8' collate 'utf8_general_ci'");
 } # fine if (numlin_query($character_set) == 1 and...
-} # fine if ($tipo_db == "mysql")
+} # fine if ($tipo_db == "mysql" or $tipo_db == "mysqli")
 if ($tipo_db == "sqlite") {
 $numconnessione = new SQLite3(C_DATI_PATH."/db_".$database_phprdb);
 } # fine if ($tipo_db == "sqlite")
 
 # creo la tabella appartamenti.
 $tableappartamenti = $prefisso_tab."appartamenti";
-esegui_query("create table $tableappartamenti ( idappartamenti varchar(100) primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, commento text )");
+esegui_query("create table $tableappartamenti ( idappartamenti varchar(100) primary key, numpiano text, maxoccupanti integer, numcasa text, app_vicini text, priorita integer, priorita2 integer, letto varchar(1), commento text )");
 # creo la tabella clienti.
 $tableclienti = $prefisso_tab."clienti";
 esegui_query("create table $tableclienti (idclienti integer primary key, cognome varchar(70) not null, nome varchar(70), soprannome varchar(70), sesso char, titolo varchar(30), lingua varchar(14), datanascita date, cittanascita varchar(70), regionenascita varchar(70), nazionenascita varchar(70), documento varchar(70), scadenzadoc date, tipodoc varchar(70), cittadoc varchar(70), regionedoc varchar(70), nazionedoc  varchar(70), nazionalita varchar(70), nazione varchar(70), regione varchar(70), citta varchar(70), via varchar(70), numcivico varchar(30), cap varchar(30), telefono varchar(50), telefono2 varchar(50), telefono3 varchar(50), fax varchar(50), email text, cod_fiscale varchar(50), partita_iva varchar(50), commento text, max_num_ordine integer, idclienti_compagni text, doc_inviati text, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer )");
@@ -213,12 +239,14 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('aggiunta_tronca_nomi_tab1','1','-2')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('linee_ripeti_date_tab_mesi','1','25')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_giorni_tab_mesi','1','SI')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('colori_tab_mesi','1','#99CCD4,#FFEE22,#FF9900,#CC0000')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_linee_tab2_prenota','1','30')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('nomi_contratti','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_tutte_prenota','1','200')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('selezione_tab_tutte_prenota','1','tutte')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_tutti_clienti','1','200')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_casse','1','50')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_messaggi','1','80')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_doc_salvati','1','100')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_storia_soldi','1','200')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_data','1','europa')");
@@ -258,7 +286,7 @@ $tablerelgruppi = $prefisso_tab."relgruppi";
 esegui_query("create table $tablerelgruppi (idutente integer not null, idgruppo integer, datainserimento $DATETIME, hostinserimento varchar(50), utente_inserimento integer )");
 crea_indice($tablerelgruppi,"idutente",$prefisso_tab."iidprelgruppi");
 $tablesessioni = $prefisso_tab."sessioni";
-esegui_query("create table $tablesessioni (idsessioni varchar(30) primary key, idutente integer, indirizzo_ip text, user_agent text, ultimo_accesso $DATETIME)");
+esegui_query("create table $tablesessioni (idsessioni varchar(30) primary key, idutente integer, indirizzo_ip text, tipo_conn varchar(12), user_agent text, ultimo_accesso $DATETIME)");
 $tabletransazioni = $prefisso_tab."transazioni";
 esegui_query("create table $tabletransazioni (idtransazioni varchar(30) primary key, idsessione varchar(30), tipo_transazione varchar(5), anno integer, spostamenti text, dati_transazione1 text, dati_transazione2 text, dati_transazione3 text, dati_transazione4 text, dati_transazione5 text, dati_transazione6 text, dati_transazione7 text, dati_transazione8 text, dati_transazione9 text, dati_transazione10 text, dati_transazione11 text, dati_transazione12 text, dati_transazione13 text, dati_transazione14 text, dati_transazione15 text, dati_transazione16 text, dati_transazione17 text, dati_transazione18 text, dati_transazione19 text, dati_transazione20 text, ultimo_accesso $DATETIME)");
 $tabletransazioniweb = $prefisso_tab."transazioniweb";
@@ -340,7 +368,10 @@ if (defined('C_EXT_DB_DATA_PATH') and C_EXT_DB_DATA_PATH) fwrite($fileaperto,"
 \$HOTELD_DB_PASS = \"\";
 \$HOTELD_TAB_PRE = \"\";
 require('".C_EXT_DB_DATA_PATH."');
-if (\$HOTELD_DB_TYPE) \$PHPR_DB_TYPE = \$HOTELD_DB_TYPE;
+if (\$HOTELD_DB_TYPE) {
+\$PHPR_DB_TYPE = \$HOTELD_DB_TYPE;
+if (\$PHPR_DB_TYPE == \"mysql\" and @function_exists('mysqli_connect')) \$PHPR_DB_TYPE = \"mysqli\";
+}
 if (\$HOTELD_DB_NAME) \$PHPR_DB_NAME = \$HOTELD_DB_NAME;
 if (\$HOTELD_DB_HOST) \$PHPR_DB_HOST = \$HOTELD_DB_HOST;
 if (strcmp(\$HOTELD_DB_PORT,\"\")) \$PHPR_DB_PORT = \$HOTELD_DB_PORT;
@@ -378,6 +409,16 @@ fwrite($fileaperto,"\$unit['special'] = 0;
 for (\$num1 = 0 ; \$num1 < count(\$car_spec) ; \$num1++) if (substr(\$unit['p_n'],0,strlen(\$car_spec[\$num1])) == \$car_spec[\$num1]) \$unit['special'] = 1;
 ?>");
 fclose($fileaperto);
+$fileaperto = fopen(C_DATI_PATH."/unit_single.php","w+");
+fwrite($fileaperto,"<?php
+\$unit['s_n'] = \$trad_var['bed'];
+\$unit['p_n'] = \$trad_var['beds'];
+\$unit['gender'] = \$trad_var['bed_gender'];
+\$unit['special'] = 0;
+\$car_spec = explode(\",\",\$trad_var['special_characters']);
+for (\$num1 = 0 ; \$num1 < count(\$car_spec) ; \$num1++) if (substr(\$unit['p_n'],0,strlen(\$car_spec[\$num1])) == \$car_spec[\$num1]) \$unit['special'] = 1;
+?>");
+fclose($fileaperto);
 $fileaperto = fopen(C_DATI_PATH."/tema.php","w+");
 fwrite($fileaperto,"<?php
 \$parole_sost = 0;
@@ -398,26 +439,47 @@ aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","reg
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","documentoid","documentiid",$tabledocumentiid,$tablerelutenti);
 aggiorna_relutenti("","SI","","",$id_utente,$id_utente,"","","","","","","","parentela","parentele",$tableparentele,$tablerelutenti);
 
+if (C_NASCONDI_MARCA == "SI" and @is_file(C_CARTELLA_CREA_MODELLI."/index.html")) @unlink(C_CARTELLA_CREA_MODELLI."/index.html");
+
 if (C_UTILIZZA_SEMPRE_DEFAULTS != "AUTO") {
 # seconda form di inserimento (appartamenti).
 echo "<br>".mex2("Inserisci ora i dati sugli appartamenti",'unit.php',$lingua)." (<b>".mex2("almeno il numero, diverso per ogni appartamento",'unit.php',$lingua)."</b>).<br>
-<form accept-charset=\"utf-8\" method=\"post\" action=\"creadb.php?numappartamenti=$numappartamenti\"><div>
+<form accept-charset=\"utf-8\" method=\"post\" action=\"creadb.php\"><div>
+<input type=\"hidden\" name=\"numappartamenti\" value=\"$numappartamenti\">
+<input type=\"hidden\" name=\"numletti\" value=\"$numletti\">
 <hr style=\"width: 95%\">";
 $zeri = (string) "0000000000000000000000000000";
-for ( $num = 1; $num <= $numappartamenti; $num = $num + 1) {
+$lettere = (string) "abcdefghijklmnopqrstuvwxyz";
+$pos_lettera = 0;
+$num_dorm = $numappartamenti;
+if (!$numletti) $num_app_max = $numappartamenti;
+else $num_app_max = $numappartamenti + ceil((double) $numletti / 26);
+for ( $num = 1; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
 $numapp = "numapp" . $num;
 $piano = "piano" . $num;
 $maxoccupanti = "maxoccupanti" . $num;
 $numcasa = "numcasa" . $num;
 $priorita = "priorita" . $num;
 $app_vicini = "app_vicini" . $num;
-$num_default = (string) substr($zeri,0,(strlen($numappartamenti) - strlen($num))).$num;
+if ($num <= $numappartamenti) $num_default = (string) substr($zeri,0,(strlen($num_app_max) - strlen($num))).$num;
+else {
+if ($pos_lettera == 0) {
+$num_dorm++;
+$num_dorm = (string) substr($zeri,0,(strlen($num_app_max) - strlen($num_dorm))).$num_dorm;
+} # fine if ($pos_lettera == 0)
+$num_default = $num_dorm.substr($lettere,$pos_lettera,1);
+$pos_lettera++;
+if ($pos_lettera == 26) $pos_lettera = 0;
+} # fine else if ($num <= $numappartamenti)
 echo "
-$num). ".mex2("Numero (o nome) dell' appartamento",'unit.php',$lingua).": 
-<input type=\"text\" name=\"$numapp\" size=\"5\" value=\"$num_default\">
- ".mex2("Massimo numero di occupanti",$pag,$lingua).": 
-<input type=\"text\" name=\"$maxoccupanti\" size=\"3\"><br>
-".mex2("Numero (o nome) piano",$pag,$lingua).": <input type=\"text\" name=\"$piano\" size=\"4\">
+$num). ";
+if ($num <= $numappartamenti) echo "".mex2("Numero (o nome) dell' appartamento",'unit.php',$lingua).": ";
+else echo "".mex2("[1]Numero (o nome) dell' appartamento",'unit.php',$lingua).": ";
+echo "<input type=\"text\" name=\"$numapp\" size=\"5\" value=\"$num_default\">
+ ".mex2("Massimo numero di occupanti",$pag,$lingua).": ";
+if ($num <= $numappartamenti) echo "<input type=\"text\" name=\"$maxoccupanti\" size=\"3\"><br>";
+else echo "1<br>";
+echo "".mex2("Numero (o nome) piano",$pag,$lingua).": <input type=\"text\" name=\"$piano\" size=\"4\">
  ".mex2("Numero (o nome) casa",$pag,$lingua).": 
 <input type=\"text\" name=\"$numcasa\" size=\"4\">
  ".mex2("Priorità (più bassa è, prima viene assegnato)",'unit.php',$lingua).": 
@@ -491,7 +553,9 @@ $torna_indietro = "SI";
 } # fine else if ($query)
 } # fine if ($numconnessione)
 else {
-echo "<br>".mex2("I dati inseriti non sono esatti o il database non è in ascolto (se postgres assicurarsi che venga avviato con -i e di avere i permessi giusti in pg_hba.conf)",$pag,$lingua).".<br>";
+echo "<br>".mex2("I dati inseriti per il collegamento al database non sono esatti o il database non è in ascolto",$pag,$lingua);
+if ($tipo_db == "postgresql") echo " (".mex2("se postgres assicurarsi che venga avviato con -i e di avere i permessi giusti in pg_hba.conf",$pag,$lingua).")";
+echo ".<br>";
 $torna_indietro = "SI";
 } # fine else if ($numconnessione)
 } # fine if (!$prefisso_tab or preg_match('/^[_a-z][_0-9a-z]*$/',$prefisso_tab))
@@ -521,6 +585,8 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"creadb.php\"><div>
 // inserisco i dati forniti nella tabella appartamenti e creo il file selezione appartamenti.
 if ($insappartamenti and !@is_file(C_DATI_PATH."/selectappartamenti.php")) {
 $mostra_form_iniziale = "NO";
+if (!controlla_num_pos($numletti) == "NO") $numletti = 0;
+if ((!$numappartamenti and !$numletti) or controlla_num_pos($numappartamenti) == "NO") $numappartamenti = 5;
 unset($lingua);
 include(C_DATI_PATH."/lingua.php");
 $lingua_mex = $lingua[1];
@@ -531,24 +597,44 @@ $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 $fileaperto = fopen(C_DATI_PATH."/selectappartamenti.php","a+");
 fwrite($fileaperto,"<?php \necho \"\n");
 $zeri = (string) "0000000000000000000000000000";
-for ( $num = 1; $num <= $numappartamenti; $num = $num + 1) {
+$lettere = (string) "abcdefghijklmnopqrstuvwxyz";
+$pos_lettera = 0;
+$num_dorm = $numappartamenti;
+if (!$numletti) $num_app_max = $numappartamenti;
+else $num_app_max = $numappartamenti + ceil((double) $numletti / 26);
+if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and $num_app_max < 10) $num_app_max = 10;
+for ( $num = 1; $num <= ($numappartamenti + $numletti) ; $num = $num + 1) {
 $numapp = "numapp" . $num;
 $numapp = $$numapp;
-if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI") $numapp = (string) substr($zeri,0,(strlen($numappartamenti) - strlen($num))).$num;
-if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") $numapp = (string) substr($zeri,0,(max(strlen($numappartamenti),2) - strlen($num))).$num;
+if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO") {
+if ($num <= $numappartamenti) $numapp = (string) substr($zeri,0,(strlen($num_app_max) - strlen($num))).$num;
+else {
+if ($pos_lettera == 0) {
+$num_dorm++;
+$num_dorm = (string) substr($zeri,0,(strlen($num_app_max) - strlen($num_dorm))).$num_dorm;
+} # fine if ($pos_lettera == 0)
+$numapp = $num_dorm.substr($lettere,$pos_lettera,1);
+$pos_lettera++;
+if ($pos_lettera == 26) $pos_lettera = 0;
+} # fine else if ($num <= $numappartamenti)
+} # fine if (C_UTILIZZA_SEMPRE_DEFAULTS == "SI" or C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO")
 $numapp = str_replace (",","",$numapp);
-$numapp = str_replace ("'","",$numapp);
 if (str_replace (" ","",$numapp) == "") $numapp = str_replace (" ","_",$numapp);
+$numapp = trim($numapp);
+$numapp = aggslashdb(htmlspecialchars(elimina_caratteri_slash($numapp)));
 $piano = "piano" . $num;
-$piano = $$piano;
+$piano = aggslashdb(htmlspecialchars(elimina_caratteri_slash($$piano)));
 $maxoccupanti = "maxoccupanti" . $num;
 $maxoccupanti = $$maxoccupanti;
+if ($num > $numappartamenti) $maxoccupanti = 1;
 $numcasa = "numcasa" . $num;
-$numcasa = $$numcasa;
+$numcasa = aggslashdb(htmlspecialchars(elimina_caratteri_slash($$numcasa)));
 $priorita = "priorita" . $num;
 $priorita = $$priorita;
 $app_vicini = "app_vicini" . $num;
-$app_vicini = $$app_vicini;
+$app_vicini = aggslashdb(htmlspecialchars($$app_vicini));
+if (controlla_num($maxoccupanti) != "SI") unset($maxoccupanti);
+if (controlla_num($priorita) != "SI") unset($priorita);
 esegui_query("insert into $tableappartamenti ( idappartamenti ) values ( '$numapp' )");
 fwrite($fileaperto,"<option value=\\\"$numapp\\\">$numapp</option>
 ");
@@ -556,17 +642,18 @@ if ($piano) {
 esegui_query("update $tableappartamenti set numpiano = '$piano' where idappartamenti = '$numapp'");
 } # fine if ($piano)
 if ($maxoccupanti) {
-esegui_query("update $tableappartamenti set maxoccupanti = $maxoccupanti where idappartamenti = '$numapp'");
+esegui_query("update $tableappartamenti set maxoccupanti = '$maxoccupanti' where idappartamenti = '$numapp'");
 } # fine if ($maxoccupanti)
 if ($numcasa) {
 esegui_query("update $tableappartamenti set numcasa = '$numcasa' where idappartamenti = '$numapp'");
 } # fine if ($numcasa)
 if ($priorita) {
-esegui_query("update $tableappartamenti set priorita = $priorita where idappartamenti = '$numapp'");
+esegui_query("update $tableappartamenti set priorita = '$priorita' where idappartamenti = '$numapp'");
 } # fine if ($priorita)
 if ($app_vicini and $assegna_vicini_nc != "SI") {
-esegui_query("update $tableappartamenti set app_vicini = $app_vicini where idappartamenti = '$numapp'");
+esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where idappartamenti = '$numapp'");
 } # fine if ($app_vicini and assegna_vicini_nc != "SI")
+if ($num > $numappartamenti) esegui_query("update $tableappartamenti set letto = '1' where idappartamenti = '$numapp'");
 } # fine for $num
 fwrite($fileaperto,"\"; \n?>");
 fclose($fileaperto);
@@ -625,9 +712,9 @@ fclose($fileaperto);
 } # fine if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php"))
 
 $tablemessaggi = $PHPR_TAB_PRE."messaggi";
-$testo = "<div style=\"max-width: 600px; line-height: 1.1;\">
-<h4>".mex("Benvenuto a HotelDruid!",$pag)."</h4><br>
-".mex("Questi sono alcuni semplici passi che puoi seguire per configurare le funzionalità di base di HotelDruid",$pag).":<br>
+$testo = "<div style=\"max-width: 600px; line-height: 1.1;\">";
+if (C_NASCONDI_MARCA != "SI") $testo .= "<h4>".mex("Benvenuto a HotelDruid!",$pag)."</h4><br>";
+$testo .= "".mex("Questi sono alcuni semplici passi che puoi seguire per configurare le funzionalità di base di HotelDruid",$pag).":<br>
 <ul style=\"line-height: 1.2;\">
 <li>".mex("Inserisci le informazioni sugli appartamenti dalla",'unit.php')."
  <em><b><a href=\"./visualizza_tabelle.php?tipo_tabella=appartamenti&amp;<sessione>\">".mex("tabella appartamenti",'unit.php')."</a></b></em>, 
@@ -645,6 +732,7 @@ $testo = "<div style=\"max-width: 600px; line-height: 1.1;\">
  \"<em><b><a href=\"./personalizza.php?<sessione>\">".mex("configura e personalizza",$pag)."</a></b></em>\"
  ".mex("per cambiare il nome della valuta, abilitare la registrazione delle entrate, inserire i metodi di pagamento, ed impostare molte altre opzioni",$pag).".<br><br></li>
 </ul></div>";
+if (C_NASCONDI_MARCA == "SI") $testo = str_replace("HotelDruid",mex("questo programma",$pag),$testo);
 $testo = aggslashdb($testo);
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 esegui_query("insert into $tablemessaggi (idmessaggi,tipo_messaggio,idutenti,idutenti_visto,datavisione,mittente,testo,datainserimento) values ('1','sistema',',1,',',1,','$datainserimento','1','$testo','$datainserimento')");
@@ -718,12 +806,17 @@ echo "".mex2("Nome del database a cui collegarsi temporaneamente",$pag,$lingua).
 <input type=\"text\" name=\"tempdatabase\" value=\"".C_CREADB_TEMPDB."\"><small>(".mex2("solo per Postgresql con database non esistente",$pag,$lingua).")</small><br>
 ".mex2("Prefisso nel nome delle tabelle",$pag,$lingua).":
 <input type=\"text\" name=\"prefisso_tab\" value=\"".C_CREADB_PREFISSO_TAB."\" maxlength=\"8\" size=\"9\"><small>(".mex2("opzionale, utile per più installazioni di HotelDruid nello stesso database",$pag,$lingua).")</small><br>
+<div style=\"height: 8px\"></div>
 ".mex2("Nome delle unità da gestire",$pag,$lingua).": <select name=\"nomeappartamenti\">
 <option value=\"camere\">".$trad_var['rooms']."</option>
 <option value=\"appartamenti\">".$trad_var['apartments']."</option>
 </select><br>
 ".mex2("Numero di unità da gestire",$pag,$lingua).": 
 <input type=\"text\" name=\"numappartamenti\"><br>
+<div style=\"height: 6px\"></div>
+".mex2("Nome delle unità singole da gestire",$pag,$lingua).": ".$trad_var['beds']."<br>
+".mex2("Numero di unità singole da gestire",$pag,$lingua).": 
+<input type=\"text\" name=\"numletti\" value=\"0\"><br>
 <div style=\"text-align: center;\"><input class=\"sbutton\" type=\"submit\" name=\"creabase\" value=\"".mex2("Crea il database",$pag,$lingua)."\"></div><br>
 <input type=\"hidden\" name=\"lingua\" value=\"$lingua\">
 </div></form>";
