@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -33,6 +33,7 @@ $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
 $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 $tableutenti = $PHPR_TAB_PRE."utenti";
+$tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -44,11 +45,15 @@ else include("./includes/head.php");
 
 
 if ($inserisci) {
+$aggiorna_ic_disp = 0;
+$aggiorna_ic_tar = 0;
 $tabelle_lock = array($tableregole);
 $altre_tab_lock = array($tableperiodi,$tableappartamenti,$tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
+
 if ($regola_1) {
+$regola_1_tar = "";
 if (!$inizioperiodo or !$fineperiodo or !$appartamento) {
 echo mex("Non sono stati inseriti tutti i dati necessari",$pag)."!<br>";
 } # fine if (!$inizioperiodo or !$fineperiodo or !$appartamento)
@@ -77,7 +82,61 @@ $idregole = $idregole + 1;
 esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ($idregole,'".aggslashdb($appartamento)."','$idinizioperiodo','$idfineperiodo')");
 if (@get_magic_quotes_gpc()) $motivazione = stripslashes($motivazione);
 $motivazione = htmlspecialchars($motivazione);
-if ($motivazione) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = $idregole");
+if ($motivazione) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
+if ($chiudi_app) {
+esegui_query("update $tableregole set motivazione2 = 'x' where idregole = '$idregole' ");
+unlock_tabelle($tabelle_lock);
+include("./includes/liberasettimane.php");
+$tabelle_lock = array($tableprenota);
+$altre_tab_lock = array($tableperiodi,$tableappartamenti,$tableregole,$tablepersonalizza);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+
+unset($limiti_var);
+unset($profondita);
+unset($dati_app);
+$limiti_var['idperiodocorrente'] = calcola_id_periodo_corrente($anno);
+if ($idinizioperiodo > $limiti_var['idperiodocorrente']) $n_ini = $idinizioperiodo;
+else {
+if (($limiti_var['idperiodocorrente'] + 1) <= $idfineperiodo) $n_ini = ($limiti_var['idperiodocorrente'] + 1);
+else $n_ini = $limiti_var['idperiodocorrente'];
+} # fine else if ($idinizioperiodo > $limiti_var['idperiodocorrente'])
+$limiti_var['n_ini'] = $n_ini;
+$limiti_var['n_fine'] = $idfineperiodo;
+$profondita['iniziale'] = "";
+$profondita['attuale'] = 1;
+$max_prenota = esegui_query("select max(idprenota) from $tableprenota");
+$tot_prenota = risul_query($max_prenota,0,0);
+$profondita['tot_prenota_ini'] = $tot_prenota;
+$profondita['tot_prenota_attuale'] = $tot_prenota;
+tab_a_var($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_app_sett,$anno,$dati_app,$profondita,$PHPR_TAB_PRE."prenota");
+$fatto_libera = "";
+$app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and idregole != '$idregole' ");
+$num_app_agenzia = numlin_query($app_agenzia);
+if ($num_app_agenzia != 0) {
+$info_periodi_ag['numero'] = $num_app_agenzia;
+for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
+$info_periodi_ag['app'][$num1] = risul_query($app_agenzia,$num1,'app_agenzia');
+$info_periodi_ag['ini'][$num1] = risul_query($app_agenzia,$num1,'iddatainizio');
+$info_periodi_ag['fine'][$num1] = risul_query($app_agenzia,$num1,'iddatafine');
+} # fine for $num1
+inserisci_prenota_fittizie($info_periodi_ag,$profondita,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett,$app_assegnabili_id);
+} # fine if ($num_app_agenzia != 0)
+unset($app_richiesti);
+$app_richiesti[',numero,'] = 1;
+$app_richiesti[1] = $appartamento;
+$idinizioperiodo_vett[1] = $n_ini;
+$idfineperiodo_vett[1] = $idfineperiodo;
+liberasettimane($idinizioperiodo_vett,$idfineperiodo_vett,$limiti_var,$anno,$fatto_libera,$app_liberato_vett,$profondita,$app_richiesti,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_app_sett,$dati_app,$PHPR_TAB_PRE."prenota");
+if ($fatto_libera != "SI") $risul_agg = 0;
+else $risul_agg = aggiorna_tableprenota($app_prenota_id,$app_orig_prenota_id,$tableprenota);
+if ($risul_agg) {
+echo mex("Il periodo chiuso è stato liberato dalle prenotazioni",$pag).".<br>";
+} # fine if ($risul_agg)
+else echo mex("<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso",$pag).".<br>";
+unlock_tabelle($tabelle_lock);
+unset($tabelle_lock);
+$aggiorna_ic_disp = 1;
+} # fine if ($chiudi_app)
 echo mex("La regola è stata inserita",$pag).".";
 } # fine else if ($motivazione == "nessuna")
 } # fine else if ($num_vecchia_regola != 0)
@@ -85,10 +144,50 @@ echo mex("La regola è stata inserita",$pag).".";
 } # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
 } # fine if ($regola_1)
 
+
+if ($regola_1_tar) {
+if (!$inizioperiodo or !$fineperiodo or !$tipotariffa or substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO") {
+echo mex("Non sono stati inseriti tutti i dati necessari",$pag)."!<br>";
+} # fine if (!$inizioperiodo or !$fineperiodo or !$tipotariffa or...
+else {
+$idinizioperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '".aggslashdb($inizioperiodo)."' ");
+if (numlin_query($idinizioperiodo) == 0) $idinizioperiodo = 9999999;
+else $idinizioperiodo = risul_query($idinizioperiodo,0,'idperiodi');
+$idfineperiodo = esegui_query("select idperiodi from $tableperiodi where datafine = '".aggslashdb($fineperiodo)."' ");
+if (numlin_query($idfineperiodo) == 0) $idfineperiodo = -1;
+else $idfineperiodo = risul_query($idfineperiodo,0,'idperiodi');
+if ($idfineperiodo < $idinizioperiodo) {
+echo mex("Le date sono sbagliate",$pag).".<br>";
+} # fine if ($idfineperiodo < $idinizioperiodo)
+else {
+$vecchia_regola = esegui_query("select * from $tableregole where tariffa_chiusa = '$tipotariffa' and iddatainizio <= '$idfineperiodo' and iddatafine >= '$idinizioperiodo'");
+$num_vecchia_regola = numlin_query($vecchia_regola);
+if ($num_vecchia_regola != 0) echo mex("Esiste già una regola di questo tipo nel periodo selezionato",$pag).".<br>";
+else {
+if ($motivazione == " ") echo mex("Motivazione non valida",$pag).".<br>";
+else {
+$idregole = esegui_query("select max(idregole) from $tableregole");
+$idregole = risul_query($idregole,0,0);
+$idregole = $idregole + 1;
+esegui_query("insert into $tableregole (idregole,tariffa_chiusa,iddatainizio,iddatafine) values ('$idregole','$tipotariffa','$idinizioperiodo','$idfineperiodo')");
+if (@get_magic_quotes_gpc()) $motivazione = stripslashes($motivazione);
+$motivazione = htmlspecialchars($motivazione);
+if ($motivazione) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
+echo mex("La regola è stata inserita",$pag).".";
+$aggiorna_ic_tar = 1;
+} # fine else if ($motivazione == "nessuna")
+} # fine else if ($num_vecchia_regola != 0)
+} # fine else if ($idfineperiodo < $idinizioperiodo)
+} # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
+} # fine if ($regola_1_tar)
+
+
 if ($canc_regola_1) {
 if ($gia_stato) {
-esegui_query("delete from $tableregole where app_agenzia != ''");
+esegui_query("delete from $tableregole where (app_agenzia != '' and app_agenzia is not NULL) or (tariffa_chiusa != '' and tariffa_chiusa is not NULL) ");
 echo mex("Le regole sono state cancellate",$pag);
+$aggiorna_ic_disp = 1;
+$aggiorna_ic_tar = 1;
 } # fine if ($gia_stato)
 else {
 echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
@@ -97,7 +196,7 @@ echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <input type=\"hidden\" name=\"canc_regola_1\" value=\"$canc_regola_1\">
-<input class=\"sbutton\" type=\"submit\" name=\"gia_stato\" value=\"  ".mex("SI",$pag)."  \"></div></form>";
+<input class=\"sbutton\" type=\"submit\" name=\"gia_stato\" value=\"  ".mex("SI",$pag)."  \"></div></form><br>";
 } # fine else if ($gia_stato)
 } # fine if ($canc_regola_1)
 
@@ -152,6 +251,7 @@ $num_giorni_ini = "NULL";
 $num_giorni_fine = "'$num_giorni'";
 } # fine if ($ini_fine == "fine")
 } # fine if ($regola_2b)
+
 if ($inserire != "NO") {
 if ($num_regole_esistente != 0) {
 if ($regola_2b) esegui_query("update $tableregole set motivazione2 = '$lista_app', iddatainizio = $num_giorni_ini, iddatafine = $num_giorni_fine where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
@@ -166,28 +266,7 @@ if ($regola_2b) esegui_query("insert into $tableregole (idregole,tariffa_per_app
 else esegui_query("insert into $tableregole (idregole,tariffa_per_app,motivazione) values ('$idregole','".aggslashdb($tipotariffa)."','$lista_app')");
 echo mex("La regola di assegnazione",$pag)." 2 ".mex("è stata inserita",$pag).".<br>";
 } # fine else if ($num_regole_esistente != 0)
-
-$file_interconnessioni = C_DATI_PATH."/dati_interconnessioni.php";
-if (@is_file($file_interconnessioni)) {
-include($file_interconnessioni);
-if (@is_array($ic_present)) {
-unlock_tabelle($tabelle_lock);
-unset($tabelle_lock);
-$interconn_dir = opendir("./includes/interconnect/");
-while ($mod_ext = readdir($interconn_dir)) {
-if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) {
-include("./includes/interconnect/$mod_ext/name.php");
-if ($ic_present[$interconnection_name] == "SI") {
-include("./includes/interconnect/$mod_ext/functions.php");
-$funz_update_availability = "update_availability_".$interconnection_name;
-$funz_update_availability($file_interconnessioni,$anno,$PHPR_TAB_PRE,1);
-} # fine if ($ic_present[$interconnection_name] == "SI")
-} # fine if ($modello_ext != "." and $modello_ext != ".." and...
-} # fine while ($mod_ext = readdir($interconn_dir))
-closedir($interconn_dir);
-} # fine if (@is_array($ic_present))
-} # fine if (@is_file($file_interconnessioni))
-
+$aggiorna_ic_disp = 1;
 } # fine if ($inserire != "NO")
 } # fine if ($regola_2 or $regola_2b)
 
@@ -269,43 +348,98 @@ echo mex("La regola di assegnazione",$pag)." 4 ".mex("è stata inserita",$pag)."
 } # fine if ($regola_4)
 
 if ($tabelle_lock) unlock_tabelle($tabelle_lock);
-
-echo "
-<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input class=\"sbutton\" type=\"submit\" name=\"ok\" value=\"".mex("Torna indietro",$pag)."\">";
+
+if ($aggiorna_ic_disp or $aggiorna_ic_tar) {
+$lock = 1;
+$aggiorna_disp = $aggiorna_ic_disp;
+$aggiorna_tar = $aggiorna_ic_tar;
+if (@function_exists('pcntl_fork')) include("./includes/interconnect/aggiorna_ic_fork.php");
+else include("./includes/interconnect/aggiorna_ic.php");
+} # fine if ($aggiorna_ic_disp or $aggiorna_ic_tar)
+
 } # fine if ($inserisci)
 
 else {
 
 
+
+
 # Form iniziale di inserimento
 echo "<br><h4>".mex("Inserisci le regole di assegnazione per le prenotazioni dell'anno",$pag)." $anno
-</h4><br><hr style=\"width: 95%\">
-<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>1</b>.</div><br>
+</h4><br><hr style=\"width: 95%\">";
+
+$inizio_select = "";
+$fine_select = "";
+$oggi = date("Y-m-d",(time() + (C_DIFF_ORE * 3600)));
+$date_select = esegui_query("select datainizio,datafine from $PHPR_TAB_PRE"."periodi$anno where datainizio <= '$oggi' and datafine > '$oggi' ");
+if (numlin_query($date_select) != 0) {
+$inizio_select = risul_query($date_select,0,'datainizio');
+$fine_select = risul_query($date_select,0,'datafine');
+} # fine if (numlin_query($date_select) != 0)
+
+echo "<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>1</b>.</div><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
-".mex("Chiedi prima di assegnare l'appartamento",'unit.php')." <select name=\"appartamento\">
+<select name=\"chiudi_app\">
+<option value=\"1\" selected>".mex("Chiudi",$pag)."</option>
+<option value=\"\">".mex("Chiedi prima di assegnare",$pag)."</option>
+</select>
+ ".mex("l'appartamento",'unit.php')." <select name=\"appartamento\">
 <option value=\"\" selected>--</option>";
 include(C_DATI_PATH."/selectappartamenti.php");
 echo "</select> ".mex("nel periodo dal",$pag)." ";
-mostra_menu_date(C_DATI_PATH."/selectperiodi$anno.$id_utente.php","inizioperiodo","","","",$id_utente,$tema);
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno.$id_utente.php","inizioperiodo",$inizio_select,"","",$id_utente,$tema);
 echo " ".mex("al",$pag)." ";
-mostra_menu_date(C_DATI_PATH."/selectperiodi$anno.$id_utente.php","fineperiodo","","","",$id_utente,$tema);
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno.$id_utente.php","fineperiodo",$fine_select,"","",$id_utente,$tema);
 echo "<br>".mex("motivazione",$pag).":
  <input type=\"text\" name=\"motivazione\" size=\"30\" maxlength=\"30\">
  (".mex("opzionale",$pag).")<br><div style=\"text-align: center;\">
 <input class=\"sbutton\" type=\"submit\" name=\"regola_1\" value=\"".mex("Inserisci la regola",$pag)." 1\">
 </div></div></form>
+<hr style=\"width: 50%; margin-left: 2.5%;\">
+
+<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div class=\"linhbox\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
+<input type=\"hidden\" name=\"regola_1_tar\" value=\"1\">
+".mex("Chiudi",$pag)." <select name=\"tipotariffa\" id=\"t1\">
+<option value=\"\" selected>----</option>";
+$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
+$tariffa = "tariffa".$numtariffa;
+$tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
+$nometariffa = risul_query($rigatariffe,0,$tariffa);
+if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
+else $nometariffa_vedi = "";
+echo "
+<option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
+} # fine for $numtariffa
+echo "</select> ".mex("nel periodo dal",$pag)." ";
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno.$id_utente.php","inizioperiodo",$inizio_select,"","",$id_utente,$tema);
+echo " ".mex("al",$pag)." ";
+mostra_menu_date(C_DATI_PATH."/selectperiodi$anno.$id_utente.php","fineperiodo",$fine_select,"","",$id_utente,$tema);
+echo "<br>".mex("motivazione",$pag).":
+ <input type=\"text\" name=\"motivazione\" size=\"30\" maxlength=\"30\">
+ (".mex("opzionale",$pag).")
+ <input class=\"sbutton\" type=\"submit\" value=\"".mex("Inserisci la regola",$pag)." 1 ".mex("per le tariffe",$pag)."\">
+</div></form>
+<hr style=\"width: 50%; margin-left: 2.5%;\">
+
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <input class=\"sbutton\" type=\"submit\" name=\"canc_regola_1\" value=\"".mex("Cancella tutte le regole di questo tipo",$pag)."\">
-</div></form><hr style=\"width: 95%\"><a name=\"regola2\"></a>
+</div></form>
+<hr style=\"width: 95%\"><a name=\"regola2\"></a>
 
 <script type=\"text/javascript\">
 <!--
@@ -510,8 +644,6 @@ $array_maxocc
 ".mex("Quando si sceglie la tariffa",$pag)."
 <select name=\"tipotariffa\" id=\"t2\" onchange=\"aggiorna_val_reg2()\">
 <option value=\"\" selected>----</option>";
-$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
-$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
 $tariffa = "tariffa".$numtariffa;
 $tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
