@@ -62,16 +62,16 @@ define('C_CAMBIA_TIPO_PERIODI',"SI");
 define('C_DISABILITA_PASS_ADMIN',"SI");
 define('C_MOSTRA_COPYRIGHT',"SI"); # You are not authorized to remove the copyright notice. Ask info@digitaldruid.net
 # 0 per nessuna limitazione
-define('C_MASSIMO_NUM_UTENTI',30);
-define('C_MASSIMO_NUM_CLIENTI',50000);
-define('C_MASSIMO_NUM_TARIFFE',50);
-define('C_MASSIMO_NUM_CONTRATTI',50);
-define('C_MASSIMO_NUM_COSTI_AGG',70);
-define('C_MASSIMO_NUM_COSTI_AGG_IN_PRENOTA',40);
-define('C_MASSIMO_NUM_STORIA_SOLDI',70000);
+define('C_MASSIMO_NUM_UTENTI',40);
+define('C_MASSIMO_NUM_CLIENTI',70000);
+define('C_MASSIMO_NUM_TARIFFE',70);
+define('C_MASSIMO_NUM_CONTRATTI',70);
+define('C_MASSIMO_NUM_COSTI_AGG',150);
+define('C_MASSIMO_NUM_COSTI_AGG_IN_PRENOTA',50);
+define('C_MASSIMO_NUM_STORIA_SOLDI',90000);
 define('C_MASSIMO_NUM_COSTI',50000);
 define('C_MASSIMO_NUM_APP',0);
-define('C_MASSIMO_NUM_BYTE_UPLOAD',3145728);
+define('C_MASSIMO_NUM_BYTE_UPLOAD',12582912);
 define('C_CREA_ULTIMO_ACCESSO',"SI");
 if (!defined('C_CARTELLA_CREA_MODELLI')) define('C_CARTELLA_CREA_MODELLI',"");
 define('C_CHMOD_EXEC_MODELLI',"NO");
@@ -83,13 +83,17 @@ define('C_FILE_SCADENZA_ACCOUNT',"");
 define('C_HTML_PRE_LOGIN',"");
 define('C_HTML_POST_LOGIN',"");
 define('C_URL_LOGO',"");
+define('C_URL_FAVICON',"");
 define('C_SEC_LIMITE_LIBERA_APP',"");
 define('C_MASCHERA_EMAIL',"SI");
 define('C_URL_MODULO_PAYBOX',"http://");
-define('C_NASCONDI_MARCA',"NO");
+define('C_NASCONDI_MARCA',"");
 define('C_DISABILITA_COD_EMAIL_MODELLI',"NO");
+define('C_PASSWORD_BOOKINGCOM_IC',"");
 define('C_ORGANIZZAZIONE_VENERE_IC',"");
-define('C_FILE_TITOLO_PERS',"./dev/mod/title.txt");
+define('C_API_KEY_BBLIVERATE_IC',"");
+define('C_FILE_TITOLO_PERS',"");
+define('C_FILE_CSS_PERS',"./dev/pers.css");
 
 # Restrizioni per la demo amministratore
 define('C_RESTRIZIONI_DEMO_ADMIN',"NO");
