@@ -101,6 +101,7 @@ $files_sorgente = array(
 'includes/funzioni_log.php',
 'includes/funzioni_menu.php',
 'includes/funzioni_mod_prenota.php',
+'includes/funzioni_mysqli.php',
 'includes/funzioni_mysql.php',
 'includes/funzioni.php',
 'includes/funzioni_postgresql.php',
@@ -122,7 +123,8 @@ $files_sorgente = array(
 'includes/spezzaprenota.php',
 'includes/variabili_contratto.php',
 'includes/interconnect/',
-'includes/interconnect/IC',
+'includes/interconnect/aggiorna_ic_fork.php',
+'includes/interconnect/aggiorna_ic.php',
 'includes/lang/',
 'includes/lang/en/',
 'includes/lang/en/aggiorna.php',
