@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -53,8 +53,8 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',2.03);
-define('C_PHPR_VERSIONE_TXT',"2.0.3");
+define('C_PHPR_VERSIONE_NUM',2.10);
+define('C_PHPR_VERSIONE_TXT',"2.1.0");
 
 # Se non si specifica nessun anno uso l'attuale
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
@@ -76,7 +76,7 @@ if ($_SERVER['SERVER_NAME']) $HOSTNAME = $_SERVER['SERVER_NAME'];
 elseif ($SERVER_NAME) $HOSTNAME = $SERVER_NAME;
 $HOSTNAME = htmlspecialchars($HOSTNAME);
 
-if (strstr($_SERVER['HTTP_USER_AGENT'],'(iP') or strstr($_SERVER['HTTP_USER_AGENT'],'Android') or strstr($_SERVER['HTTP_USER_AGENT'],'webOS') or strstr($_SERVER['HTTP_USER_AGENT'],'BlackBerry')) $mobile_device = 1;
+if (strstr($_SERVER['HTTP_USER_AGENT'],'(iP') or strstr($_SERVER['HTTP_USER_AGENT'],'Android') or strstr($_SERVER['HTTP_USER_AGENT'],'webOS') or strstr($_SERVER['HTTP_USER_AGENT'],'BlackBerry') or strstr($_SERVER['HTTP_USER_AGENT'],'Mobile')) $mobile_device = 1;
 else $mobile_device = 0;
 
 
@@ -457,7 +457,10 @@ if ($_SERVER['REMOTE_PORT']) $REMOTE_PORT = $_SERVER['REMOTE_PORT'];
 $REMOTE_PORT = aggslashdb($REMOTE_PORT);
 if ($_SERVER['HTTP_USER_AGENT']) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
 $HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
-esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente','$REMOTE_ADDR','$HTTP_USER_AGENT','$ultimo_accesso')","",$id_utente);
+if ($_SERVER['HTTPS'] == "on" or $_SERVER['SERVER_PORT'] == "443") $tipo_conn = "HTTPS";
+else $tipo_conn = "HTTP";
+if (C_VERSIONE_ATTUALE >= 2.1) esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,tipo_conn,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente','$REMOTE_ADDR','$tipo_conn','$HTTP_USER_AGENT','$ultimo_accesso')","",$id_utente);
+else esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente','$REMOTE_ADDR','$HTTP_USER_AGENT','$ultimo_accesso')","",$id_utente);
 } # fine if ($password == $password_phpr and $tipo_pass != "n")
 
 else $login_fallito = "SI";
@@ -518,8 +521,9 @@ $HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
 $sessione = esegui_query("select * from $tablesessioni where idsessioni = '$id_sessione'");
 if (numlin_query($sessione) == 1) {
 $indirizzo_ip = risul_query($sessione,0,'indirizzo_ip');
+$tipo_conn = @risul_query($sessione,0,'tipo_conn');
 $user_agent = risul_query($sessione,0,'user_agent');
-if ($indirizzo_ip == $REMOTE_ADDR and $user_agent == $HTTP_USER_AGENT) {
+if (($indirizzo_ip == $REMOTE_ADDR and $user_agent == $HTTP_USER_AGENT) or ($tipo_conn == "HTTPS" and ($_SERVER['HTTPS'] == "on" or $_SERVER['SERVER_PORT'] == "443"))) {
 $id_utente_presunto = risul_query($sessione,0,'idutente');
 $utente_presente = esegui_query("select nome_utente from $tableutenti where idutenti = '$id_utente_presunto'");
 if (numlin_query($utente_presente) == 1) {
@@ -528,7 +532,7 @@ $id_utente = $id_utente_presunto;
 esegui_query("update $tablesessioni set ultimo_accesso = '$ultimo_accesso' where idsessioni = '$id_sessione'");
 } # fine if (numlin_query($utente_presente) == 1)
 else $sessione_scaduta = "SI";
-} # fine if ($indirizzo_ip == $REMOTE_ADDR and $user_agent == $HTTP_USER_AGENT)
+} # fine if (($indirizzo_ip == $REMOTE_ADDR and $user_agent == $HTTP_USER_AGENT) or...
 else $sessione_scaduta = "SI";
 } # fine if (numlin_query($sessione) == 1)
 else $sessione_scaduta = "SI";
