@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -41,9 +41,10 @@ $tablemessaggi = $PHPR_TAB_PRE."messaggi";
 $tableinterconnessioni  = $PHPR_TAB_PRE."interconnessioni";
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableutenti = $PHPR_TAB_PRE."utenti";
+$tablerelclienti = $PHPR_TAB_PRE."relclienti";
 
 
-if ($PHPR_DB_TYPE == "mysql") @esegui_query("SET default_storage_engine=MYISAM",1);
+if ($PHPR_DB_TYPE == "mysql" or $PHPR_DB_TYPE == "mysqli") @esegui_query("SET default_storage_engine=MYISAM",1);
 
 $filelock = fopen(C_DATI_PATH."/anni.lock","w+");
 if ($filelock) {
@@ -115,7 +116,7 @@ crea_indice($tablerclientiprenota,"idprenota",$PHPR_TAB_PRE."iidprclientiprenota
 
 # Creo la tabella per le regole di assegnazione
 $tableregole = $PHPR_TAB_PRE."regole".$anno;
-$col_tableregole = "idregole integer, app_agenzia varchar(100), tariffa_per_app text, tariffa_per_utente text, tariffa_per_persone text, tariffa_commissioni integer, iddatainizio integer, iddatafine integer, motivazione text, motivazione2 text";
+$col_tableregole = "idregole integer, app_agenzia varchar(100), tariffa_chiusa text, tariffa_per_app text, tariffa_per_utente text, tariffa_per_persone text, tariffa_commissioni integer, iddatainizio integer, iddatafine integer, motivazione text, motivazione2 text";
 esegui_query("create table $tableregole ($col_tableregole)");
 $col_tableregole = estrai_col_tabella($col_tableregole);
 
@@ -131,7 +132,7 @@ $col_tablesoldi = "idsoldi integer unique, motivazione text, id_pagamento text,
 esegui_query("create table $tablesoldi ($col_tablesoldi)");
 $col_tablesoldi = estrai_col_tabella($col_tablesoldi);
 
-$tabelle_lock = array($tableanni,$tableprenotazioni,$tablecostiprenota,$tablerclientiprenota,$tablenometariffe,$tableperiodi,$tablecosti,$tableregole,$tablesoldi,$tablepersonalizza,$tableprivilegi,$tabletransazioni);
+$tabelle_lock = array($tableanni,$tableprenotazioni,$tablecostiprenota,$tablerclientiprenota,$tablenometariffe,$tableperiodi,$tablerelclienti,$tablecosti,$tableregole,$tablesoldi,$tablepersonalizza,$tableprivilegi,$tabletransazioni);
 if ($importa_anno_prec == "SI") {
 $anno_prec = $anno - 1;
 $tablenometariffe_prec = $PHPR_TAB_PRE."ntariffe".$anno_prec;
@@ -142,7 +143,7 @@ $tableperiodi_prec = $PHPR_TAB_PRE."periodi".$anno_prec;
 $tableregole_prec = $PHPR_TAB_PRE."regole".$anno_prec;
 $tablesoldi_prec = $PHPR_TAB_PRE."soldi".$anno_prec;
 $tablecosti_prec = $PHPR_TAB_PRE."costi".$anno_prec;
-$tabelle_lock = array($tableanni,$tableprenota_prec,$tableprenotazioni,$tablecostiprenota_prec,$tablecostiprenota,$tablerclientiprenota_prec,$tablerclientiprenota,$tablenometariffe,$tableperiodi,$tablecosti_prec,$tablecosti,$tableregole,$tablesoldi_prec,$tablesoldi,$tableinterconnessioni,$tablemessaggi,$tablepersonalizza,$tableprivilegi,$tabletransazioni);
+$tabelle_lock = array($tableanni,$tableprenota_prec,$tableprenotazioni,$tablecostiprenota_prec,$tablecostiprenota,$tablerclientiprenota_prec,$tablerclientiprenota,$tablenometariffe,$tableperiodi,$tablerelclienti,$tablecosti_prec,$tablecosti,$tableregole,$tablesoldi_prec,$tablesoldi,$tableinterconnessioni,$tablemessaggi,$tablepersonalizza,$tableprivilegi,$tabletransazioni);
 $altre_tab_lock = array($tablenometariffe_prec,$tableperiodi_prec,$tableregole_prec,$tablecontratti,$tableutenti);
 $max_data_ini_prec = esegui_query("select max(datainizio) from $tableperiodi_prec");
 if (numlin_query($max_data_ini_prec) != 0) {
@@ -300,6 +301,9 @@ fclose($fileaperto);
 if ($importa_anno_prec == "SI" and @is_file(C_DATI_PATH."/selperiodimenu".($anno - 1).".1.php")) estendi_menu_date(C_DATI_PATH."/selperiodimenu".($anno - 1).".1.php",C_DATI_PATH."/selperiodimenu$anno.1.php",$tipo_periodi,date("Y-m-d",mktime(0,0,0,$mese_ini,1,$anno)),$data_ini_agg,date("Y-m-d",mktime(0,0,0,($mese_fine + 1),1,$anno)),$anno,$pag);
 else copy(C_DATI_PATH."/selectperiodi$anno.1.php",C_DATI_PATH."/selperiodimenu$anno.1.php");
 
+$lista_clienti_importati = "";
+
+
 # Importo eventuali prenotazioni, tariffe e regole dell'anno precedente
 if ($importa_anno_prec == "SI") {
 $tableprenota = $tableprenotazioni;
@@ -338,6 +342,7 @@ $num_prenota_gia_iniziate = numlin_query($prenota_gia_iniziate);
 for ($num1 = 0 ; $num1 < $num_prenota_gia_iniziate ; $num1 = $num1 + 1) {
 $idprenota = risul_query($prenota_gia_iniziate,$num1,'idprenota');
 $idclienti = risul_query($prenota_gia_iniziate,$num1,'idclienti');
+$lista_clienti_importati .= "and idclienti != '$idclienti' ";
 $idappartamenti = risul_query($prenota_gia_iniziate,$num1,'idappartamenti');
 $iddatafine = risul_query($prenota_gia_iniziate,$num1,'iddatafine');
 $iddatafine = $iddatafine - $id_data_ini_periodi_prec + 1;
@@ -372,6 +377,8 @@ $iddatainizio = risul_query($prenota_importate,$num1,'iddatainizio');
 $iddatainizio = $iddatainizio - $id_data_ini_periodi_prec + 1;
 $iddatafine = risul_query($prenota_importate,$num1,'iddatafine');
 $iddatafine = $iddatafine - $id_data_ini_periodi_prec + 1;
+$idclienti = risul_query($prenota_importate,$num1,'idclienti');
+$lista_clienti_importati .= "and idclienti != '$idclienti' ";
 $id_anni_prec = risul_query($prenota_importate,$num1,'id_anni_prec');
 if (!$id_anni_prec) $id_anni_prec = ";";
 $id_anni_prec .= "$anno_prec,$idprenota;";
@@ -466,6 +473,7 @@ $num_regole_prec = numlin_query($regole_prec);
 for ($num1 = 0 ; $num1 < $num_regole_prec ; $num1 = $num1 + 1) {
 $idregole = risul_query($regole_prec,$num1,'idregole');
 $app_agenzia = risul_query($regole_prec,$num1,'app_agenzia');
+$tariffa_chiusa = risul_query($regole_prec,$num1,'tariffa_chiusa');
 $tariffa_commissioni = risul_query($regole_prec,$num1,'tariffa_commissioni');
 $iddatainizio = risul_query($regole_prec,$num1,'iddatainizio');
 if ($iddatainizio < $id_data_ini_periodi_prec) { $iddatainizio = $id_data_ini_periodi_prec; }
@@ -474,7 +482,10 @@ $iddatafine = risul_query($regole_prec,$num1,'iddatafine');
 if ($iddatafine > $id_data_fine_periodi_prec) { $iddatafine = $id_data_fine_periodi_prec; }
 $iddatafine = $iddatafine - $id_data_ini_periodi_prec + 1;
 if ($tariffa_commissioni) esegui_query("insert into $tableregole (idregole,tariffa_commissioni,iddatainizio,iddatafine) values ('$idregole','$tariffa_commissioni','$iddatainizio','$iddatafine') ");
+else {
+if ($tariffa_chiusa) esegui_query("insert into $tableregole (idregole,tariffa_chiusa,iddatainizio,iddatafine) values ('$idregole','$tariffa_chiusa','$iddatainizio','$iddatafine') ");
 else esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ('$idregole','$app_agenzia','$iddatainizio','$iddatafine') ");
+} # fine else $tariffa_commissioni)
 } # fine for $num1
 
 $soldi_importati = esegui_query("select * from $tablesoldi_prec where data_inserimento >= '$data_inizio_periodi' and  saldo_prenota is not NULL order by idsoldi");
@@ -546,7 +557,7 @@ esegui_query("update $tablemessaggi set dati_messaggio1 = '$n_lista_pren', dati_
 } # fine if ($agg_mess)
 } # fine for $num1
 
-# aggiorno i numeri delle prenotazioni importate nei nomi dei documenti già creati nel nuovo annoù
+# aggiorno i numeri delle prenotazioni importate nei nomi dei documenti già creati nel nuovo anno
 $dirs_salva = esegui_query("select * from $tablecontratti where tipo = 'dir'");
 $num_dirs_salva = numlin_query($dirs_salva);
 if ($num_dirs_salva) {
@@ -714,6 +725,8 @@ esegui_query("update $tablenometariffe set nomecostoagg = '8' where idntariffe =
 esegui_query("update $tablenometariffe set numlimite_ca = '11' where idntariffe = '1'");
 } # fine if ($inserisci_in_ntariffe != "NO")
 
+esegui_query("delete from $tablerelclienti where tipo = 'cc' $lista_clienti_importati");
+
 unlock_tabelle($tabelle_lock);
 
 
