@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,11 +23,15 @@
 
 
 
-function inserisci_dati_cliente (&$cognome,&$nome,$soprannome,$titolo_cli,$sesso,$mesenascita,$giornonascita,$annonascita,&$nazionenascita,&$cittanascita,&$regionenascita,$documento,$tipodoc,$mesescaddoc,$giornoscaddoc,$annoscaddoc,&$cittadoc,&$regionedoc,&$nazionedoc,&$nazionalita,&$lingua_cli,&$nazione,&$citta,&$regione,&$via,$nomevia,$numcivico,$cap,$telefono,$telefono2,$telefono3,$fax,$email,$cod_fiscale,$partita_iva,$max_num_ordine,$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti="",$valida="") {
+function inserisci_dati_cliente (&$cognome,&$nome,$soprannome,$titolo_cli,$sesso,$mesenascita,$giornonascita,$annonascita,&$nazionenascita,&$cittanascita,&$regionenascita,$documento,$tipodoc,$mesescaddoc,$giornoscaddoc,$annoscaddoc,&$cittadoc,&$regionedoc,&$nazionedoc,&$nazionalita,&$lingua_cli,&$nazione,&$citta,&$regione,&$via,$nomevia,$numcivico,$cap,$telefono,$telefono2,$telefono3,$fax,$email,$cod_fiscale,$partita_iva,$max_num_ordine,$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti="",$valida="",$campi_pers_vett="") {
 global $lingua_mex,$HOSTNAME,$id_utente,$PHPR_TAB_PRE;
 $tableclienti = $PHPR_TAB_PRE."clienti";
+$tablerelclienti = $PHPR_TAB_PRE."relclienti";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
+if (@is_array($campi_pers_vett) and $campi_pers_vett['num']) $num_campi_pers = $campi_pers_vett['num'];
+else $num_campi_pers = 0;
+
 if ($valida != "NO") {
 if (@get_magic_quotes_gpc()) {
 $cognome = stripslashes($cognome);
@@ -56,6 +60,7 @@ $fax = stripslashes($fax);
 $email = stripslashes($email);
 $cod_fiscale = stripslashes($cod_fiscale);
 $partita_iva = stripslashes($partita_iva);
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = stripslashes($campi_pers_vett['val'][$num1]);
 } # fine if (@get_magic_quotes_gpc())
 $cognome = htmlspecialchars($cognome);
 $nome = htmlspecialchars($nome);
@@ -83,6 +88,7 @@ $fax = htmlspecialchars($fax);
 $email = htmlspecialchars($email);
 $cod_fiscale = htmlspecialchars($cod_fiscale);
 $partita_iva = htmlspecialchars($partita_iva);
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) $campi_pers_vett['val'][$num1] = htmlspecialchars($campi_pers_vett['val'][$num1]);
 } # fine if ($valida != "NO")
 
 if (!$idclienti) {
@@ -235,7 +241,15 @@ if ($cod_fiscale) esegui_query("update $tableclienti set cod_fiscale = '$cod_fis
 $partita_iva = aggslashdb($partita_iva);
 if ($partita_iva) esegui_query("update $tableclienti set partita_iva = '$partita_iva' where idclienti = '$idclienti' ");
 if ($max_num_ordine) esegui_query("update $tableclienti set max_num_ordine = '".aggslashdb($max_num_ordine)."' where idclienti = '$idclienti' ");
+
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) {
+if (strcmp($campi_pers_vett['val'][$num1],"")) {
+esegui_query("insert into $tablerelclienti (idclienti,numero,tipo,testo1,testo2,testo3,datainserimento,hostinserimento,utente_inserimento) values ('$idclienti','1','campo_pers','".$campi_pers_vett[$num1]."','".$campi_pers_vett['tipo'][$num1]."','".$campi_pers_vett['val'][$num1]."','$datainserimento','$HOSTNAME','$id_utente_ins') ");
+} # fine if (strcmp($campi_pers_vett['val'][$num1],""))
+} # fine for $num1
+
 return $idclienti;
+
 } # fine function inserisci_dati_cliente
 
 
