@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 
 
 
-function dati_costi_agg_ntariffe ($tablenometariffe,$num_tariffe,$solo_visibili = "NO",$ordine_imposto = "") {
+function dati_costi_agg_ntariffe ($tablenometariffe,$num_tariffe,$solo_visibili="NO",$ordine_imposto="",$tableappartamenti="") {
 global $LIKE;
 
 if ($num_tariffe == "NO") $num_tariffe = 0;
@@ -118,6 +118,20 @@ $dati_ca[$num1]['sett_periodipermessi_fine'][$num2] = $sett_periodipermesso[1];
 } # fine for $num2
 } # fine if ($dati_ca[$num1][periodipermessi])
 $dati_ca[$num1]['appincompatibili'] = risul_query($costi,$num1,'appincompatibili_ca');
+if ($dati_ca[$num1]['letto'] == "s" and $tableappartamenti) {
+if (!$app_letto) {
+$app_letto = esegui_query("select idappartamenti from $tableappartamenti where letto = '1' ");
+$num_app_letto = numlin_query($app_letto);
+} # fine if (!$app_letto)
+if ($num_app_letto) {
+$dati_ca[$num1]['var_appi'] = "s";
+for ($num2 = 0 ; $num2 < $num_app_letto ; $num2++) {
+$idapp = risul_query($app_letto,$num2,'idappartamenti');
+if (!strstr(",".$dati_ca[$num1]['appincompatibili'].",",",$idapp,")) $dati_ca[$num1]['appincompatibili'] .= ",$idapp";
+} # fine for $num2
+if (substr($dati_ca[$num1]['appincompatibili'],0,1) == ",") $dati_ca[$num1]['appincompatibili'] = substr($dati_ca[$num1]['appincompatibili'],1);
+} # fine if ($num_app_letto)
+} # fine if ($dati_ca[$num1]['letto'] == "s" and $tableappartamenti)
 $dati_ca[$num1]['categoria'] = risul_query($costi,$num1,'categoria_ca');
 $dati_ca[$num1]['numlimite'] = risul_query($costi,$num1,'numlimite_ca');
 $regoleassegna_ca = explode(";",risul_query($costi,$num1,'regoleassegna_ca'));
