@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -87,6 +87,7 @@ $rigasettimana = esegui_query("select * from $tableperiodi where idperiodi = '$n
 $esistetariffa = risul_query($rigasettimana,0,$tipotariffa[$n_t]);
 $esistetariffap = risul_query($rigasettimana,0,$tipotariffa[$n_t]."p");
 if ((!strcmp($esistetariffa,"") or $esistetariffa < 0) and (!strcmp($esistetariffap,"") or $esistetariffap < 0) and !strcmp($tar_sett_imp[$num1],"")) $tariffa_sbagliata = "SI";
+if ($dati_tariffe[$tipotariffa[$n_t]]['chiusa'][$num1] and !strcmp($tar_sett_imp[$num1],"")) $tariffa_sbagliata = "SI";
 } # fine for $num1
 } # fine else if (substr($tipotariffa[$n_t],0,7) != "tariffa" or...
 if ($tariffa_sbagliata == "SI") {
@@ -250,6 +251,18 @@ else $tot_prenota = 0;
 $profondita['tot_prenota_ini'] = $tot_prenota;
 $profondita['tot_prenota_attuale'] = $tot_prenota;
 tab_a_var($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_app_sett,$anno,$dati_app,$profondita,$PHPR_TAB_PRE."prenota");
+unset($info_periodi_ag);
+$info_periodi_ag['numero'] = 0;
+for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
+$mot2 = risul_query($app_agenzia,$num1,'motivazione2');
+if ($mot2 == "x") {
+$info_periodi_ag['app'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'app_agenzia');
+$info_periodi_ag['ini'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'iddatainizio');
+$info_periodi_ag['fine'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'iddatafine');
+$info_periodi_ag['numero']++;
+} # fine if ($mot2 == "x")
+} # fine for $num1
+if ($info_periodi_ag['numero']) inserisci_prenota_fittizie($info_periodi_ag,$profondita,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett,$app_assegnabili_id);
 $limiti_var2 = $limiti_var;
 $profondita2 = $profondita;
 $prenota_in_app_sett2 = $prenota_in_app_sett;
@@ -257,13 +270,18 @@ $inizio_prenota_id2 = $inizio_prenota_id;
 $fine_prenota_id2 = $fine_prenota_id;
 $app_prenota_id2 = $app_prenota_id;
 $app_assegnabili_id2 = $app_assegnabili_id;
-$info_periodi_ag['numero'] = $num_app_agenzia;
-for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1 = $num1 + 1) {
-$info_periodi_ag['app'][$num1] = risul_query($app_agenzia,$num1,'app_agenzia');
-$info_periodi_ag['ini'][$num1] = risul_query($app_agenzia,$num1,'iddatainizio');
-$info_periodi_ag['fine'][$num1] = risul_query($app_agenzia,$num1,'iddatafine');
+unset($info_periodi_ag);
+$info_periodi_ag['numero'] = 0;
+for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
+$mot2 = risul_query($app_agenzia,$num1,'motivazione2');
+if ($mot2 != "x") {
+$info_periodi_ag['app'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'app_agenzia');
+$info_periodi_ag['ini'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'iddatainizio');
+$info_periodi_ag['fine'][$info_periodi_ag['numero']] = risul_query($app_agenzia,$num1,'iddatafine');
+$info_periodi_ag['numero']++;
+} # fine if ($mot2 != "x")
 } # fine for $num1
-inserisci_prenota_fittizie($info_periodi_ag,$profondita2,$app_prenota_id2,$inizio_prenota_id2,$fine_prenota_id2,$prenota_in_app_sett2,$app_assegnabili_id2);
+if ($info_periodi_ag['numero']) inserisci_prenota_fittizie($info_periodi_ag,$profondita2,$app_prenota_id2,$inizio_prenota_id2,$fine_prenota_id2,$prenota_in_app_sett2,$app_assegnabili_id2);
 $occupare_app_agenzia_sempre = "NO";
 for ($num1 = $idinizioperiodo_tot ; $num1 <= $idfineperiodo_tot ; $num1++) {
 $numprenotazioni = 0;
@@ -272,7 +290,7 @@ if ($numprenotazioni >= $numappartamenti) $occupare_app_agenzia_sempre = "SI";
 } # fine for $num1
 if ($occupare_app_agenzia_sempre != "SI") {
 $app_orig_prenota_id = $app_prenota_id2;
-liberasettimane ($idinizioperiodo_vett,$idfineperiodo_vett,$limiti_var2,$anno,$fatto_libera,$app_liberato,$profondita2,$app_richiesti,$app_prenota_id2,$app_orig_prenota_id,$inizio_prenota_id2,$fine_prenota_id2,$app_assegnabili_id2,$prenota_in_app_sett2,$dati_app,$PHPR_TAB_PRE."prenota");
+liberasettimane($idinizioperiodo_vett,$idfineperiodo_vett,$limiti_var2,$anno,$fatto_libera,$app_liberato,$profondita2,$app_richiesti,$app_prenota_id2,$app_orig_prenota_id,$inizio_prenota_id2,$fine_prenota_id2,$app_assegnabili_id2,$prenota_in_app_sett2,$dati_app,$PHPR_TAB_PRE."prenota");
 } # fine if ($occupare_app_agenzia_sempre != "SI")
 else $fatto_libera = "NO";
 if ($fatto_libera == "SI") {
@@ -311,6 +329,8 @@ else {
 $appartamento = $app_liberato;
 $mess_regola1 .= mex("Sono stati fatti i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>","clienti.php").":<br>";
 for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
+$mot2 = risul_query($app_agenzia,$num1,'motivazione2');
+if ($mot2 != "x") {
 $id_app_agenzia = risul_query($app_agenzia,$num1,'app_agenzia');
 $idinizio_app_agenzia = risul_query($app_agenzia,$num1,'iddatainizio');
 $idfine_app_agenzia = risul_query($app_agenzia,$num1,'iddatafine');
@@ -365,6 +385,7 @@ if ($id_app_agenzia == $appartamento_controlla and $idinizio_app_agenzia <= $idf
 $mess_regola1 .= mex("La nuova prenotazione verrà inserita nell'appartamento",'unit.php')." <div style=\"display: inline; color: blue;\"><b>$id_app_agenzia</b></div> (<b>$motivazione_app_agenzia</b>).<br>";
 } # fine if ($id_app_agenzia == $appartamento_controlla and ...
 } # fine for $num2
+} # fine if ($mot2 != "x")
 } # fine for $num1
 } # fine else if ($fatto_libera2 == "NO")
 } # fine else if ($fatto_libera == "SI")
