@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -297,7 +297,7 @@ $d_prenota_comp_idpr = "";
 $n_host_inserimento_idpr = "";
 
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
-$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num']);
+$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO","",$tableappartamenti);
 
 
 $dati_prenota_modifica = esegui_query("select * from $tableprenota where idprenota = '".$id_prenota_idpr[0]."' and idclienti != '0'");
@@ -368,7 +368,7 @@ $tableperiodi_prec = $PHPR_TAB_PRE."periodi".($anno - 1);
 $tableprenota_prec = $PHPR_TAB_PRE."prenota".($anno - 1);
 $tablecostiprenota_prec = $PHPR_TAB_PRE."costiprenota".($anno - 1);
 $dati_tariffe = dati_tariffe($PHPR_TAB_PRE."ntariffe".($anno - 1),"","",$PHPR_TAB_PRE."regole".($anno - 1));
-$dati_ca = dati_costi_agg_ntariffe($PHPR_TAB_PRE."ntariffe".($anno - 1),$dati_tariffe['num']);
+$dati_ca = dati_costi_agg_ntariffe($PHPR_TAB_PRE."ntariffe".($anno - 1),$dati_tariffe['num'],"NO","",$tableappartamenti);
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota_prec,$id_prenota_prec);
 ${"dati_cap".$id_prenota} = $dati_cap;
 function passa_var_a_anno_prec (&$id_prenota,&$tableperiodi,&$tableprenota,&$tablecostiprenota,&$d_id_data_inizio,&$d_id_data_fine,&$n_fineperiodo,&$inizioperiodo,&$fineperiodo,&$lunghezza_periodo,$dati_prenota_modifica) {
@@ -516,7 +516,7 @@ include("./includes/interconnect/$mod_ext/functions_import.php");
 $funz_import_reservations = "import_reservations_".$interconnection_name;
 $id_utente_origi = $id_utente;
 $id_utente = 1;
-$funz_import_reservations("","",$file_interconnessioni,$anno,$PHPR_TAB_PRE,1,$id_utente,$HOSTNAME);
+$funz_import_reservations("","",$file_interconnessioni,$anno,$PHPR_TAB_PRE,2,$id_utente,$HOSTNAME);
 $id_utente = $id_utente_origi;
 } # fine if ($ic_present[$interconnection_name] == "SI")
 } # fine if ($modello_ext != "." and $modello_ext != ".." and...
@@ -634,16 +634,15 @@ $dati_cap = ${"dati_cap".$id_prenota};
 unset($num_costi_presenti);
 
 
-$dati_prenota = esegui_query("select * from $tableprenota where idprenota = '$id_prenota' and idclienti != '0'");
-$dati_prenota_idpr[$id_prenota] = $dati_prenota;
-$num_dati_prenota = numlin_query($dati_prenota);
+$dati_prenota_idpr[$id_prenota] = esegui_query("select * from $tableprenota where idprenota = '$id_prenota' and idclienti != '0'");
+$num_dati_prenota = numlin_query($dati_prenota_idpr[$id_prenota]);
 if ($num_dati_prenota == 0) {
 $inserire = "NO";
 $cancellata = "SI";
 } # fine if ($num_dati_prenota == 0)
 else {
-$n_data_inserimento = risul_query($dati_prenota,0,'datainserimento');
-$n_host_inserimento = risul_query($dati_prenota,0,'hostinserimento');
+$n_data_inserimento = risul_query($dati_prenota_idpr[$id_prenota],0,'datainserimento');
+$n_host_inserimento = risul_query($dati_prenota_idpr[$id_prenota],0,'hostinserimento');
 if ($n_data_inserimento != $d_data_inserimento_idpr[$num_idpr] or $n_host_inserimento != $d_host_inserimento_idpr[$num_idpr]) {
 $inserire = "NO";
 $cancellata = "SI";
@@ -651,18 +650,18 @@ $inizioperiodo = "";
 $fineperiodo = "";
 } # fine if ($n_data_inserimento != $d_data_inserimento_idpr[$num_idpr] or ...
 if ($n_appartamento != "") $appartamento = $n_appartamento;
-else $appartamento = risul_query($dati_prenota,0,'idappartamenti');
+else $appartamento = risul_query($dati_prenota_idpr[$id_prenota],0,'idappartamenti');
 if ($n_numpersone != "") $numpersone = $n_numpersone;
-else $numpersone = risul_query($dati_prenota,0,'num_persone');
+else $numpersone = risul_query($dati_prenota_idpr[$id_prenota],0,'num_persone');
 if (!$numpersone) $numpersone = 0;
 if ($n_assegnazioneapp != "") $assegnazioneapp = $n_assegnazioneapp;
-else $assegnazioneapp = risul_query($dati_prenota,0,'assegnazioneapp');
+else $assegnazioneapp = risul_query($dati_prenota_idpr[$id_prenota],0,'assegnazioneapp');
 if ($n_lista_app != "") $lista_app = $n_lista_app;
-else $lista_app = risul_query($dati_prenota,0,'app_assegnabili');
+else $lista_app = risul_query($dati_prenota_idpr[$id_prenota],0,'app_assegnabili');
 if ($n_inizioperiodo != "") $inizioperiodo = $n_inizioperiodo;
-else $inizioperiodo = risul_query($dati_prenota,0,'iddatainizio');
+else $inizioperiodo = risul_query($dati_prenota_idpr[$id_prenota],0,'iddatainizio');
 if ($n_fineperiodo != "") $fineperiodo = $n_fineperiodo;
-else $fineperiodo = risul_query($dati_prenota,0,'iddatafine');
+else $fineperiodo = risul_query($dati_prenota_idpr[$id_prenota],0,'iddatafine');
 } # fine else if ($num_dati_prenota == 0)
 
 if ($n_stima_checkin) {
@@ -688,6 +687,9 @@ $maxoccupanti = risul_query($appartamento_esistente,0,'maxoccupanti');
 if ($maxoccupanti and $numpersone > $maxoccupanti and $n_numpersone) $inserire = "NO";
 } # fine else if (numlin_query($appartamento_esistente) != 1)
 
+$appartamento_chiuso = esegui_query("select idregole from $tableregole where iddatainizio <= '$fineperiodo' and iddatafine >= '$inizioperiodo' and app_agenzia = '$appartamento' and motivazione2 = 'x' ");
+if (numlin_query($appartamento_chiuso)) $inserire = "NO";
+
 if ($assegnazioneapp == "c" and str_replace(",".$appartamento.",","",",".$lista_app.",") == ",".$lista_app."," and ($n_appartamento or $n_assegnazioneapp or $n_lista_app)) $inserire = "NO";
 
 if ($attiva_regole1_consentite == "s" and ($n_appartamento != "" or $n_assegnazioneapp != "" or $n_lista_app != "")) {
@@ -697,7 +699,7 @@ if ($assegnazioneapp == "k") $appartameti_in_lista[0] = $appartamento;
 if ($assegnazioneapp == "c") $appartameti_in_lista = explode(",",$lista_app);
 for ($n_lista = 0 ; $n_lista < count($appartameti_in_lista) ; $n_lista++) {
 $appartamento_lista = $appartameti_in_lista[$n_lista];
-$motivazioni_regola1 = esegui_query("select motivazione,iddatainizio,iddatafine from $tableregole where iddatainizio <= '$fineperiodo' and iddatafine >= '$inizioperiodo' and app_agenzia = '$appartamento_lista' order by iddatainizio");
+$motivazioni_regola1 = esegui_query("select motivazione,iddatainizio,iddatafine from $tableregole where iddatainizio <= '$fineperiodo' and iddatafine >= '$inizioperiodo' and app_agenzia = '$appartamento_lista' and (motivazione2 != 'x' or motivazione2 is NULL) order by iddatainizio");
 if (numlin_query($motivazioni_regola1) == 0) $inserire = "NO";
 else {
 unset($motivazioni_consentite);
@@ -723,7 +725,7 @@ if ($iddatainizio_regole_tot > $inizioperiodo or $iddatafine_regole_tot < $finep
 if ($dati_da_anno_prec == "SI") passa_var_a_anno_prec($id_prenota,$tableperiodi,$tableprenota,$tablecostiprenota,$d_id_data_inizio,$d_id_data_fine,$n_fineperiodo,$inizioperiodo,$fineperiodo,$lunghezza_periodo,$dati_prenota_modifica);
 if ($n_nometipotariffa != "") {
 $trovata_tariffa = "NO";
-$dati_tariffe = dati_tariffe($tablenometariffe);
+$dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
 for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
 $tariffa = "tariffa".$numtariffa;
 $nometariffa = $dati_tariffe[$tariffa]['nome'];
@@ -739,6 +741,7 @@ $rigasettimana = esegui_query("select * from $tableperiodi where idperiodi = '$n
 $esistetariffa = risul_query($rigasettimana,0,$n_tipotariffa);
 $esistetariffap = risul_query($rigasettimana,0,$n_tipotariffa."p");
 if ((!strcmp($esistetariffa,"") or $esistetariffa < 0) and (!strcmp($esistetariffap,"") or $esistetariffap < 0)) $inserire = "NO";
+if ($n_nometipotariffa != $d_nome_tariffa_idpr[$id_prenota] and $dati_tariffe[$n_tipotariffa]['chiusa'][$num2]) $inserire = "NO";
 } # fine for $num2
 } # fine if ($n_nometipotariffa != "")
 
@@ -970,7 +973,6 @@ $num1++;
 # Aggiorno la prenotazione e faccio i primi controlli sulla prenotazione modificata
 for ($num_idpr = 0 ; $num_idpr < $num_id_prenota ; $num_idpr++) {
 $id_prenota = $id_prenota_idpr[$num_idpr];
-$dati_prenota = $dati_prenota_idpr[$id_prenota];
 $n_appartamento = $n_appartamento_idpr[$id_prenota];
 $n_assegnazioneapp = $n_assegnazioneapp_idpr[$id_prenota];
 $n_lista_app = $n_lista_app_idpr[$id_prenota];
@@ -985,10 +987,10 @@ else $prenota_in_app_sett[$app_prenota_id[$id_prenota]][$num1] = $id_prenota;
 if ($n_assegnazioneapp == "v") $app_assegnabili_id[$id_prenota] = $dati_app['lista'];
 if ($n_assegnazioneapp == "k") $app_assegnabili_id[$id_prenota] = "";
 if ($n_assegnazioneapp == "c" and $n_lista_app) $app_assegnabili_id[$id_prenota] = ",".$n_lista_app.",";
-$assegnazione_app = risul_query($dati_prenota,0,'assegnazioneapp');
+$assegnazione_app = risul_query($dati_prenota_idpr[$id_prenota],0,'assegnazioneapp');
 if (!$n_assegnazioneapp and $assegnazione_app == "c" and $n_lista_app) $app_assegnabili_id[$id_prenota] = ",".$n_lista_app.",";
 if ($n_numpersone) $num_persone_prenota = $n_numpersone;
-else $num_persone_prenota = risul_query($dati_prenota,0,'num_persone');
+else $num_persone_prenota = risul_query($dati_prenota_idpr[$id_prenota],0,'num_persone');
 if ($num_persone_prenota and $dati_app['maxocc'][$app_prenota_id[$id_prenota]] and $dati_app['maxocc'][$app_prenota_id[$id_prenota]] < $num_persone_prenota) $inserire = "NO";
 if (str_replace(",".$app_prenota_id[$id_prenota].",","",$dati_app['lista']) == $dati_app['lista']) $inserire = "NO";
 if ($app_assegnabili_id[$id_prenota] and $app_assegnabili_id[$id_prenota] != "v") {
@@ -1039,6 +1041,10 @@ echo mex("Non si è potuto spostare la prenotazione per la registrazione dell'en
 } # fine if ($inserire != "NO")
 
 if ($inserire != "NO" and $tableprenota_da_aggiornare) {
+for ($num_idpr = 0 ; $num_idpr < $num_id_prenota ; $num_idpr++) {
+$id_prenota = $id_prenota_idpr[$num_idpr];
+if (strcmp($app_prenota_id[$id_prenota],"") and !strcmp($app_orig_prenota_id[$id_prenota],"")) $app_orig_prenota_id[$id_prenota] = $app_prenota_id[$id_prenota]."x";
+} # fine for $num_idpr
 $risul_agg = aggiorna_tableprenota($app_prenota_id,$app_orig_prenota_id,$tableprenota);
 if (!$risul_agg) $inserire = "NO";
 } # fine if ($inserire != "NO" and $tableprenota_da_aggiornare)
@@ -1293,47 +1299,35 @@ if ($dati_da_anno_prec == "SI") passa_var_a_anno_corr($id_prenota,$tableperiodi,
 } # fine for $num_idpr
 
 
-if ($tableprenota_da_aggiornare or $n_inizioperiodo != "" or $n_fineperiodo != "") {
-if (@is_file($file_interconnessioni)) {
-include($file_interconnessioni);
-if (@is_array($ic_present)) {
-$interconn_dir = opendir("./includes/interconnect/");
-while ($mod_ext = readdir($interconn_dir)) {
-if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) {
-include("./includes/interconnect/$mod_ext/name.php");
-if ($ic_present[$interconnection_name] == "SI") {
-$funz_update_availability = "update_availability_".$interconnection_name;
-if (!function_exists($funz_update_availability)) include("./includes/interconnect/$mod_ext/functions.php");
-$funz_update_availability($file_interconnessioni,$anno,$PHPR_TAB_PRE,0);
-} # fine if ($ic_present[$interconnection_name] == "SI")
-} # fine if ($modello_ext != "." and $modello_ext != ".." and...
-} # fine while ($mod_ext = readdir($interconn_dir))
-closedir($interconn_dir);
-} # fine if (@is_array($ic_present))
-} # fine if (@is_file($file_interconnessioni))
-} # fine if ($tableprenota_da_aggiornare or...
-
-
 aggiorna_beniinv_presenti($tablerelinventario,$beniinv_presenti);
 
-unlock_tabelle($tabelle_lock);
+if ($tabelle_lock) unlock_tabelle($tabelle_lock);
+
+
+if ($tableprenota_da_aggiornare or $n_inizioperiodo != "" or $n_fineperiodo != "") {
+$lock = 1;
+$aggiorna_disp = 1;
+$aggiorna_tar = 0;
+if (@function_exists('pcntl_fork')) include("./includes/interconnect/aggiorna_ic_fork.php");
+else include("./includes/interconnect/aggiorna_ic.php");
+} # fine if ($tableprenota_da_aggiornare or...
+
 
 
 for ($num_idpr = 0 ; $num_idpr < $num_id_prenota ; $num_idpr++) {
 $id_prenota = $id_prenota_idpr[$num_idpr];
-$dati_prenota = $dati_prenota_idpr[$id_prenota];
 $n_pagato = $n_pagato_idpr[$id_prenota];
 if ($n_pagato != "") {
 $datainserimento_saldo = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
-$idcliente_saldo = risul_query($dati_prenota,0,'idclienti');
-$d_idinizioprenota = risul_query($dati_prenota,0,'iddatainizio');
-$d_idfineprenota = risul_query($dati_prenota,0,'iddatafine');
+$idcliente_saldo = risul_query($dati_prenota_idpr[$id_prenota],0,'idclienti');
+$d_idinizioprenota = risul_query($dati_prenota_idpr[$id_prenota],0,'iddatainizio');
+$d_idfineprenota = risul_query($dati_prenota_idpr[$id_prenota],0,'iddatafine');
 if ($n_inizioperiodo != "") $idinizioperiodo_saldo = $n_inizioperiodo;
 else $idinizioperiodo_saldo = $d_idinizioprenota;
 if ($n_fineperiodo != "") $idfineperiodo_saldo = $n_fineperiodo;
 else $idfineperiodo_saldo = $d_idfineprenota;
 $motivazione_saldo = "$idcliente_saldo;$idinizioperiodo_saldo;$idfineperiodo_saldo;$id_prenota";
-$pagato_attuale = risul_query($dati_prenota,0,'pagato');
+$pagato_attuale = risul_query($dati_prenota_idpr[$id_prenota],0,'pagato');
 if (!$pagato_attuale) $pagato_attuale = 0;
 $saldo = $n_pagato - $pagato_attuale;
 $metodo_pagamento = ${"metodo_pagamento".$id_prenota};
