@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,7 @@
 ##################################################################################
 
 
-function crea_quadro_disp ($id_data_inizio_tab_disp,$num_colonne_tab_disp,$mostra_quadro_disp,$mostra_num_liberi,$app_consentito,$app_consentito_sett,$app_regola2_orig,$tipo_periodi,$numero_tariffe,$nome_tariffa,$dati_app,$prenota_in_app_sett,$app_orig_prenota_id,$tableperiodi,$allinea_disp="") {
+function crea_quadro_disp ($id_data_inizio_tab_disp,$num_colonne_tab_disp,$mostra_quadro_disp,$mostra_num_liberi,$app_consentito,$app_consentito_sett,$app_regola2_orig,$tipo_periodi,$numero_tariffe,$nome_tariffa,$dati_app,$prenota_in_app_sett,$app_orig_prenota_id,$tableperiodi,$allinea_disp="",$dati_tariffe="") {
 global $c_sfondo_tab_disp,$c_inisett_tab_disp,$c_libero_tab_disp,$c_occupato_tab_disp,$aper_font_tab_disp,$chiu_font_tab_disp,$fr_persone,$fr_persona,$nome_mese,$colonna_destra_tab_disp,$tablepersonalizza,$id_utente,$anno;
 
 if ($tipo_periodi == "s") $colspan = 14;
@@ -29,6 +29,7 @@ else $colspan = 2;
 $num_raggr = 0;
 unset($nome_raggr);
 unset($app_ric_raggr);
+unset($tipotariffa);
 unset($num_app_ric_raggr);
 
 if ($mostra_quadro_disp == "app") {
@@ -52,6 +53,7 @@ for ($num1 = 0 ; $num1 < count($app_regola2) ; $num1++) if ($app_consentito[$app
 if ($app_ric_raggr[$num_raggr]) {
 $app_ric_raggr[$num_raggr] = substr($app_ric_raggr[$num_raggr],0,-1);
 $nome_raggr[$num_raggr] = str_replace(" ","&nbsp;",$nome_tariffa[$numtariffa]);
+$tipotariffa[$num_raggr] = "tariffa$numtariffa";
 $num_raggr++;
 } # fine if ($app_ric_raggr[$num_raggr])
 } # fine if ($app_regola2_orig[$numtariffa])
@@ -119,6 +121,7 @@ lista_prenota_periodo($id_periodo,$id_periodo,$dati_app,$prenota_in_app_sett,$pr
 for ($num3 = 0 ; $num3 < $num_lista_pren_per ; $num3++) {
 if (str_replace(",".$app_orig_prenota_id[$lista_prenota_periodo[$num3]].",","",$app_ric_colonna) != $app_ric_colonna) $num_app_liberi--;
 } # fine for $num3
+if ($mostra_quadro_disp == "reg2" and $dati_tariffe and $dati_tariffe[$tipotariffa[$num1]]['chiusa'][$id_periodo]) $num_app_liberi = 0;
 if ($num_app_liberi > 0) $color = $c_libero_tab_disp;
 else $color = $c_occupato_tab_disp;
 if ($num_app_liberi > 0 and $mostra_num_liberi == "SI") $val_liberi = $num_app_liberi;
