@@ -45,32 +45,42 @@ $dati_tariffe['tariffa'.$num1]['val_importa'] = $importa_prezzi[3];
 if ($importa_prezzi[2] == "p") $dati_tariffe['tariffa'.$num1]['arrotond_importa'] = $importa_prezzi[4];
 $dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'] .= "$num1,";
 } # fine if ($importa_prezzi)
+} # fine if (!$tariffa_sel or $tariffa_sel == $num1)
+} # fine for $num1
+
 if ($tableregole) {
-$comm = esegui_query("select * from $tableregole where tariffa_commissioni = '$num1' order by iddatainizio ");
-$num_comm = numlin_query($comm);
-for ($num2 = 0 ; $num2 < $num_comm ; $num2++) {
-$comm_percent = risul_query($comm,$num2,'motivazione');
+$regole = esegui_query("select * from $tableregole where (tariffa_commissioni != '' and tariffa_commissioni is not NULL) or (tariffa_chiusa != '' and tariffa_chiusa is not NULL) order by iddatainizio ");
+$num_regole = numlin_query($regole);
+for ($num1 = 0 ; $num1 < $num_regole ; $num1++) {
+$tariffa_commissioni = risul_query($regole,$num1,'tariffa_commissioni');
+if (strcmp($tariffa_commissioni,"") and (!$tariffa_sel or $tariffa_sel == $tariffa_commissioni)) {
+$comm_percent = risul_query($regole,$num1,'motivazione');
 $comm_base = "t";
 if (substr($comm_percent,0,1) == "s" or substr($comm_percent,0,1) == "c") {
 $comm_base = substr($comm_percent,0,1);
 $comm_percent = substr($comm_percent,1);
 } # fine if (substr($comm_percent,0,1) == "s" or substr($comm_percent,0,1) == "c")
-$iddataini = risul_query($comm,$num2,'iddatainizio');
+$iddataini = risul_query($regole,$num1,'iddatainizio');
 if (!$iddataini) {
-$dati_tariffe['tariffa'.$num1]['commissioni_percent']['def'] = $comm_percent;
-$dati_tariffe['tariffa'.$num1]['commissioni_base']['def'] = $comm_base;
-$dati_tariffe['tariffa'.$num1]['commissioni_arrotond']['def'] = risul_query($comm,$num2,'motivazione2');
+$dati_tariffe['tariffa'.$tariffa_commissioni]['commissioni_percent']['def'] = $comm_percent;
+$dati_tariffe['tariffa'.$tariffa_commissioni]['commissioni_base']['def'] = $comm_base;
+$dati_tariffe['tariffa'.$tariffa_commissioni]['commissioni_arrotond']['def'] = risul_query($regole,$num1,'motivazione2');
 } # fine if (!$iddataini)
 else {
-$iddatafin = risul_query($comm,$num2,'iddatafine');
-$dati_tariffe['tariffa'.$num1]['commissioni_percent']["$iddataini-$iddatafin"] = $comm_percent;
-$dati_tariffe['tariffa'.$num1]['commissioni_base']["$iddataini-$iddatafin"] = $comm_base;
-$dati_tariffe['tariffa'.$num1]['commissioni_arrotond']["$iddataini-$iddatafin"] = risul_query($comm,$num2,'motivazione2');
+$iddatafin = risul_query($regole,$num1,'iddatafine');
+$dati_tariffe['tariffa'.$tariffa_commissioni]['commissioni_percent']["$iddataini-$iddatafin"] = $comm_percent;
+$dati_tariffe['tariffa'.$tariffa_commissioni]['commissioni_base']["$iddataini-$iddatafin"] = $comm_base;
+$dati_tariffe['tariffa'.$tariffa_commissioni]['commissioni_arrotond']["$iddataini-$iddatafin"] = risul_query($regole,$num1,'motivazione2');
 } # fine else if (!$iddataini)
-} # fine for $num2
-} # fine if ($tableregole)
-} # fine if (!$tariffa_sel or $tariffa_sel == $num1)
+} # fine if (strcmp($tariffa_commissioni,"") and (!$tariffa_sel or...
+$tariffa_chiusa = risul_query($regole,$num1,'tariffa_chiusa');
+if ($tariffa_chiusa and (!$tariffa_sel or $tariffa_sel == substr($tariffa_chiusa,7))) {
+$iddataini = risul_query($regole,$num1,'iddatainizio');
+$iddatafine = risul_query($regole,$num1,'iddatafine');
+for ($num2 = $iddataini ; $num2 <= $iddatafine ; $num2++) $dati_tariffe[$tariffa_chiusa]['chiusa'][$num2] = 1;
+} # fine if ($tariffa_chiusa and (!$tariffa_sel or...
 } # fine for $num1
+} # fine if ($tableregole)
 
 if ($tablepersonalizza) {
 global $id_utente;
