@@ -57,7 +57,7 @@ case "Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con cui mo
 case "Costo settimanale":  				$messaggio = "Weekly cost"; break;
 case "Costo unico":  				$messaggio = "Single cost"; break;
 case "Costo giornaliero":  				$messaggio = "Daily cost"; break;
-case "Motivazioni della regola di assegnazone 1 da tenere in conto":	$messaggio = "Motivations of rule 1 to consider"; break;
+case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivations of assignment rules 1 for conditional availability to consider"; break;
 case "nessuna":  				$messaggio = "no motivation"; break;
 case "comportati come se non vi fosse più disponibilità":	$messaggio = "Show that there is no more availability"; break;
 case "dai ancora disponibilità con questa frase alternativa":	$messaggio = "Show that there is still availability with this alternative phrase"; break;
@@ -288,6 +288,8 @@ case "Esempio di codice html per includere il primo passo della form in modalit
 case "selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla":	$messaggio = "select \"custom html\" in page appearance to modify it"; break;
 case "Categoria":  				$messaggio = "Category"; break;
 case "Attenzione":  				$messaggio = "Warning"; break;
+case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
+case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -543,6 +545,7 @@ case "var_fr_Data_di_arrivo":  			$messaggio = "var_phr_Arrival_date"; break;
 case "var_fr_Data_di_partenza":  		$messaggio = "var_phr_Departure_date"; break;
 case "var_fr_Tipologia":  			$messaggio = "var_phr_Type"; break;
 case "var_fr_Accetto":  			$messaggio = "var_phr_I_accept"; break;
+case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
 
