@@ -141,6 +141,11 @@ case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</
 case "Lingua":  				$messaggio = "Language"; break;
 case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
 case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
+case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
+case "Il campo":  				$messaggio = "The field"; break;
+case "verrà tolto":  				$messaggio = "will be deleted"; break;
+case "verrà modificato":  			$messaggio = "will be modified"; break;
+case "verrà aggiunto":  			$messaggio = "will be added"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
