@@ -341,6 +341,39 @@ case "città":  					$messaggio = "city"; break;
 case "indirizzo":  				$messaggio = "address"; break;
 case "codice postale":  			$messaggio = "postal code"; break;
 case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "The fields to be considered when searching clients have been changed"; break;
+case "Nome delle unità singole":  		$messaggio = "Name of single units"; break;
+case "Tabella dei messaggi":  			$messaggio = "Messages table"; break;
+case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "The number of rows of the messages table has been changed"; break;
+case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Download emails for availability enquiries from mail server"; break;
+case "per es.":  				$messaggio = "e.g."; break;
+case "Protocollo":  				$messaggio = "Protocol"; break;
+case "Porta":  					$messaggio = "Port"; break;
+case "default":  				$messaggio = "default"; break;
+case "persoalizzata":  				$messaggio = "custom"; break;
+case "Nome utente":  				$messaggio = "Username"; break;
+case "Password":  				$messaggio = "Password"; break;
+case "lasciare vuota per chiedere ogni volta":	$messaggio = "leave empty to ask each time"; break;
+case "Identificazione messaggi di richiesta":	$messaggio = "Enquiry messages identification"; break;
+case "Messaggio iniziale":  			$messaggio = "First post"; break;
+case "Qualsiasi messaggio":  			$messaggio = "Any post"; break;
+case "da":  					$messaggio = "from"; break;
+case "con oggetto contenete":  			$messaggio = "with subject containing"; break;
+case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "The data to download emails are wrong or incomplete"; break;
+case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "The download of emails for availability enquiries from mail server has been changed"; break;
+case "Colori delle prenotazioni":  		$messaggio = "Reservations colors"; break;
+case "Tutto pagato":  				$messaggio = "All paid"; break;
+case "Caparra pagata":  			$messaggio = "Deposit paid"; break;
+case "Confermate":  				$messaggio = "Confirmed"; break;
+case "Non confermate":  			$messaggio = "Not confirmed"; break;
+case "I colori sono sbagliati":  		$messaggio = "Colors are wrong"; break;
+case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Reservations colors have been changed"; break;
+case "Campi personalizzati dei clienti":  	$messaggio = "Custom fields for clients"; break;
+case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "New custom field for clients added"; break;
+case "Campo personalizzato dei clienti eliminato":	$messaggio = "Custom field for clients deleted"; break;
+case "tipo":  					$messaggio = "type"; break;
+case "booleano":  				$messaggio = "boolean"; break;
+case "testo":  					$messaggio = "text"; break;
+case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "The custom field contains not allowed characters"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
