@@ -106,7 +106,10 @@ case "Email":  					$messaggio = "Email"; break;
 case "Data_di_nascita":  			$messaggio = "Birthday"; break;
 case "2°telefono":  				$messaggio = "2nd phone"; break;
 case "Commento":  				$messaggio = "Comment"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 1 for"; break;
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 2 for"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 3 for"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 4 for"; break;
 case "La regola di assegnazione è stata cancellata":	$messaggio = "The assignment rule has been deleted"; break;
 case "La regola di assegnazione è già stata cancellata":	$messaggio = "The assignment rule has already been deleted"; break;
 case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Table with the assignment rules 1 of"; break;
@@ -166,7 +169,6 @@ case "Cliente":  				$messaggio = "Client"; break;
 case "cliente":  				$messaggio = "client"; break;
 case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Table with the assignment rules 3 of"; break;
 case "Utente":  				$messaggio = "User"; break;
-case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 3 for"; break;
 case "Periodi_permessi":  			$messaggio = "Permitted_periods"; break;
 case "unico":  					$messaggio = "single"; break;
 case "fisso":  					$messaggio = "fixed"; break;
@@ -218,7 +220,6 @@ case "Applica i cambiamenti":  			$messaggio = "Apply changes"; break;
 case "documento di tipo":  			$messaggio = "document type"; break;
 case "visualizza":  				$messaggio = "view"; break;
 case "Vedi tutte le prenotazioni":  		$messaggio = "View all reservations"; break;
-case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignment rule 4 for"; break;
 case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Table with the assignment rules 4 of"; break;
 case "Numero di persone":  			$messaggio = "Number of people"; break;
 case "assegna_se_":  				$messaggio = "assign_if_"; break;
@@ -349,6 +350,10 @@ case "password per le carte di credito":  	$messaggio = "password for credit car
 case "Cancellate":  				$messaggio = "Deleted"; break;
 case "carte di credito":  			$messaggio = "credit cards"; break;
 case "password errata":  			$messaggio = "wrong password"; break;
+case "Creare":  				$messaggio = "Create"; break;
+case "Aggiungi":  				$messaggio = "Add"; break;
+case "persona":  				$messaggio = "person"; break;
+case "chiusa":  				$messaggio = "closed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
