@@ -57,7 +57,7 @@ case "Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con cui mo
 case "Costo settimanale":  			$messaggio = "Coste semanal"; break;
 case "Costo unico":  				$messaggio = "Coste único"; break;
 case "Costo giornaliero":  			$messaggio = "Coste diario"; break;
-case "Motivazioni della regola di assegnazone 1 da tenere in conto":	$messaggio = "Motivaciones de la regla 1 a considerar"; break;
+case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivaciones de las reglas de asignación 1 para disponibilidad condicional a considerar"; break;
 case "nessuna":  				$messaggio = "ninguna"; break;
 case "comportati come se non vi fosse più disponibilità":	$messaggio = "Portate como si ya no hubiese disponibilidad"; break;
 case "dai ancora disponibilità con questa frase alternativa":	$messaggio = "Dí que todavía hay disponibilidad con esta frase alternativa"; break;
@@ -288,6 +288,8 @@ case "Esempio di codice html per includere il primo passo della form in modalit
 case "selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla":	$messaggio = "seleccionar \"html personalizado\" en el aspecto de la página para modificarla"; break;
 case "Categoria":  				$messaggio = "Categoría"; break;
 case "Attenzione":  				$messaggio = "Atención"; break;
+case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "las reglas 1 de cierre son aplicadas siempre"; break;
+case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "La tipología pedida está cerrada en este período"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -543,6 +545,7 @@ case "var_fr_Data_di_arrivo":  			$messaggio = "var_fr_Fecha_de_llegada"; break;
 case "var_fr_Data_di_partenza":  		$messaggio = "var_fr_Fecha_de_salida"; break;
 case "var_fr_Tipologia":  			$messaggio = "var_fr_Tipologia"; break;
 case "var_fr_Accetto":  			$messaggio = "var_fr_Acepto"; break;
+case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_fr_La_tipologia_pedida_esta_cerrada_en_este_periodo"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
 
