@@ -1,6 +1,6 @@
 <?php exit(); ?>
 
-<!--             2013-03-06 16:27:08             -->
+<!--             2013-12-30 21:53:01             -->
 
 <!--  **    SAVE THIS FILE AS hoteld_doc_backup.php     **  -->
 
@@ -14,11 +14,11 @@
 <nometabella>contratti</nometabella>
 <colonnetabella>
 <nomecolonna>numero</nomecolonna>
-<tipocolonna>int4</tipocolonna>
+<tipocolonna>3</tipocolonna>
 <nomecolonna>tipo</nomecolonna>
-<tipocolonna>varchar</tipocolonna>
+<tipocolonna>253</tipocolonna>
 <nomecolonna>testo</nomecolonna>
-<tipocolonna>text</tipocolonna>
+<tipocolonna>252</tipocolonna>
 </colonnetabella>
 <righetabella>
 <riga><cmp>1</cmp><cmp>vett2</cmp><cmp>iva_porc_vect_fact;num_iva_fact</cmp></riga>
@@ -73,6 +73,8 @@
 <riga><cmp>423</cmp><cmp>var2</cmp><cmp>ens_coste_tasa_fact</cmp></riga>
 <riga><cmp>424</cmp><cmp>var2</cmp><cmp>iva_fact</cmp></riga>
 <riga><cmp>425</cmp><cmp>var2</cmp><cmp>tot_costes_tasa_fact</cmp></riga>
+<riga><cmp>426</cmp><cmp>var2</cmp><cmp>ens_coste_como_tasas_fact</cmp></riga>
+<riga><cmp>427</cmp><cmp>var2</cmp><cmp>ens_subtotal_fact</cmp></riga>
 <riga><cmp>1</cmp><cmp>var</cmp><cmp>Mr</cmp></riga>
 <riga><cmp>3</cmp><cmp>var</cmp><cmp>il</cmp></riga>
 <riga><cmp>4</cmp><cmp>var</cmp><cmp>Il_</cmp></riga>
@@ -102,6 +104,9 @@ Saludos,
 
 [nombre_estructura]
 [sitio_web_estructura]
+
+
+[texto_citado_email_pedido]
 </cmp></riga>
 <riga><cmp>6</cmp><cmp>mln_es</cmp><cmp>Estimad[o] Señor[a] [apellido_ec],
 le confirmo que he reservado a su nombre un apartamento[c num_personas_tot!=""] para [num_personas_tot] personas[/c] para el período desde el [fecha_inicial] hasta el [fecha_final]. El precio para dicho período es de [coste_tot_p] [nombre_divisa] (incluyendo costes asociados). Para completar la reserva es necesario pagar por adelantado [fianza_p] [nombre_divisa], puede efectuar este pago siguiendo este enlace:
@@ -137,6 +142,9 @@ Best regards,
 
 [structure_name]
 [structure_website]
+
+
+[enquiry_email_quoted_text]
 </cmp></riga>
 <riga><cmp>6</cmp><cmp>mln_en</cmp><cmp>Dear Mr[Mr] [apellido_ec],
 I confirm you that I have reserved you an apartment[c people_num_tot!=""] for [people_num_tot] people[/c] in the period from [starting_date] to [ending_date]. The price for this period is [price_tot_p] [currency_name] (including cleaning and utilities). In order to complete the reservation you must send a down-payment of [deposit_p] [currency_name], you can pay it following this link:
@@ -267,8 +275,11 @@ Best regards,
 [r3][c ens_coste_agn_fact="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
 \pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Extra: \'93[nombre_coste_agna]\'94}
 \cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [coste_agn_no_iva_fact_p]}
+[/c][c ens_coste_como_tasas_fact="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
+\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Tasa: \'93[nombre_coste_agna]\'94}
+\cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [tasas_coste_agna_p]}
 [/c][/r3][/r]
-[c max_num_iva_fact!="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
+[c ens_subtotal_fact="1"]\cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
 \pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Imponible al [iva_porc_vect_fact(num_iva_fact)]%}
 \cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [tot_parc_no_iva_fact_p]}
 \cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
@@ -282,7 +293,7 @@ Best regards,
 \pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Total Imponible}
 \cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [tot_no_iva_fact_p]}
 \cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
-\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Total Iva[c num_iva_fact="1"] al [iva_porc_vect_fact(num_iva_fact)]%[/c]}
+\pard\intbl\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\ql\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 Total Impuestos[c num_iva_fact="1"] al [iva_porc_vect_fact(num_iva_fact)]%[/c]}
 \cell\pard\plain \intbl\ltrpar\s1{\*\hyphen2\hyphlead2\hyphtrail2\hyphmax0}\qr\rtlch\af1\afs24\lang255\ltrch\dbch\af1\langfe255\hich\f1\fs24\lang1040\loch\f1\fs24\lang1040 {\rtlch \ltrch\loch\f1\fs24\lang1040\i0\b0 [nombre_divisa] [iva_fact_p]}
 [r][r3][c ens_coste_tasa_fact="1"]
 \cell\row\pard \trowd\trql\trleft276\trpaddft3\trpaddt55\trpaddfl3\trpaddl55\trpaddfb3\trpaddb55\trpaddfr3\trpaddr55\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clcbpat2\cellx7792\clbrdrl\brdrs\brdrw1\brdrcf1\clbrdrb\brdrs\brdrw1\brdrcf1\clbrdrr\brdrs\brdrw1\brdrcf1\clcbpat2\clvertalb\cellx9637
@@ -467,8 +478,10 @@ Factura n. [numero_progresivo_documento] del [hoy]
 [/c]
 [r3][c ens_coste_agn_fact="1"]<tr><td style="border-color: black;">Extra: "[nombre_coste_agna]"</td>
 <td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [coste_agn_no_iva_fact_p]</td></tr>
+[/c][c ens_coste_como_tasas_fact="1"]<tr><td style="border-color: black;">Tasa: "[nombre_coste_agna]"</td>
+<td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tasas_coste_agna_p]</td></tr>
 [/c][/r3][/r]
-[c max_num_iva_fact!="1"]<tr><td style="border-color: black;">Imponible al [iva_porc_vect_fact(num_iva_fact)]%</td>
+[c ens_subtotal_fact="1"]<tr><td style="border-color: black;">Imponible al [iva_porc_vect_fact(num_iva_fact)]%</td>
 <td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tot_parc_no_iva_fact_p]</td></tr>
 <tr><td style="border-color: black;">Iva al [iva_porc_vect_fact(num_iva_fact)]%</td>
 <td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tot_parc_iva_fact_p]</td></tr>
@@ -479,7 +492,7 @@ Factura n. [numero_progresivo_documento] del [hoy]
 <table class="imponible_factura" border="1" cellpadding="5" style="border: 1px black solid; width: 740px; margin-left: auto; margin-right: 5px; margin-top: 8px; border-collapse: collapse; background-color: #e6e6e6;">
 <tr><td style="border-color: black;">Total Imponible</td>
 <td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [tot_no_iva_fact_p]</td></tr>
-<tr><td style="border-color: black;">Total Iva[c num_iva_fact="1"] al [iva_porc_vect_fact(num_iva_fact)]%[/c]</td>
+<tr><td style="border-color: black;">Total Impuestos[c num_iva_fact="1"] al [iva_porc_vect_fact(num_iva_fact)]%[/c]</td>
 <td style="width: 120px; text-align: right; border-color: black;">[nombre_divisa] [iva_fact_p]</td></tr>
 [r][r3][c ens_coste_tasa_fact="1"]
 <tr><td style="border-color: black;">[nombre_coste_agna]</td>
@@ -536,96 +549,103 @@ Factura n. [numero_progresivo_documento] del [hoy]
 <riga><cmp>27</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?410#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>30</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?ens_tarifa_fact#%?=#%?txt#%?1#$?sconto#%?!=#%?txt#%?0#@?set#%?410#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>31</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?411#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>32</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?423#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>36</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nome_costo_agg#%?=#%?var#%?nombre_coste_tasa_fact#@?set#%?423#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>38</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?iva_porc_vect_fact(num_iva_fact)#%?=#%?var#%?percentuale_tasse_costo_agg#$?valore_costo_agg#%?!=#%?txt#%?0#$?num_ripeticion_fact#%?>#%?txt#%?1#$?ens_coste_tasa_fact#%?!=#%?txt#%?1#@?set#%?411#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>39</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_tariffa#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>40</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?var_tmp_fact#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>42</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?iva_porc_exist_fact(var_tmp_fact)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
-<riga><cmp>43</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?num_iva_fact#%?+#%?txt#%?1#%?</cmp></riga>
-<riga><cmp>44</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?num_iva_fact#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>46</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?var_tmp_fact#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>48</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>52</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
-<riga><cmp>60</cmp><cmp>cond2</cmp><cmp>rpt#@?or#$?valore_costo_agg#%?=#%?txt#%?0#$?valore_costo_agg#%?=#%?txt#%?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
-<riga><cmp>61</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>65</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?var_tmp_fact#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>75</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?iva_porc_exist_fact(var_tmp_fact)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
-<riga><cmp>76</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?num_iva_fact#%?+#%?txt#%?1#%?</cmp></riga>
-<riga><cmp>81</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?num_iva_fact#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>83</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?var_tmp_fact#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>84</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>86</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
-<riga><cmp>87</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?351#%?valore_costo_agg_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>88</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?oper#%?351#%?valore_costo_agg#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>89</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?342#%?=#%?var#%?nome_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>90</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
-<riga><cmp>91</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
-<riga><cmp>95</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?+#%?var#%?tasse_costo_agg#%?</cmp></riga>
-<riga><cmp>100</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?oper#%?425#%?tot_costes_tasa_fact#%?+#%?var#%?valore_costo_agg#%?</cmp></riga>
-<riga><cmp>103</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>105</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?tot_parc_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>106</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?tot_parc_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>108</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?coste_tot_fact#%?-#%?var#%?tot_no_iva_fact#%?</cmp></riga>
-<riga><cmp>110</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?iva_fact#%?-#%?var#%?tot_costes_tasa_fact#%?</cmp></riga>
-<riga><cmp>111</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>112</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ultima_reserva_fact#%?=#%?var#%?numero_prenotazione#@?break#%?</cmp></riga>
-<riga><cmp>113</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?339#%?=#%?var#%?numero_prenotazione#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>114</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
-<riga><cmp>115</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
-<riga><cmp>116</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?+#%?var#%?tasse_tariffa#%?</cmp></riga>
-<riga><cmp>117</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
-<riga><cmp>118</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
-<riga><cmp>119</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?-#%?var#%?tasse_sconto#%?</cmp></riga>
-<riga><cmp>120</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?353#%?costo_tariffa_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>121</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?352#%?sconto_senza_tasse#%?*#%?txt#%?-1#%?</cmp></riga>
-<riga><cmp>122</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>123</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?tot_parc_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>124</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?tot_parc_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>125</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?coste_tot_fact#%?-#%?var#%?tot_no_iva_fact#%?</cmp></riga>
-<riga><cmp>126</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?iva_fact#%?-#%?var#%?tot_costes_tasa_fact#%?</cmp></riga>
-<riga><cmp>128</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>129</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?une_descuento_a_tarifa#%?=#%?txt#%?SI#@?oper#%?353#%?costo_tariffa_senza_tasse#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
-<riga><cmp>130</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?une_descuento_a_tarifa#%?=#%?txt#%?SI#@?set#%?410#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>131</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?418#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>132</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?num_persone_tot#%?!=#%?txt#%?#$?num_persone_tot#%?!=#%?txt#%?0#@?set#%?418#%?=#%?txt#%? para x personas#%?txt#%?x#%?var#%?num_persone_tot</cmp></riga>
-<riga><cmp>133</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?num_ripeticion_fact#%?>#%?txt#%?1#@?break#%?</cmp></riga>
-<riga><cmp>134</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?347#%?coste_tot_fact#%?+#%?var#%?costo_tot#%?</cmp></riga>
-<riga><cmp>135</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?348#%?coste_tot_fact#%?+#%?txt#%?0#%?</cmp></riga>
-<riga><cmp>136</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?=#%?txt#%?- N.I.F. #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>137</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?.=#%?var#%?codice_fiscale_struttura#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>138</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?=#%?txt#%?Tel. #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>139</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?telefono_struttura#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>140</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?339#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>141</cmp><cmp>cond2</cmp><cmp>inr#@?#@?oper#%?412#%?num_ripeticion_fact#%?+#%?txt#%?1#%?</cmp></riga>
-<riga><cmp>142</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?419#%?=#%?txt#%?SI#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>143</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?422#%?=#%?txt#%?nombre del coste a cosiderar como tasa#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>144</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?347#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>145</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?telefono_struttura#%?!=#%?txt#%?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?txt#%? - #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>146</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?sito_web_struttura#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>147</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?343#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>148</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?331#%?=#%?var#%?nome#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>149</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?332#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>150</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?=#%?txt#%?, #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>151</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?.=#%?var#%?numcivico#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>152</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?citta#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?citta#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>153</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%? (#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>154</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?regione#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>155</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%?)#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>156</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>157</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>158</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>159</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?405#%?=#%?var#%?partita_iva#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>160</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?406#%?=#%?var#%?codice_fiscale#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>161</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?407#%?=#%?var#%?via#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>162</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?408#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>163</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?412#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>164</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?413#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>165</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?414#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>166</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?=#%?txt#%?<img src="#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>167</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?var#%?logo_struttura#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>168</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?txt#%?" alt="Logo" style="float: right;">#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>169</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?425#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>32</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?426#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>36</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?427#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>38</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?423#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>39</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nome_costo_agg#%?=#%?var#%?nombre_coste_tasa_fact#@?set#%?423#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>40</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?iva_porc_vect_fact(num_iva_fact)#%?=#%?var#%?percentuale_tasse_costo_agg#$?valore_costo_agg#%?!=#%?txt#%?0#$?num_ripeticion_fact#%?>#%?txt#%?1#$?ens_coste_tasa_fact#%?!=#%?txt#%?1#@?set#%?411#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>42</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_tariffa#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>43</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?var_tmp_fact#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>44</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?iva_porc_exist_fact(var_tmp_fact)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
+<riga><cmp>46</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?num_iva_fact#%?+#%?txt#%?1#%?</cmp></riga>
+<riga><cmp>48</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?num_iva_fact#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>52</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?var_tmp_fact#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>60</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>61</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
+<riga><cmp>65</cmp><cmp>cond2</cmp><cmp>rpt#@?or#$?valore_costo_agg#%?=#%?txt#%?0#$?valore_costo_agg#%?=#%?txt#%?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
+<riga><cmp>75</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?336#%?=#%?var#%?percentuale_tasse_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>76</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?var_tmp_fact#%?=#%?txt#%?#@?set#%?336#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>81</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?iva_porc_exist_fact(var_tmp_fact)#%?=#%?txt#%?1#@?break#%?cont</cmp></riga>
+<riga><cmp>83</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?408#%?num_iva_fact#%?+#%?txt#%?1#%?</cmp></riga>
+<riga><cmp>84</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?417#%?=#%?var#%?num_iva_fact#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>86</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a1#%?=#%?var#%?var_tmp_fact#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>87</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?a2#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>88</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
+<riga><cmp>89</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?351#%?valore_costo_agg_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>90</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?oper#%?351#%?valore_costo_agg#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>91</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?342#%?=#%?var#%?nome_costo_agg#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>95</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
+<riga><cmp>100</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?+#%?var#%?valore_costo_agg_senza_tasse#%?</cmp></riga>
+<riga><cmp>103</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?+#%?var#%?tasse_costo_agg#%?</cmp></riga>
+<riga><cmp>105</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_coste_tasa_fact#%?=#%?txt#%?1#@?oper#%?425#%?tot_costes_tasa_fact#%?+#%?var#%?valore_costo_agg#%?</cmp></riga>
+<riga><cmp>106</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>108</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?tot_parc_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>110</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?tot_parc_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>111</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?coste_tot_fact#%?-#%?var#%?tot_no_iva_fact#%?</cmp></riga>
+<riga><cmp>112</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?iva_fact#%?-#%?var#%?tot_costes_tasa_fact#%?</cmp></riga>
+<riga><cmp>113</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>114</cmp><cmp>cond2</cmp><cmp>rpt#@?or#$?ens_coste_agn_fact#%?!=#%?txt#%?1#$?percentuale_tasse_costo_agg#%?!=#%?txt#%?-1#@?break#%?cont</cmp></riga>
+<riga><cmp>115</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?426#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>116</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?411#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>117</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?cont</cmp></riga>
+<riga><cmp>118</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?max_num_iva_fact#%?!=#%?txt#%?1#$?ens_coste_agn_fact#%?=#%?txt#%?1#@?set#%?427#%?=#%?txt#%?1#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>119</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ultima_reserva_fact#%?=#%?var#%?numero_prenotazione#@?break#%?</cmp></riga>
+<riga><cmp>120</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?339#%?=#%?var#%?numero_prenotazione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>121</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
+<riga><cmp>122</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?+#%?var#%?costo_tariffa_senza_tasse#%?</cmp></riga>
+<riga><cmp>123</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_tarifa_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?+#%?var#%?tasse_tariffa#%?</cmp></riga>
+<riga><cmp>124</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?343#%?tot_no_iva_fact#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
+<riga><cmp>125</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?413#%?tot_parc_no_iva_fact#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
+<riga><cmp>126</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?ens_descuento_fact#%?=#%?txt#%?1#@?oper#%?414#%?tot_parc_iva_fact#%?-#%?var#%?tasse_sconto#%?</cmp></riga>
+<riga><cmp>128</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?353#%?costo_tariffa_senza_tasse#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>129</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?352#%?sconto_senza_tasse#%?*#%?txt#%?-1#%?</cmp></riga>
+<riga><cmp>130</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?350#%?tot_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>131</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?415#%?tot_parc_no_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>132</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?416#%?tot_parc_iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>133</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?coste_tot_fact#%?-#%?var#%?tot_no_iva_fact#%?</cmp></riga>
+<riga><cmp>134</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?424#%?iva_fact#%?-#%?var#%?tot_costes_tasa_fact#%?</cmp></riga>
+<riga><cmp>135</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?349#%?iva_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>136</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?une_descuento_a_tarifa#%?=#%?txt#%?SI#@?oper#%?353#%?costo_tariffa_senza_tasse#%?-#%?var#%?sconto_senza_tasse#%?</cmp></riga>
+<riga><cmp>137</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?une_descuento_a_tarifa#%?=#%?txt#%?SI#@?set#%?410#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>138</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?418#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>139</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?num_persone_tot#%?!=#%?txt#%?#$?num_persone_tot#%?!=#%?txt#%?0#@?set#%?418#%?=#%?txt#%? para x personas#%?txt#%?x#%?var#%?num_persone_tot</cmp></riga>
+<riga><cmp>140</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?num_ripeticion_fact#%?>#%?txt#%?1#@?break#%?</cmp></riga>
+<riga><cmp>141</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?347#%?coste_tot_fact#%?+#%?var#%?costo_tot#%?</cmp></riga>
+<riga><cmp>142</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?oper#%?348#%?coste_tot_fact#%?+#%?txt#%?0#%?</cmp></riga>
+<riga><cmp>143</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?=#%?txt#%?- N.I.F. #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>144</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?codice_fiscale_struttura#%?!=#%?txt#%?#@?set#%?330#%?.=#%?var#%?codice_fiscale_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>145</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?=#%?txt#%?Tel. #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>146</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?telefono_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?telefono_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>147</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?339#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>148</cmp><cmp>cond2</cmp><cmp>inr#@?#@?oper#%?412#%?num_ripeticion_fact#%?+#%?txt#%?1#%?</cmp></riga>
+<riga><cmp>149</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?419#%?=#%?txt#%?SI#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>150</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?422#%?=#%?txt#%?nombre del coste a cosiderar como tasa#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>151</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?347#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>152</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?telefono_struttura#%?!=#%?txt#%?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?txt#%? - #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>153</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?sito_web_struttura#%?!=#%?txt#%?#@?set#%?333#%?.=#%?var#%?sito_web_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>154</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?343#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>155</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?331#%?=#%?var#%?nome#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>156</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?332#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>157</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?=#%?txt#%?, #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>158</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?.=#%?var#%?numcivico#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>159</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?citta#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?citta#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>160</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%? (#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>161</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?regione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>162</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%?)#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>163</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>164</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>165</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>166</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?405#%?=#%?var#%?partita_iva#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>167</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?406#%?=#%?var#%?codice_fiscale#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>168</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?407#%?=#%?var#%?via#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>169</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?408#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>170</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?412#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>171</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?413#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>172</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?414#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>173</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?=#%?txt#%?<img src="#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>174</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?var#%?logo_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>175</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?txt#%?" alt="Logo" style="float: right;">#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>176</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?425#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>1</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?1#%?=#%?txt#%?s#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>3</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?il#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>4</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?la#%?txt#%?#%?txt#%?</cmp></riga>
