@@ -32,6 +32,27 @@ case "Messaggi eliminati":  			$messaggio = "Mensajes eliminados"; break;
 case "arrivati":  				$messaggio = "llegados"; break;
 case "prima del":  				$messaggio = "antes del"; break;
 case "dopo il":  				$messaggio = "después del"; break;
+case "Scarica messaggi email":  		$messaggio = "Descargar mensajes email"; break;
+case "Nessun nuovo messaggio":  		$messaggio = "Ningún mensaje nuevo"; break;
+case "Nuovi messaggi":  			$messaggio = "Nuevos mensajes"; break;
+case "Scaricati":  				$messaggio = "Descargados"; break;
+case "Connessione al server":  			$messaggio = "La conexión al servidor"; break;
+case "non riuscita!":  				$messaggio = "ha sido rechazada!"; break;
+case "Controllare i dati immessi in \"configura e personalizza\"":	$messaggio = "Controlar los datos insertados en \"configurar y personalizar\""; break;
+case "Dati ricavati dal messaggio email":  	$messaggio = "Datos extraídos del mensaje email"; break;
+case "Controlla disponibilità":  		$messaggio = "Controlar disponibilidad"; break;
+case "Nome":  					$messaggio = "Nombre"; break;
+case "Email":  					$messaggio = "Email"; break;
+case "arrivo":  				$messaggio = "llegada"; break;
+case "partenza":  				$messaggio = "salida"; break;
+case "notti":  					$messaggio = "noches"; break;
+case "persone":  				$messaggio = "personas"; break;
+case "individui":  				$messaggio = "individuos"; break;
+case "ospiti":  				$messaggio = "huéspedes"; break;
+case "adulti":  				$messaggio = "adultos"; break;
+case "bambini":  				$messaggio = "niños"; break;
+case "gruppo":  				$messaggio = "grupo"; break;
+case "Modifica":  				$messaggio = "Modificar"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
