@@ -143,6 +143,11 @@ case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "El <b>apodo</b> s
 case "Lingua":  				$messaggio = "Idioma"; break;
 case "La lingua verrà cambiata da":  		$messaggio = "El idioma será cambiado de"; break;
 case "La <b>lingua</b> verrà cancellata":  	$messaggio = "El <b>idioma</b> será borrado"; break;
+case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Los datos de la tarjeta de crédito pueden ser vistos solo através de una conexión segura"; break;
+case "Il campo":  				$messaggio = "El campo"; break;
+case "verrà tolto":  				$messaggio = "será eliminado"; break;
+case "verrà modificato":  			$messaggio = "será modificado"; break;
+case "verrà aggiunto":  			$messaggio = "será añadido"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
