@@ -340,7 +340,40 @@ case "telefono":  				$messaggio = "teléfono"; break;
 case "città":  					$messaggio = "ciudad"; break;
 case "indirizzo":  				$messaggio = "dirección"; break;
 case "codice postale":  			$messaggio = "código postal"; break;
-case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = ""; break;
+case "I campi da considerare per la ricerca dei clienti sono stati cambiati":	$messaggio = "Los campos a considerar para la búsqueda de los clientes han sido cambiados"; break;
+case "Nome delle unità singole":  		$messaggio = "Nombre de las unidades individuales"; break;
+case "Tabella dei messaggi":  			$messaggio = "Tabla de los mensajes"; break;
+case "Il numero di righe della tabella dei messaggi è stato cambiato":	$messaggio = "El número de líneas de la tabla con los mensajes ha sido cambiado"; break;
+case "Scarica le email di richiesta disponibiltà dal server di posta":	$messaggio = "Decargar los emails de pedido disponibilidad desde el servidor de correo"; break;
+case "per es.":  				$messaggio = "por ej."; break;
+case "Protocollo":  				$messaggio = "Protocolo"; break;
+case "Porta":  					$messaggio = "Puerta"; break;
+case "default":  				$messaggio = "predefinida"; break;
+case "persoalizzata":  				$messaggio = "personalizada"; break;
+case "Nome utente":  				$messaggio = "Nombre de usuario"; break;
+case "Password":  				$messaggio = "Contraseña"; break;
+case "lasciare vuota per chiedere ogni volta":	$messaggio = "dejar vacio para preguntar cada vez"; break;
+case "Identificazione messaggi di richiesta":	$messaggio = "Indentificaciòn de los mensajes de pedido"; break;
+case "Messaggio iniziale":  			$messaggio = "Mensaje inicial"; break;
+case "Qualsiasi messaggio":  			$messaggio = "Qualquier mensaje"; break;
+case "da":  					$messaggio = "desde"; break;
+case "con oggetto contenete":  			$messaggio = "con asunto que contenga"; break;
+case "I dati per lo scaricamento delle email sono sbagliati o incompleti":	$messaggio = "Los datos para descargar los emails son equivocados o incompletos"; break;
+case "Lo scaricamento delle email di richiesta disponibiltà dal server di posta è stato cambiato":	$messaggio = "La Decarga de los emails de pedido disponibilidad desde el servidor de correo a sido cambiada"; break;
+case "Colori delle prenotazioni":  		$messaggio = "Colores de las reservas"; break;
+case "Tutto pagato":  				$messaggio = "Todo pagado"; break;
+case "Caparra pagata":  			$messaggio = "Fianza pagada"; break;
+case "Confermate":  				$messaggio = "Confirmadas"; break;
+case "Non confermate":  			$messaggio = "No confirmadas"; break;
+case "I colori sono sbagliati":  		$messaggio = "Los colores están equivocados"; break;
+case "I colori delle prenotazioni sono stati cambiati":	$messaggio = "Los colores de las reservas han sido cambiados"; break;
+case "Campi personalizzati dei clienti":  	$messaggio = "Campos personalizados de los clientes"; break;
+case "Nuovo campo personalizzato dei clienti aggiunto":	$messaggio = "Nuevo campos personalizado para los clientes añadido"; break;
+case "Campo personalizzato dei clienti eliminato":	$messaggio = "Campos personalizado para los clientes eliminado"; break;
+case "tipo":  					$messaggio = "tipo"; break;
+case "booleano":  				$messaggio = "booleano"; break;
+case "testo":  					$messaggio = "texto"; break;
+case "Il campo personalizzato contiene caratteri non consentiti":	$messaggio = "El campo personalizado contiene caracteres no consentidos"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
