@@ -256,6 +256,8 @@ $trad_var['codice_fiscale_struttura'] = 'num_identificacion_fiscal_estructura';
 $trad_var['partita_iva_struttura'] = 'certificado_identificacion_fiscal_estructura';
 $trad_var['numero_stelle_struttura'] = 'numero_estrellas_estructura';
 $trad_var['logo_struttura'] = 'logo_estructura';
+$trad_var['testo_email_richiesta'] = 'texto_email_pedido';
+$trad_var['testo_quotato_email_richiesta'] = 'texto_citado_email_pedido';
 $trad_var['nome_valuta'] = 'nombre_divisa';
 $trad_var['ritorno_a_capo'] = 'carriage_return';
 $trad_var['avanzamento_riga'] = 'new_line';
@@ -263,6 +265,7 @@ $trad_var['errore_ripetizione'] = 'error_repeticion';
 $trad_var['messaggio_di_errore'] = 'mensaje_de_error';
 $trad_var['codice_lingua'] = 'codigo_idioma';
 $trad_var['email_inviata'] = 'email_ya_enviada';
+$trad_var['campo_personalizzato'] = 'campo_personalizado';
 
 
 ?>
\ No newline at end of file
