@@ -106,7 +106,10 @@ case "Email":  					$messaggio = "Correo electrónico"; break;
 case "Data_di_nascita":  			$messaggio = "Fecha_de_nacimiento"; break;
 case "2°telefono":  				$messaggio = "2° teléfono"; break;
 case "Commento":  				$messaggio = "Comentario"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 1 para la"; break;
 case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 2 para la"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 3 para la"; break;
+case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 4 para la"; break;
 case "La regola di assegnazione è stata cancellata":	$messaggio = "La regla de asignación ha sido borrada"; break;
 case "La regola di assegnazione è già stata cancellata":	$messaggio = "La regla de asignación había sido ya borrada"; break;
 case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Tabla con las reglas de asignación 1 del"; break;
@@ -167,7 +170,6 @@ case "Cliente":  				$messaggio = "Cliente"; break;
 case "cliente":  				$messaggio = "cliente"; break;
 case "Tabella con le regole di assegnazione 3 del":	$messaggio = "Tabla con las reglas de asignación 3 del"; break;
 case "Utente":  				$messaggio = "Usuario"; break;
-case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 3 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 3 para la"; break;
 case "Periodi_permessi":  			$messaggio = "Periodos_permitidos"; break;
 case "unico":  					$messaggio = "único"; break;
 case "fisso":  					$messaggio = "fijo"; break;
@@ -219,7 +221,6 @@ case "Applica i cambiamenti":  			$messaggio = "Aplicar los cambios"; break;
 case "documento di tipo":  			$messaggio = "documento tipo"; break;
 case "visualizza":  				$messaggio = "Ver"; break;
 case "Vedi tutte le prenotazioni":  		$messaggio = "Mirar todas las reservas"; break;
-case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 4 per la":	$messaggio = "Estás seguro de querer <b>borrar</b> la regla de asignación 4 para la"; break;
 case "Tabella con le regole di assegnazione 4 del":	$messaggio = "Tabla con las reglas de asignación 4 del"; break;
 case "Numero di persone":  			$messaggio = "Número de personas"; break;
 case "assegna_se_":  				$messaggio = "asignar_con_"; break;
@@ -350,6 +351,10 @@ case "password per le carte di credito":  	$messaggio = "contraseña para las ta
 case "Cancellate":  				$messaggio = "Borradas"; break;
 case "carte di credito":  			$messaggio = "tarjetas de crédito"; break;
 case "password errata":  			$messaggio = "contraseña equivocada"; break;
+case "Creare":  				$messaggio = "Crear"; break;
+case "Aggiungi":  				$messaggio = "Añadir"; break;
+case "persona":  				$messaggio = "persona"; break;
+case "chiusa":  				$messaggio = "cerrada"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
