@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -200,14 +200,14 @@ echo "</tr>";
 } # fine if ($celle != 1)
 echo "</table><br>";
 
-echo "".mex("Motivazioni della regola di assegnazone 1 da tenere in conto",$pag).":<br>
+echo "".mex("Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto",$pag).":<br>
 <table style=\"margin-left: auto; margin-right: auto;\" border=\"1\" cellspacing=\"0\" cellpadding=\"4\">";
 $celle = 1;
 $num_colonne = 3;
 $tableregole_modello = $PHPR_TAB_PRE."regole".$anno_modello;
-$regole = esegui_query("select * from $tableregole_modello where app_agenzia != '' order by app_agenzia");
+$regole = esegui_query("select * from $tableregole_modello where app_agenzia != '' and (motivazione2 != 'x' or motivazione2 is NULL) order by app_agenzia");
 $num_regole = numlin_query($regole);
-$motivazioni_presenti = "";
+unset($motivazioni_presenti);
 $num_motivazioni = 0;
 for ($num1 = 0 ; $num1 < $num_regole ; $num1 = $num1 + 1) {
 if ($celle == 1) echo "<tr>";
@@ -237,7 +237,8 @@ for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
 echo "</tr>";
 } # fine if ($celle != 1)
 elseif ($num_regole == 0) echo "<tr><td style=\"width: 250px;\">&nbsp;</td></tr>";
-echo "</table><br>
+echo "</table>
+<div style=\"font-size: smaller; text-align: center;\">(".mex("le regole 1 di chiusura vengono sempre applicate",$pag).")</div><br>
 <input type=\"hidden\" name=\"num_motivazioni\" value=\"$num_motivazioni\">";
 
 $dati_struttura = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'dati_struttura' and idutente = '$id_utente'");
@@ -283,8 +284,8 @@ for ($num2 = 1 ; $num2 <= $num_colori ; $num2++) {
 $colore_corr = $colori_tema[$num2]['default'];
 if ($sel and ${"colore_tema_".$num2}) $colore_corr = ${"colore_tema_".$num2};
 $js_opz_tema .= "".mex("Colore del tema",$pag)." \"".$template_theme_name[$num1]."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
- <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltema$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_col_tema_txt($num2)\">\\
-<select id=\"colsel$num2\" onchange=\"agg_col_tema($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
+ <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltxt$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_colore_sel_txt($num2)\">\\
+<select id=\"colsel$num2\" onchange=\"agg_colore_sel($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
 } # fine for $num2
 $valori_tema = $template_theme_values[$num1];
 $num_valori = count($valori_tema);
@@ -346,12 +347,6 @@ options_colori = '<option value=\"#ffffff\" style=\"background-color: #ffffff;\"
 <option value=\"#999999\" style=\"background-color: #999999;\">&nbsp;<\/option>\\
 <option value=\"#000000\" style=\"background-color: #000000;\">&nbsp;<\/option>\\
 ';
-function agg_col_tema (ncol) {
-var sel = document.getElementById('colsel'+ncol);
-var colsel = sel.options[sel.selectedIndex].value;
-document.getElementById('coltema'+ncol).value = colsel;
-sel.style.backgroundColor = colsel;
-}
 function agg_tema_sel () {
 var tema_sel = document.getElementById('tema_sel').selectedIndex;
 tema_sel = document.getElementById('tema_sel').options[tema_sel].value;
@@ -372,13 +367,6 @@ txt_html_nota.innerHTML = '';
 opz_tema.innerHTML = '';
 }
 }
-function agg_col_tema_txt (ncol) {
-var sel = document.getElementById('colsel'+ncol);
-var colsel = document.getElementById('coltema'+ncol).value;
-var colre1 = new RegExp('^#[0-9a-f]{3,3}$','i');
-var colre2 = new RegExp('^#[0-9a-f]{6,6}$','i');
-if (colre1.test(colsel) || colre2.test(colsel)) sel.style.backgroundColor = colsel;
-}
 agg_tema_sel();
 -->
 </script>
