@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -279,9 +279,9 @@ else $mostra_numero_liberi_quadro_disponibilita = "NO";
 
 global $num_motivazioni;
 $tableregole_modello = $PHPR_TAB_PRE."regole".$anno_modello;
-$regole = esegui_query("select * from $tableregole_modello where app_agenzia != '' order by app_agenzia");
+$regole = esegui_query("select * from $tableregole_modello where app_agenzia != '' and (motivazione2 != 'x' or motivazione2 is NULL) order by app_agenzia");
 $num_regole = numlin_query($regole);
-$motivazioni_presenti = "";
+$motivazioni_presenti = array();
 $num_motivazioni = 0;
 for ($num1 = 0 ; $num1 < $num_regole ; $num1 = $num1 + 1) {
 $idregole = risul_query($regole,$num1,'idregole');
@@ -615,7 +615,7 @@ else $cost_percorso_a_dati = "./";
 
 if ($template_file_name[$lingua_modello]) $nome_file = $template_file_name[$lingua_modello];
 else {
-$template_file_name_m = mext_cal($template_file_name['ita'],$pag);
+$template_file_name_m = mext_cal($template_file_name['ita'],$pag,$lingua_modello);
 if ($template_file_name_m != $template_file_name['ita'] and $template_file_name_m != $template_file_name['en'] and $template_file_name_m != $template_file_name['es']) $nome_file = $template_file_name_m;
 else $nome_file = $lingua_modello."_".$template_file_name['en'];
 } # fine else if ($template_file_name[$lingua_modello])
@@ -803,6 +803,7 @@ fwrite($file,"
 includi_file("./includes/funzioni.php",$file);
 includi_file(C_DATI_PATH."/versione.php",$file);
 includi_file("./includes/liberasettimane.php",$file);
+includi_file("./includes/funzioni_tariffe.php",$file);
 includi_file("./includes/funzioni_quadro_disp.php",$file);
 if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") {
 $f_scad_acc = explode("/",$percorso_cartella_modello);
