@@ -260,8 +260,8 @@ for ($num2 = 1 ; $num2 <= $num_colori ; $num2++) {
 $colore_corr = $colori_tema[$num2]['default'];
 if ($sel and ${"colore_tema_".$num2}) $colore_corr = ${"colore_tema_".$num2};
 $js_opz_tema .= "".mex("Colore del tema",$pag)." \"".$template_theme_name[$num1]."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
- <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltema$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_col_tema_txt($num2)\">\\
-<select id=\"colsel$num2\" onchange=\"agg_col_tema($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
+ <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltxt$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_colore_sel_txt($num2)\">\\
+<select id=\"colsel$num2\" onchange=\"agg_colore_sel($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
 } # fine for $num2
 $valori_tema = $template_theme_values[$num1];
 $num_valori = count($valori_tema);
@@ -323,12 +323,6 @@ options_colori = '<option value=\"#ffffff\" style=\"background-color: #ffffff;\"
 <option value=\"#999999\" style=\"background-color: #999999;\">&nbsp;<\/option>\\
 <option value=\"#000000\" style=\"background-color: #000000;\">&nbsp;<\/option>\\
 ';
-function agg_col_tema (ncol) {
-var sel = document.getElementById('colsel'+ncol);
-var colsel = sel.options[sel.selectedIndex].value;
-document.getElementById('coltema'+ncol).value = colsel;
-sel.style.backgroundColor = colsel;
-}
 function agg_tema_sel () {
 var tema_sel = document.getElementById('tema_sel').selectedIndex;
 tema_sel = document.getElementById('tema_sel').options[tema_sel].value;
@@ -349,13 +343,6 @@ txt_html_nota.innerHTML = '';
 opz_tema.innerHTML = '';
 }
 }
-function agg_col_tema_txt (ncol) {
-var sel = document.getElementById('colsel'+ncol);
-var colsel = document.getElementById('coltema'+ncol).value;
-var colre1 = new RegExp('^#[0-9a-f]{3,3}$','i');
-var colre2 = new RegExp('^#[0-9a-f]{6,6}$','i');
-if (colre1.test(colsel) || colre2.test(colsel)) sel.style.backgroundColor = colsel;
-}
 agg_tema_sel();
 -->
 </script>
