@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -119,12 +119,12 @@ $num_periodi_date++;
 
 
 $tabelle_lock = "";
-$altre_tab_lock = array("$tableperiodi","$tablenometariffe");
+$altre_tab_lock = array($tablenometariffe,$tableperiodi,$tableregole);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 $periodi = esegui_query("select * from $tableperiodi order by idperiodi");
 $rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 or idntariffe = 2 order by idntariffe ");
-$dati_tariffe = dati_tariffe($tablenometariffe);
+$dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
 $dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO");
 
 unlock_tabelle($tabelle_lock);
@@ -152,8 +152,9 @@ else $per_persona[$num_tariffe_mostra] = 0;
 
 $num_colonne_periodi = 0;
 $num_periodi = numlin_query($periodi);
-unset($tariffa_colonna_periodo);
-unset($tariffap_colonna_periodo);
+$tariffa_colonna_periodo = array();
+$tariffap_colonna_periodo = array();
+$tariffa_chiusa = array();
 for ($num1 = 0 ; $num1 < $num_periodi ; $num1++) {
 $datainizio_db[$num1] = risul_query($periodi,$num1,'datainizio');
 $datafine_db[$num1] = risul_query($periodi,$num1,'datafine');
@@ -171,9 +172,18 @@ for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($tariffe_mostra[${"numtariffa".$num1}] == "SI") {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]);
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]."p");
+if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)]) {
+$tariffa_colonna_periodo[$num1][$num_colonne_periodi] = "c";
+$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = "c";
+} # fine if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)])
 for ($num_i = 1 ; $num_i < $intervalloperiodi[$num_p] ; $num_i++) {
+if ($tariffa_colonna_periodo[$num1][$num_colonne_periodi] == "c") break;
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] += (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]);
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] += (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]."p");
+if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + $num_i + 1)]) {
+$tariffa_colonna_periodo[$num1][$num_colonne_periodi] = "c";
+$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = "c";
+} # fine if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + $num_i + 1)])
 } # fine for $num_i
 } # fine if ($tariffe_mostra[${"numtariffa".$num1}] == "SI")
 } # fine for $num1
@@ -184,9 +194,18 @@ for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
 if ($tariffe_mostra[${"numtariffa".$num2}] == "SI") {
 ${$tariffa[$num2]} = (double) risul_query($periodi,$num1,$tariffa[$num2]);
 ${$tariffa[$num2]."p"} = (double) risul_query($periodi,$num1,$tariffa[$num2]."p");
+if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)]) {
+${$tariffa[$num2]} = "c";
+${$tariffa[$num2]."p"} = "c";
+} # fine if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)])
 for ($num_i = 1 ; $num_i < $intervalloperiodi[$num_p] ; $num_i++) {
+if (${$tariffa[$num2]} == "c") break;
 ${$tariffa[$num2]} += (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]);
 ${$tariffa[$num2]."p"} += (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]."p");
+if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + $num_i + 1)]) {
+${$tariffa[$num2]} = "c";
+${$tariffa[$num2]."p"} = "c";
+} # fine if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + $num_i + 1)])
 } # fine for $num_i
 if (${$tariffa[$num2]} != $tariffa_colonna_periodo[$num2][$num_colonne_periodi] or ${$tariffa[$num2]."p"} != $tariffap_colonna_periodo[$num2][$num_colonne_periodi]) $nuova_colonna = "SI";
 } # fine if ($tariffe_mostra[${"numtariffa".$num2}] == "SI")
@@ -235,7 +254,7 @@ else echo "<br><small><small>($fr_a_persona)</small></small>";
 } # fine if ($per_persona[$num1])
 echo "$chiusura_tag_font</td>";
 for ($num2 = 0 ; $num2 < $num_colonne_periodi ; $num2++) {
-if (!$tariffa_colonna_periodo[$num1][$num2] and !$tariffap_colonna_periodo[$num1][$num2]) $tariffa_vedi = "&nbsp;";
+if ((!$tariffa_colonna_periodo[$num1][$num2] and !$tariffap_colonna_periodo[$num1][$num2]) or $tariffa_colonna_periodo[$num1][$num2] == "c") $tariffa_vedi = "&nbsp;";
 else {
 if ($tariffa_colonna_periodo[$num1][$num2]) $tariffa_vedi = punti_in_num($tariffa_colonna_periodo[$num1][$num2],$stile_soldi);
 if ($tariffap_colonna_periodo[$num1][$num2]) {
