@@ -276,17 +276,30 @@ $var_predef[249] = "codice_fiscale_struttura";
 $var_predef[250] = "partita_iva_struttura";
 $var_predef[251] = "numero_stelle_struttura";
 $var_predef[252] = "logo_struttura";
-$var_predef[253] = "nome_valuta";
-$var_predef[254] = "ritorno_a_capo";
-$var_predef[255] = "avanzamento_riga";
-$var_predef[256] = "email_gia_inviata";
-$var_predef[257] = "errore_ripetizione";
-$var_predef[258] = "messaggio_di_errore";
+$var_predef[253] = "testo_email_richiesta";
+$var_predef[254] = "testo_quotato_email_richiesta";
+$var_predef[255] = "nome_valuta";
+$var_predef[256] = "ritorno_a_capo";
+$var_predef[257] = "avanzamento_riga";
+$var_predef[258] = "email_gia_inviata";
+$var_predef[259] = "errore_ripetizione";
+$var_predef[260] = "messaggio_di_errore";
 
 $num_var_predef = count($var_predef);
-$num_var_non_ripeti = 113;
+$num_var_non_ripeti = 115;
 $num_var_predef_ripeti = $num_var_predef - $num_var_non_ripeti;
 
+if ($num_campi_pers_cliente) {
+$numero_inserimento_pers = 31;
+for ($num_v = ($num_var_predef - 1) ; $num_v >= $numero_inserimento_pers ; $num_v--) $var_predef[($num_v + $num_campi_pers_cliente)] = $var_predef[$num_v];
+for ($num_v = 0 ; $num_v < $num_campi_pers_cliente ; $num_v++) {
+$opt_pers = explode("<",$campi_pers_cliente[$num_v]);
+$var_predef[($numero_inserimento_pers + $num_v)] = $campo_personalizzato_.$opt_pers[0];
+} # fine for $num_v
+$num_var_predef = $num_var_predef + $num_campi_pers_cliente;
+$num_var_predef_ripeti = $num_var_predef_ripeti + $num_campi_pers_cliente;
+} # fine if ($num_campi_pers_cliente)
+
 
 
 $var_predef_data = "";
@@ -442,6 +455,7 @@ $var_riserv['data_inizio_selezione_f'] = 1;
 $var_riserv['data_fine_selezione_f'] = 1;
 $var_riserv['oggi_orig'] = 1;
 $var_riserv['oggi_f'] = 1;
+$var_riserv['testo_quotato_email_richiesta_orig'] = 1;
 $var_riserv['id_pren'] = 1;
 $var_riserv['arrotond_tasse'] = 1;
 $var_riserv['apertura_rip_contr'] = 1;
