@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -68,7 +68,7 @@ break;
 if (@is_file("./COPYING")) $file_copying = "file <a href=\"COPYING\">COPYING</a>";
 else $file_copying = "<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\">AGPLv3</a> License";
 echo "<div style=\"text-align: center;\"><h3>".mex("Benvenuto a HOTELDRUID",$pag).".</h3><br><br>
-HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2012 Marco M. F. De Santis<br>
+HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2014 Marco M. F. De Santis<br>
 HotelDruid comes with ABSOLUTELY NO WARRANTY; <br>for details see the $file_copying.<br>
 This is free software, and you are welcome to redistribute it<br>
  under certain conditions; see the $file_copying for details.<br>
@@ -446,6 +446,8 @@ echo "<table class=\"rbox\" style=\"margin-left: auto; margin-right: auto;\" cel
 <form accept-charset=\"utf-8\" method=\"post\" action=\"disponibilita.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\"><input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 ".ucfirst(mex("disponibilità dal",$pag))." ";
+$inizio_select = "";
+$fine_select = "";
 if ($numconnessione) {
 $oggi = date("Y-m-d",(time() + (C_DIFF_ORE * 3600)));
 $date_select = esegui_query("select datainizio,datafine from $PHPR_TAB_PRE"."periodi$anno where datainizio <= '$oggi' and datafine > '$oggi' ");
@@ -489,7 +491,7 @@ while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $
 $condizione_prenota_proprie .= " )";
 } # fine if ($priv_vedi_tab_prenotazioni == "p" or $priv_vedi_tab_prenotazioni == "g")
 else $condizione_prenota_proprie = "";
-$id_periodo_corrente = calcola_id_periodo_corrente($anno);
+$id_periodo_corrente = calcola_id_periodo_corrente($anno,"");
 $prenotazioni = esegui_query("select * from $tableprenota where ((iddatainizio <= '$id_periodo_corrente' and checkin is NULL) or (iddatafine < '$id_periodo_corrente' and checkout is NULL)) and idclienti != '0' $condizione_prenota_proprie order by checkin desc, iddatainizio, iddatafine");
 $num_prenotazioni = numlin_query($prenotazioni);
 $data_inizio_assoluta = esegui_query("select datainizio from $tableperiodi where idperiodi = 1");
@@ -497,7 +499,7 @@ $data_inizio_assoluta = risul_query($data_inizio_assoluta,0,'datainizio');
 unlock_tabelle($tabelle_lock);
 
 if ($num_prenotazioni > 0) {
-if (!function_exists("dati_costi_agg_prenota")) include("./includes/funzioni_costi_agg.php");
+if (!function_exists('dati_costi_agg_prenota')) include("./includes/funzioni_costi_agg.php");
 $fr_Appartamento = mex("Appartamento",'unit.php');
 if (strlen($fr_Appartamento) > 4) $fr_Appartamento = substr($fr_Appartamento,0,3).".";
 echo "<table class=\"t1\" style=\"background-color: $t1color; margin-left: auto; margin-right: auto;\" width=780 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
