@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -38,6 +38,7 @@ $tableutenti = $PHPR_TAB_PRE."utenti";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablecontratti = $PHPR_TAB_PRE."contratti";
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
+$tablecache = $PHPR_TAB_PRE."cache";
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -163,7 +164,8 @@ $max_mess = esegui_query("select max(idmessaggi) from $tablemessaggi");
 if (numlin_query($max_mess) != 0) $max_mess = (risul_query($max_mess,0,0) + 1);
 else $max_mess = 1;
 if ($destinatario != "tutti") $lista_utenti = ",".$destinatario.",";
-$datavisione = $anno_visione.$data_visione." ".$ora_visione.":".$min_visione.":00";
+if ($anno_visione.str_replace("-","",$data_visione).$ora_visione.$min_visione < date("YmdHi",(time() + (C_DIFF_ORE * 3600)))) $datavisione = date("Y-m-d H:i",(time() + (C_DIFF_ORE * 3600))).":00";
+else $datavisione = $anno_visione.$data_visione." ".$ora_visione.":".$min_visione.":00";
 if (@get_magic_quotes_gpc()) $testo = stripslashes($testo);
 $testo = htmlspecialchars($testo);
 $testo = aggslashdb($testo);
@@ -201,8 +203,8 @@ esegui_query("delete from $tablemessaggi where idmessaggi = '$idmessaggi'");
 } # fine function cancella_messaggi_vecchi
 
 if ($elimina_messaggio) {
-$tabelle_lock = array("$tablemessaggi");
-$altre_tab_lock = array("$tableutenti","$tableprivilegi");
+$tabelle_lock = array($tablemessaggi);
+$altre_tab_lock = array($tableutenti,$tableprivilegi);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $messaggio = esegui_query("select idutenti,tipo_messaggio,dati_messaggio1,mittente from $tablemessaggi where idmessaggi = '".aggslashdb($idmessaggi)."'");
 if (numlin_query($messaggio) == 1) {
@@ -228,6 +230,7 @@ $idutenti = risul_query($messaggio,0,'idutenti');
 esegui_query("update $tablemessaggi set idutenti = '".str_replace(",$id_utente,",",",$idutenti)."' where idmessaggi = '$idmessaggi'");
 cancella_messaggi_vecchi($tableprivilegi,$tablemessaggi);
 echo mex("Messaggio eliminato",$pag).".<br>";
+$mostra_form_iniziale = "SI";
 } # fine if ($continua != "NO")
 } # fine if (numlin_query($messaggio) == 1)
 unlock_tabelle($tabelle_lock);
@@ -270,8 +273,8 @@ if ($data_arrivo) {
 if ($prima_dopo == "prima") $cond_data_arrivo = " and datavisione < '$data_arrivo 00:00:00'";
 if ($prima_dopo == "dopo") $cond_data_arrivo = " and datavisione > '$data_arrivo 23:59:59'";
 } # fine if ($data_arrivo)
-$tabelle_lock = array("$tablemessaggi");
-$altre_tab_lock = array("$tableutenti","$tableprivilegi");
+$tabelle_lock = array($tablemessaggi);
+$altre_tab_lock = array($tableutenti,$tableprivilegi);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 $messaggi = esegui_query("select idmessaggi,idutenti from $tablemessaggi where datavisione < '$adesso'$cond_data_arrivo and idutenti $LIKE '%,$id_utente,%'");
@@ -288,6 +291,294 @@ echo mex("Messaggi eliminati",$pag).".<br>";
 } # fine if ($elimina_tutti_mess == "SI")
 
 
+
+if ($scarica_mess and function_exists('imap_open')) {
+$tabelle_lock = array($tablemessaggi,$tablecache);
+$altre_tab_lock = array($tablepersonalizza);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$server_email_tab_messaggi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'server_email_tab_messaggi' and idutente = '$id_utente' ");
+if (numlin_query($server_email_tab_messaggi)) {
+$server = explode("#@#",risul_query($server_email_tab_messaggi,0,'valpersonalizza'));
+$proto_email_tm = $server[2];
+$porta_email_tm = $server[3];
+$username_email_tm = $server[1];
+$password_email_tm = $server[4];
+$num_trova_email_tm = $server[5];
+$therad_email_tm = explode("#?#",$server[6]);
+$mittente_email_tm = explode("#?#",$server[7]);
+$oggetto_email_tm = explode("#?#",$server[8]);
+$server_email_tm = $server[0];
+if ($porta_email_tm) $server_email_tm .= ":$porta_email_tm";
+$server_email_tm = "$server_email_tm/$proto_email_tm";
+$email_conn = imap_open("{".$server_email_tm."}INBOX",$username_email_tm,$password_email_tm);
+
+if ($email_conn) {
+$messaggi_visti = esegui_query("select * from $tablecache where numero = '$id_utente' and tipo = 'messv_em' ");
+if (numlin_query($messaggi_visti)) {
+$ultimo_controllo = substr(risul_query($messaggi_visti,0,'data_modifica'),0,10);
+if (substr($ultimo_controllo,0,4).substr($ultimo_controllo,5,2).substr($ultimo_controllo,8,2) > date("Ymd",(time() - (36 * 3600)))) $ultimo_controllo = date("d-M-Y",(time() - (36 * 3600)));
+else $ultimo_controllo = date("d-M-Y",mktime(0,0,0,substr($ultimo_controllo,5,2),substr($ultimo_controllo,8,2),substr($ultimo_controllo,0,4)));
+$inbox_id_visto = risul_query($messaggi_visti,0,'testo');
+} # fine if (numlin_query($messaggi_visti))
+else {
+$ultimo_controllo = date("d-M-Y",(time() - (36 * 3600)));
+$inbox_id_visto = 0;
+} # fine else if (numlin_query($messaggi_visti))
+$max_inbox_id = $inbox_id_visto;
+#$ultimo_controllo = date("d-M-Y",(time() - (96 * 3600)));
+
+$mess = imap_search($email_conn,"ALL UNDELETED SINCE \"$ultimo_controllo\"");
+if ($mess) {
+include("./includes/funzioni_testo.php");
+$num_mess = count($mess);
+$mess_nuovi = 0;
+$mess_scaricati = 0;
+$info_mess = imap_fetch_overview($email_conn,implode(",",$mess));
+$max_mess = esegui_query("select max(idmessaggi) from $tablemessaggi");
+if (numlin_query($max_mess) != 0) $max_mess = (risul_query($max_mess,0,0) + 1);
+else $max_mess = 1;
+$lingue = "";
+
+for ($num1 = 0 ; $num1 < $num_mess ; $num1++) {
+$inbox_id = $info_mess[$num1]->uid;
+/*echo "<b>$num1</b> ".htmlspecialchars("messaggio id: ".$info_mess[$num1]->message_id." / $inbox_id - date: ".$info_mess[$num1]->date." - from: ".$info_mess[$num1]->from." - ").utf8_encode(imap_qprint($info_mess[$num1]->subject))." - ".$info_mess[$num1]->in_reply_to." - ".$info_mess[$num1]->references."<br>";
+#echo "---------------------------------------------------------<br>".htmlspecialchars(utf8_encode(imap_qprint(imap_body($email_conn,$mess[$num1]))))."<br>";
+echo "<br>";*/
+#$inbox_id_visto = 26742;
+if ($inbox_id > $inbox_id_visto) {
+$mess_nuovi++;
+if ($max_inbox_id < $inbox_id) $max_inbox_id = $inbox_id;
+$id_messaggio = $info_mess[$num1]->message_id;
+$mittente = $info_mess[$num1]->from;
+$risposta_a = $info_mess[$num1]->in_reply_to;
+$riferimento = $info_mess[$num1]->references;
+$oggetto = utf8_encode(imap_qprint($info_mess[$num1]->subject));
+$inserisci_mess = 0;
+for ($num2 = 0 ; $num2 < $num_trova_email_tm ; $num2++) {
+if ($mittente == $mittente_email_tm[$num2] or stristr($mittente,"<".$mittente_email_tm[$num2].">") or !$mittente_email_tm[$num2]) {
+if (stristr($oggetto,$oggetto_email_tm[$num2])) {
+if ($therad_email_tm[$num2] == "tutti" or (!$risposta_a and !$riferimento)) {
+$inserisci_mess = 1;
+$mess_scaricati++;
+break;
+} # fine if ($therad_email_tm[$num2] == "tutti" or...
+} # fine if (stristr($oggetto,$oggetto_email_tm[$num2]))
+} # fine if ($mittente == $mittente_email_tm[$num2] or...
+} # fine for $num2
+
+if ($inserisci_mess) {
+$lista_utenti = ",".$id_utente.",";
+$datavisione = date("Y-m-d H:i",(time() + (C_DIFF_ORE * 3600))).":00";
+$datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+if (strstr($mittente,"<")) $mittente = substr(strstr($mittente,"<"),1,-1);
+$eml_header = imap_headerinfo($email_conn,$mess[$num1]);
+#echo "<br><br>".var_dump($header)."<br><br>";
+$mittente = "";
+$nome_cognome_richiedente = "";
+$eml_reply_to = $eml_header->reply_to;
+if (is_array($eml_reply_to) and count($eml_reply_to) > 0) {
+for ($num2 = 0 ; $num2 < count($eml_reply_to) ; $num2++) $mittente .= $eml_reply_to[$num2]->mailbox."@".$eml_reply_to[$num2]->host.",";
+$mittente = substr($mittente,0,-1);
+$nome_cognome_richiedente = $eml_reply_to[0]->personal;
+} # fine if (is_array($eml_reply_to) and count($eml_reply_to) > 0)
+else {
+$eml_from = $eml_header->from;
+for ($num2 = 0 ; $num2 < count($eml_from) ; $num2++) $mittente .= $eml_from[$num2]->mailbox."@".$eml_from[$num2]->host.",";
+$mittente = substr($mittente,0,-1);
+$eml_cc = $eml_header->reply_to;
+if (is_array($eml_cc) and count($eml_cc) > 0) {
+for ($num2 = 0 ; $num2 < count($eml_cc) ; $num2++) $mittente .= ",".$eml_cc[$num2]->mailbox."@".$eml_cc[$num2]->host;
+} # fine if (is_array($eml_cc) and count($eml_cc) > 0)
+} # fine else if (is_array($reply_to) and count($reply_to) > 0)
+#if (strstr($mittente,"<")) $mittente = substr(strstr($mittente,"<"),1,-1);
+$testo = utf8_encode(imap_qprint(imap_body($email_conn,$mess[$num1],FT_PEEK)));
+if (@get_magic_quotes_gpc()) $testo = stripslashes($testo);
+$testo = htmlspecialchars($testo);
+$testo = aggslashdb($testo);
+if (stristr($testo,"Content-Type: multipart/alternative;") and stristr($testo,"Content-Type: text/plain;")) {
+$testo = explode("------=_Part",$testo);
+for ($num2 = 0 ; $num2 < count($testo) ; $num2++) {
+if (stristr($testo[$num2],"Content-Type: text/plain;")) {
+$testo = str_replace("\r","\n",str_replace("\r\n","\n",$testo[$num2]));
+if (strstr($testo,"\n\n")) $testo = (strstr($testo,"\n\n"));
+break;
+} # fine if (stristr($testo[$num2],"Content-Type: text/plain;"))
+} # fine for $num2
+} # fine if (stristr($testo,"Content-Type: multipart/alternative;") and...
+else {
+if (stristr($testo,"Content-Type: text/html;")) {
+$testo = strip_tags(str_replace("<br>","\n",str_replace("<BR>","\n",str_replace("</div>","\n",str_replace("</DIV>","\n",str_replace("</tr>","\n",str_replace("</TR>","\n",$testo)))))));
+} # fine if (stristr($testo,"Content-Type: text/html;"))
+} # fine else if (stristr($testo,"Content-Type: multipart/alternative;") and...
+$dati_richiedente = "$nome_cognome_richiedente<d><d>$mittente<d><d><d><d><d><d><d><d><d><d><d><d><d><d>";
+esegui_query("insert into $tablemessaggi (idmessaggi,tipo_messaggio,idutenti,idutenti_visto,datavisione,mittente,testo,dati_messaggio1,dati_messaggio3,dati_messaggio8,dati_messaggio15,dati_messaggio20,datainserimento) values ('$max_mess','rprenota','$lista_utenti','$lista_utenti','$datavisione','$mittente','".aggslashdb($testo)."','da_inserire','1','1','".aggslashdb($dati_richiedente)."','email','$datainserimento')");
+
+# Estrazione dati da testo email
+$testo = preg_replace("/  +/"," ",str_replace("\n"," - ",$testo));
+$arrivo_trovato = 0;
+$arrivo_cercato = array();
+$partenza_trovata = 0;
+$partenza_cercata = array();
+$num_persone = 0;
+$persone_cercate = array();
+
+if (!is_array($lingue)) {
+if (is_dir("./includes/lang/en")) {
+$lingue[0] = "en";
+$num_lingue = 1;
+} # fine if (is_dir("./includes/lang/en"))
+else $num_lingue = 0;
+$lingue[$num_lingue] = "ita";
+$num_lingue++;
+$lang_dir = opendir("./includes/lang/");
+while ($ini_lingua = readdir($lang_dir)) {
+if ($ini_lingua != "." and $ini_lingua != ".." and $ini_lingua != "en" and strlen($ini_lingua) < 4) {
+$lingue[$num_lingue] = $ini_lingua;
+$num_lingue++;
+} # fine if ($ini_lingua != "." and $ini_lingua != ".." and...
+} # fine while ($ini_lingua = readdir($lang_dig))
+} # fine if (!is_array($lingue))
+for ($num2 = 0 ; $num2 < $num_lingue ; $num2++) {
+$lingua_orig = $lingua_mex;
+$lingua_mex = $lingue[$num2];
+$fr_arrivo = mex("arrivo",$pag);
+$fr_partenza = mex("partenza",$pag);
+$fr_persone = mex("persone",$pag);
+$lingua_mex = $lingua_orig;
+if (!$arrivo_trovato and !$arrivo_cercato[$fr_arrivo]) {
+$arrivo_cercato[$fr_arrivo] = 1;
+# strano syntax error se si rimuove "." (dovuto a riconoscimento array?)
+$arrivo = preg_split("/$fr_arrivo"."[^0-9a-z]/i",$testo);
+if ($arrivo[1]) {
+$arrivo = preg_split("/$fr_partenza"."[^0-9a-z]/i",substr($testo,strlen($arrivo[0])));
+$arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2]);
+if ($arrivo) $arrivo_trovato = 1;
+} # fine if ($arrivo[1])
+} # fine if (!$arrivo_trovato and !$arrivo_cercato[$fr_arrivo])
+if (!$partenza_trovata and !$partenza_cercata[$fr_partenza]) {
+$partenza_cercata[$fr_partenza] = 1;
+$partenza = preg_split("/$fr_partenza"."[^0-9a-z]/i",$testo);
+if ($partenza[1]) {
+$partenza = trova_prima_data(substr($testo,strlen($partenza[0]),40),$stile_data,$lingue[$num2]);
+if ($partenza and $partenza != $arrivo) $partenza_trovata = 1;
+} # fine if ($partenza[1])
+} # fine if (!$partenza_trovata and !$partenza_cercata[$fr_partenza])
+if (!$num_persone and !$persone_cercate[$fr_persone]) {
+$persone_cercate[$fr_persone] = 1;
+$lingua_mex = $lingue[$num2];
+$fr_persone2 = mex("individui",$pag);
+$fr_ospiti = mex("ospiti",$pag);
+$fr_gruppo = mex("gruppo",$pag);
+$fr_adulti = mex("adulti",$pag);
+$fr_bambini = mex("bambini",$pag);
+$lingua_mex = $lingua_orig;
+$num_persone = trova_numero_vicino($testo,$fr_adulti);
+if ($num_persone) {
+$num_bambini = trova_numero_vicino($testo,$fr_bambini);
+if ($num_bambini) $num_persone = $num_persone + $num_bambini;
+} # fine if ($num_persone)
+else {
+$num_persone = trova_numero_vicino($testo,$fr_ospiti);
+if (!$num_persone) {
+$num_persone = trova_numero_vicino($testo,$fr_gruppo);
+if (!$num_persone) {
+$num_persone = trova_numero_vicino($testo,$fr_persone2);
+if (!$num_persone) $num_persone = trova_numero_vicino($testo,$fr_persone);
+} # fine if (!$num_persone)
+} # fine if (!$num_persone)
+} # fine else if ($num_persone)
+} # fine if (!$num_persone and !$persone_cercate[$fr_persone])
+} # fine for $num2
+for ($num2 = 0 ; $num2 < $num_lingue ; $num2++) {
+$lingua_orig = $lingua_mex;
+$lingua_mex = $lingue[$num2];
+$fr_notti = mex("notti",$pag);
+$lingua_mex = $lingua_orig;
+# Se non è stata fornita la data di partenza ma solo il numero di notti
+if (!$partenza_trovata and $arrivo_trovato and !$partenza_cercata[$fr_notti]) {
+$partenza = trova_numero_vicino($testo,$fr_notti);
+if ($partenza) {
+$partenza_trovata = 1;
+$partenza = date("Y-m-d",mktime(0,0,0,substr($arrivo,5,2),((integer) substr($arrivo,8,2) + $partenza),substr($arrivo,0,4)));
+} # fine if ($partenza)
+} # fine if (!$partenza_trovata and $arrivo_trovato and...
+} # fine for $num2
+
+if ($arrivo_trovato) esegui_query("update $tablemessaggi set dati_messaggio4 = '$arrivo' where idmessaggi = '$max_mess' ");
+if ($partenza_trovata) esegui_query("update $tablemessaggi set dati_messaggio5 = '$partenza' where idmessaggi = '$max_mess' ");
+if ($num_persone) esegui_query("update $tablemessaggi set dati_messaggio7 = '$num_persone' where idmessaggi = '$max_mess' ");
+
+$max_mess++;
+} # fine if ($inserisci_mess)
+} # fine if ($inbox_id > $inbox_id_visto)
+} # fine for $num1
+
+#echo "<br><br>".var_dump($info_mess);
+$data_modifica = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
+if (numlin_query($messaggi_visti)) esegui_query("update $tablecache set testo = '$max_inbox_id', data_modifica = '$data_modifica' where numero = '$id_utente' and tipo = 'messv_em' ");
+else esegui_query("insert into $tablecache (numero,tipo,testo,data_modifica,datainserimento) values ('$id_utente','messv_em','$max_inbox_id','$data_modifica','$data_modifica') ");
+if ($mess_nuovi) echo mex("Nuovi messaggi",$pag).": $mess_nuovi. ".mex("Scaricati",$pag).": $mess_scaricati.<br>";
+else echo mex("Nessun nuovo messaggio",$pag).".<br>";
+} # fine if ($mess)
+else echo mex("Nessun nuovo messaggio",$pag).".<br>";
+imap_close($email_conn);
+} # fine if ($email_conn)
+
+else echo mex("Connessione al server",$pag)." ".$server[0]." ".mex("non riuscita!",$pag)." ".mex("Controllare i dati immessi in \"configura e personalizza\"",$pag).".<br>";
+} # fine if (numlin_query($server_email_tab_messaggi))
+unlock_tabelle($tabelle_lock);
+} # fine if ($scarica_mess and function_exists('imap_open'))
+
+
+
+if ($cambia_dati_ricavati and controlla_num_pos($cambia_dati_ricavati) == "SI") {
+$tabelle_lock = array($tablemessaggi);
+$altre_tab_lock = array($tableperiodi);
+$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$mess_esist = esegui_query("select * from $tablemessaggi where idmessaggi = '$cambia_dati_ricavati' ");
+if (numlin_query($mess_esist)) {
+$tipo_mess = risul_query($mess_esist,0,'tipo_messaggio');
+if ($tipo_mess == "rprenota") {
+if (@get_magic_quotes_gpc()) {
+$n_cognome_richiedente = stripslashes($n_cognome_richiedente);
+$n_email_richiedente = stripslashes($n_email_richiedente);
+} # fine if (@get_magic_quotes_gpc())
+if ($n_cognome_richiedente or $n_email_richiedente) {
+$dati_richiedente = risul_query($mess_esist,0,'dati_messaggio15');
+$dati_richiedente = explode("<d>",$dati_richiedente);
+if ($n_cognome_richiedente) {
+$n_cognome_richiedente = htmlspecialchars($n_cognome_richiedente);
+$dati_richiedente[0] = $n_cognome_richiedente;
+} # fine if ($n_cognome_richiedente)
+if ($n_email_richiedente) {
+$n_email_richiedente = htmlspecialchars($n_email_richiedente);
+$dati_richiedente[2] = $n_email_richiedente;
+} # fine if ($n_email_richiedente)
+$dati_richiedente = implode("<d>",$dati_richiedente);
+esegui_query("update $tablemessaggi set dati_messaggio15 = '".aggslashdb($dati_richiedente)."' where idmessaggi = '$cambia_dati_ricavati' ");
+} # fine if ($n_cognome_richiedente or $n_email_richiedente)
+if ($n_data_arrivo) {
+$idperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '".aggslashdb($n_data_arrivo)."' ");
+if (numlin_query($idperiodo)) {
+esegui_query("update $tablemessaggi set dati_messaggio4 = '".aggslashdb($n_data_arrivo)."' where idmessaggi = '$cambia_dati_ricavati' ");
+} # fine if (numlin_query($idperiodo))
+} # fine if ($n_data_arrivo)
+if ($n_data_partenza) {
+$idperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '".aggslashdb($n_data_partenza)."' ");
+if (numlin_query($idperiodo)) {
+esegui_query("update $tablemessaggi set dati_messaggio5 = '".aggslashdb($n_data_partenza)."' where idmessaggi = '$cambia_dati_ricavati' ");
+} # fine if (numlin_query($idperiodo))
+} # fine if ($n_data_partenza)
+if ($n_num_persone and controlla_num_pos($n_num_persone) == "SI") {
+esegui_query("update $tablemessaggi set dati_messaggio7 = '$n_num_persone' where idmessaggi = '$cambia_dati_ricavati' ");
+} # fine if ($n_num_persone and controlla_num_pos($n_num_persone) == "SI")
+} # fine if ($tipo_mess == "rprenota")
+} # fine if (numlin_query($mess_esist))
+unlock_tabelle($tabelle_lock);
+} # fine if ($cambia_dati_ricavati and controlla_num_pos($cambia_dati_ricavati) == "SI")
+
+
+
 if ($mostra_form_iniziale == "NO") {
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -305,6 +596,20 @@ echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 
 if ($mostra_form_iniziale != "NO") {
 
+if (function_exists('imap_open')) {
+$server_email_tab_messaggi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'server_email_tab_messaggi' and idutente = '$id_utente' ");
+if (numlin_query($server_email_tab_messaggi)) {
+$server = explode("#@#",risul_query($server_email_tab_messaggi,0,'valpersonalizza'));
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"line-height:160%\">
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<input type=\"hidden\" name=\"scarica_mess\" value=\"1\">
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Scarica messaggi email",$pag)."\" style=\"font-size: 70%;\">
+</div></form>";
+} # fine if (numlin_query($server_email_tab_messaggi))
+} # fine if (function_exists('imap_open'))
+
 
 echo "<h3>".mex("Messaggi",$pag)."</h3><br><br>";
 
@@ -362,6 +667,32 @@ $option_date .= "<option value=\"$data_select\">$data_select_vedi</option>";
 
 if ($num_messaggi > 0) {
 
+$stringa_pagine = "";
+$stringa_puntini_tab = "";
+$num_vedi_in_tab = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'num_righe_tab_messaggi' and idutente = '$id_utente'");
+$num_vedi_in_tab = risul_query($num_vedi_in_tab,0,'valpersonalizza_num');
+if ($num_messaggi > $num_vedi_in_tab) {
+$num_pagine = ceil($num_messaggi / $num_vedi_in_tab);
+$stringa_pagine = "<div style=\"text-align: center; margin: 3px;\"><small>".mex("pagine",'visualizza_tabelle.php')."</small>:";
+if (!$pagina_messaggi) $pagina_messaggi = 1;
+for ($num1 = 1 ; $num1 <= $num_pagine ; $num1++) {
+$stringa_pagine .= " ";
+if ($num1 != $pagina_messaggi) {
+$stringa_pagine .= "<a href=\"./$pag?anno=$anno&amp;id_sessione=$id_sessione&amp;pagina_messaggi=$num1\">";
+} # fine if ($num1 != $pagina_messaggi)
+else $stringa_pagine .= "<b>";
+$stringa_pagine .= $num1;
+if ($num1 != $pagina_messaggi) $stringa_pagine .= "</a>";
+else $stringa_pagine .= "</b>";
+} # fine for $num1
+$stringa_pagine .= "</div>";
+$stringa_puntini_tab = "<tr><td colspan=\"5\" style=\"text-align: center;\">...</td></tr>";
+} # fine if ($num_messaggi > $num_vedi_in_tab)
+else $num_pagine = 1;
+
+$orario_tab_messaggi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'mostra_orario_tab_messaggi' and idutente = '$id_utente'");
+$orario_tab_messaggi = risul_query($orario_tab_messaggi,0,'valpersonalizza');
+
 function crea_tasto_modifica_prenota ($stato_prenota,$priv_mod_prenota_iniziate,$priv_mod_prenotazioni,$priv_mod_prenota_ore,$anno,$PHPR_TAB_PRE,$pag,$id_sessione,$id_utente) {
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tasto_prenota = str_replace(" ","&nbsp;",mex("Inserito",$pag)).": ";
@@ -402,22 +733,27 @@ $tasto_prenota .= $link_modifica_inizio.$prenota_inserite[$num2].$link_modifica_
 return $tasto_prenota;
 } # fine function crea_tasto_modifica_prenota
 
-echo "<table class=\"me1\" style=\"background-color: $t1color; margin-left: auto; margin-right: auto;\" border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
+echo "$stringa_pagine
+<table class=\"me1\" style=\"background-color: $t1color; margin-left: auto; margin-right: auto;\" border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
 <tr><td align=\"center\">".mex("N°",$pag)."</td>
 <td align=\"center\">".mex("Mittente",$pag)."</td>
 <td align=\"center\">".mex("Testo",$pag)."</td>
 <td align=\"center\">".mex("Data",$pag)."</td>
 <td align=\"center\">".mex("Azioni",$pag)."</td></tr>";
+if ($stringa_pagine and $pagina_messaggi != 1) echo $stringa_puntini_tab;
+
 
 for ($num1 = 0 ; $num1 < $num_messaggi ; $num1++) {
 $numero = $num_messaggi - $num1;
+if ($num_pagine == 1 or (($num1 + 1) > (($pagina_messaggi - 1) * $num_vedi_in_tab) and ($num1 + 1) <= ($pagina_messaggi * $num_vedi_in_tab))) {
+
 $idmessaggi = risul_query($messaggi,$num1,'idmessaggi');
 $idutenti_visto = risul_query($messaggi,$num1,'idutenti_visto');
 if (str_replace(",$id_utente,","",$idutenti_visto) != $idutenti_visto) {
 $font_num = "<div style=\"display: inline; color: red;\"><b>";
 $slash_font_num = "</b></div>";
 $tabelle_lock = array($tablemessaggi);
-$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$tabelle_lock = lock_tabelle($tabelle_lock,"");
 $idutenti_visto = esegui_query("select idutenti_visto from $tablemessaggi where idmessaggi = '$idmessaggi'");
 if (numlin_query($idutenti_visto) == 1) {
 $idutenti_visto = risul_query($idutenti_visto,0,'idutenti_visto');
@@ -436,9 +772,12 @@ $testo = risul_query($messaggi,$num1,'testo');
 
 $tasto_prenota = "";
 $tasto_contr = "";
+$aggiunta_testo_dt = "";
 if ($tipo_messaggio == "rprenota") {
 $mittente = "<small>$mittente</small>";
+$testo_orig = $testo;
 $testo = "<small>".nl2br($testo)."</small>";
+if (strlen($testo) > 3000) $testo = "<small>$testo</small>";
 
 unset($costo_presente);
 unset($numsettimane);
@@ -459,6 +798,7 @@ $id_periodi_costo_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio14
 $dati_calcolati_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio16'));
 $anno_prenota_dt = risul_query($messaggi,$num1,'dati_messaggio18');
 $origine_prenota_dt = risul_query($messaggi,$num1,'dati_messaggio19');
+$aggiunta_testo_dt = risul_query($messaggi,$num1,'dati_messaggio20');
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $inizioperiodo[$n_t] = aggslashdb($inizioperiodo_dt[($n_t - 1)]);
 $idinizioperiodo[$n_t] = esegui_query("select idperiodi from $tableperiodi where datainizio = '".$inizioperiodo[$n_t]."'");
@@ -530,7 +870,7 @@ $oracheckin = $oracheckin.":00";
 $metodo_pagamento = $dati_richiedente_dt[17];
 
 if ($stato_prenota == "da_inserire") {
-if ($priv_ins_nuove_prenota == "s") {
+if ($priv_ins_nuove_prenota == "s" and $inizioperiodo[1]) {
 $tasto_prenota = "<form accept-charset=\"utf-8\" method=\"post\" action=\"prenota.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -579,13 +919,28 @@ $tasto_prenota .= "<input type=\"hidden\" name=\"costoagg$ncostiagg"."_$n_t\" va
 } # fine for $n_t
 $tasto_prenota .= "<input class=\"sbutton\" type=\"submit\" value=\"".mex("Inserisci la prenotazione",$pag)."\">
 </div></form><br>";
-} # fine if ($priv_ins_nuove_prenota == "s")
+
+if ($num_tipologie == 1 and !$numero_tariffa[1] and $num_app_tipo_richiesti[1] == 1 and $fineperiodo[1]) {
+$tasto_prenota .= "<form accept-charset=\"utf-8\" method=\"post\" action=\"disponibilita.php\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"cognome_1\" value=\"$cognome_richiedente\">
+<input type=\"hidden\" name=\"email_1\" value=\"$email_richiedente\">
+<input type=\"hidden\" name=\"testo_email_richiesta\" value=\"".str_replace("\"","&quot;",$testo_orig)."\">
+<input type=\"hidden\" name=\"inizioperiodo\" value=\"".$inizioperiodo[1]."\">
+<input type=\"hidden\" name=\"fineperiodo\" value=\"".$fineperiodo[1]."\">
+<input type=\"hidden\" name=\"origine\" value=\"messaggi.php#mess$idmessaggi\">";
+if ($numpersone[1]) $tasto_prenota .= "<input type=\"hidden\" name=\"numpersone\" value=\"".$numpersone[1]."\">";
+$tasto_prenota .= "<input class=\"sbutton\" type=\"submit\" value=\"".mex("Controlla disponibilità",$pag)."\">
+</div></form><br>";
+} # fine if ($num_tipologie == 1 and !$numero_tariffa[1] and...
+} # fine if ($priv_ins_nuove_prenota == "s" and $inizioperiodo[1])
 
 if ($option_contratti) {
 $tasto_contr = "<form accept-charset=\"utf-8\" method=\"post\" action=\"visualizza_contratto.php\"><div class=\"linhbox\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"origine\" value=\"messaggi.php\">";
+<input type=\"hidden\" name=\"origine\" value=\"messaggi.php#mess$idmessaggi\">";
 $n_c = 0;
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 for ($n_r = 1 ; $n_r <= $num_app_tipo_richiesti[$n_t] ; $n_r++) {
@@ -632,6 +987,7 @@ $tasto_contr .= "<input type=\"hidden\" name=\"costo_tot_$n_c\" value=\"$costo_t
 } # fine for $n_r
 } # fine for $n_t
 $tasto_contr .= "<input type=\"hidden\" name=\"num_ripeti\" value=\"$n_c\">
+<input type=\"hidden\" name=\"testo_email_richiesta\" value=\"".str_replace("\"","&quot;",$testo_orig)."\">
 <select name=\"numero_contratto\">
 $option_contratti
 </select><br>
@@ -664,11 +1020,36 @@ if ($tipo_messaggio == "sistema") $testo = str_replace("<sessione>","anno=$anno&
 
 
 $data = risul_query($messaggi,$num1,'datavisione');
-$data = formatta_data(substr($data,0,10),$stile_data);
+$data = formatta_data(substr($data,0,10),$stile_data).substr($data,10,6);
 echo "<tr><td align=\"center\">$font_num".$numero."$slash_font_num</td>
 <td align=\"center\">$mittente</td>
-<td align=\"left\">$testo</td>
-<td align=\"center\">$data</td>
+<td align=\"left\"><a name=\"mess$idmessaggi\"></a>";
+if ($aggiunta_testo_dt) {
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#mess$idmessaggi\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<input type=\"hidden\" name=\"cambia_dati_ricavati\" value=\"$idmessaggi\">
+-------------------------<br>
+<em>".mex("Dati ricavati dal messaggio email",$pag)."</em>:<br>
+".mex("Nome",$pag).": $cognome_richiedente (<input name=\"n_cognome_richiedente\" size=\"28\" type=\"text\">)<br>
+".mex("Email",$pag).": $email_richiedente (<input name=\"n_email_richiedente\" size=\"28\" type=\"text\">)<br>
+".ucfirst(mex("arrivo",$pag)).": ";
+if ($inizioperiodo[1]) echo formatta_data($inizioperiodo[1],$stile_data);
+echo " (";
+mostra_menu_date(C_DATI_PATH."/selperiodimenu$anno.$id_utente.php","n_data_arrivo","",1," selected",$id_utente,$tema,"",$inizioperiodo[1]);
+echo ")<br>
+".ucfirst(mex("partenza",$pag)).": ";
+if ($fineperiodo[1]) echo formatta_data($fineperiodo[1],$stile_data);
+echo " (";
+mostra_menu_date(C_DATI_PATH."/selperiodimenu$anno.$id_utente.php","n_data_partenza","",1," selected",$id_utente,$tema,"",$fineperiodo[1]);
+echo ")<br>
+".ucfirst(mex("persone",$pag)).": ".$numpersone[1]." (<input name=\"n_num_persone\" size=\"3\" type=\"text\">)<br>
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("Modifica",$pag)."\"><br>
+-------------------------<br></div></form>";
+} # fine if ($aggiunta_testo_dt)
+echo "$testo</td>
+<td align=\"center\">$data$orario</td>
 <td align=\"center\">$tasto_prenota
 $tasto_contr
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
@@ -678,9 +1059,13 @@ $tasto_contr
 <input type=\"hidden\" name=\"idmessaggi\" value=\"$idmessaggi\">
 <input class=\"sbutton\" type=\"submit\" name=\"elimina_messaggio\" value=\"".mex("Elimina",$pag)."\">
 </div></form></td></tr>";
+
+} # fine if ($num_pagine == 1 or (($num1 + 1) > (($pagina_messaggi - 1) * $num_vedi_in_tab) and ($num1 + 1) <= ($pagina_messaggi * $num_vedi_in_tab)))
 } # fine for $num1
 
-echo "</table><br><div style=\"text-align: center\">
+
+if ($stringa_pagine and $pagina_messaggi != $num_pagine) echo $stringa_puntini_tab;
+echo "</table>$stringa_pagine<br><div style=\"text-align: center\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"line-height:160%\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
