@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -275,6 +275,7 @@ ${"d_commento".$num1} = stripslashes(${"d_commento".$num1});
 } # fine if (get_magic_quotes_gpc())
 ${"n_nome_app".$num1} = str_replace(",","",${"n_nome_app".$num1});
 if (str_replace (" ","",${"n_nome_app".$num1}) == "") ${"n_nome_app".$num1} = str_replace(" ","_",${"n_nome_app".$num1});
+${"n_nome_app".$num1} = trim(${"n_nome_app".$num1});
 ${"n_nome_app".$num1} = elimina_caratteri_slash(${"n_nome_app".$num1});
 ${"n_nome_app".$num1} = htmlspecialchars(${"n_nome_app".$num1});
 ${"n_numcasa".$num1} = elimina_caratteri_slash(${"n_numcasa".$num1});
@@ -324,6 +325,7 @@ $num_tab++;
 $tabelle_lock[$num_tab] = $tabledescrizioni;
 } # fine if ($modificaappartamento == "Continua")
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+unset($d_letto);
 
 for ($num1 = 0 ;$num1 < $num_app_modifica ; $num1++) {
 $idappartamenti = ${"idappartamenti".$num1};
@@ -334,7 +336,7 @@ $n_numpiano = ${"n_numpiano".$num1};
 $n_maxoccupanti = ${"n_maxoccupanti".$num1};
 $n_priorita = ${"n_priorita".$num1};
 $n_app_vicini = ${"n_app_vicini".$num1};
-${"d_app_vicini".$num1} = esegui_query("select app_vicini from $tableappartamenti where idappartamenti = '$idappartamenti' ");
+${"d_app_vicini".$num1} = esegui_query("select app_vicini from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 if (numlin_query(${"d_app_vicini".$num1})) ${"d_app_vicini".$num1} = risul_query(${"d_app_vicini".$num1},0,'app_vicini');
 
 if ($cambia_nome_app and $modificaappartamento == "Continua") {
@@ -349,16 +351,19 @@ if ($anno_esistente != $anno_esistente2) $modificare = "NO";
 if ($modificare == "NO") echo mex("<b>L'appartamento non è stato modificato</b> perchè il database è cambiato nel frattempo",'unit.php').".<br>";
 } # fine if ($n_nome_app and $modificaappartamento == "Continua")
 
-$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '$idappartamenti'");
+$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."'");
 $num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 1) {
 echo mex("L'appartamento",'unit.php')." $idappartamenti ".mex("non esiste più",$pag).".<br>";
 $modificare = "NO";
 $tornare_a = "inizio.php";
 } # fine if ($num_app_esiste != 1)
-else $tornare_a = $pag;
+else {
+$tornare_a = $pag;
+$d_letto[$idappartamenti] = risul_query($app_esiste,0,'letto');
+} # fine else if ($num_app_esiste != 1)
 if ($n_nome_app and strcmp($n_nome_app,$idappartamenti)) {
-$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '$n_nome_app'");
+$app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($n_nome_app)."'");
 $num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 0) {
 echo mex("L'appartamento",'unit.php')." $n_nome_app ".mex("esiste già",$pag).".<br>";
@@ -415,15 +420,17 @@ $comp_priorita = "";
 $comp_app_vicini = (string) $d_app_vicini;
 $comp_commento = ${"d_commento".$num1};
 } # fine else if ($form_tabella)
+if ($d_letto[$idappartamenti]) $fr1 = "[1]";
+else $fr1 = "";
 $messaggi = "";
-if (strcmp($n_nome_app,$comp_nome_app)) $messaggi .= mex("Il nome dell'appartamento verrà cambiato da",'unit.php')." $idappartamenti ".mex("a",$pag)." $n_nome_app.<br>";
-if ($n_numcasa != $comp_numcasa) $messaggi .= mex("La casa verrà cambiata da",$pag)." ".${"d_numcasa".$num1}." ".mex("a",$pag)." $n_numcasa.<br>";
-if ($n_numpiano != $comp_numpiano) $messaggi .= mex("Il piano verrà cambiato da",$pag)." ".${"d_numpiano".$num1}." ".mex("a",$pag)." $n_numpiano.<br>";
-if ($n_maxoccupanti != $comp_maxoccupanti) $messaggi .= mex("Il massimo numero di occupanti verrà cambiato da",$pag)." ".${"d_maxoccupanti".$num1}." ".mex("a",$pag)." $n_maxoccupanti.<br>";
-if ($n_priorita != $comp_priorita) $messaggi .= mex("La priorità verrà cambiata da",$pag)." ".${"d_priorita".$num1}." ".mex("a",$pag)." $n_priorita.<br>";
-if ($n_app_vicini != $comp_app_vicini) $messaggi .= mex("Gli appartamenti vicini verranno cambiati",'unit.php').".<br>";
+if (strcmp($n_nome_app,$comp_nome_app)) $messaggi .= mex($fr1."Il nome dell'appartamento verrà cambiato da",'unit.php')." $idappartamenti ".mex("a",$pag)." $n_nome_app.<br>";
+if ($n_numcasa != $comp_numcasa) $messaggi .= mex("La casa verrà cambiata da",$pag)." \"".${"d_numcasa".$num1}."\" ".mex("a",$pag)." \"$n_numcasa\".<br>";
+if ($n_numpiano != $comp_numpiano) $messaggi .= mex("Il piano verrà cambiato da",$pag)." \"".${"d_numpiano".$num1}."\" ".mex("a",$pag)." \"$n_numpiano\".<br>";
+if ($n_maxoccupanti != $comp_maxoccupanti) $messaggi .= mex("Il massimo numero di occupanti verrà cambiato da",$pag)." \"".${"d_maxoccupanti".$num1}."\" ".mex("a",$pag)." \"$n_maxoccupanti\".<br>";
+if ($n_priorita != $comp_priorita) $messaggi .= mex("La priorità verrà cambiata da",$pag)." \"".${"d_priorita".$num1}."\" ".mex("a",$pag)." \"$n_priorita\".<br>";
+if ($n_app_vicini != $comp_app_vicini) $messaggi .= mex($fr1."Gli appartamenti vicini verranno cambiati",'unit.php').".<br>";
 if ($n_commento != $comp_commento) $messaggi .= mex("Il commento verrà cambiato",$pag).".<br>";
-if ($messaggi) echo mex("Appartamento",'unit.php')." $idappartamenti:<br>$messaggi<br>";
+if ($messaggi) echo mex($fr1."Appartamento",'unit.php')." $idappartamenti:<br>$messaggi<br>";
 echo "<input type=\"hidden\" name=\"idappartamenti$num1\" value=\"$idappartamenti\">
 <input type=\"hidden\" name=\"n_nome_app$num1\" value=\"$n_nome_app\">
 <input type=\"hidden\" name=\"n_numcasa$num1\" value=\"$n_numcasa\">
@@ -475,6 +482,8 @@ $comp_priorita = "";
 $comp_app_vicini = $d_app_vicini;
 $comp_commento = ${"d_commento".$num1};
 } # fine else if ($form_tabella)
+if ($d_letto[$idappartamenti]) $fr1 = "[1]";
+else $fr1 = "";
 $modificato = "NO";
 
 if (strcmp($n_nome_app,$comp_nome_app)) {
@@ -575,37 +584,40 @@ esegui_query("update $tableappartamenti set app_vicini = '".aggslashdb($app_reci
 } # fine if (numlin_query($app_reciprici) == 1)
 } # fine if (str_replace(",".$d_app_vicino.",",",",",".$n_app_vicini.",") == ",".$n_app_vicini.",")
 } # fine for $num2
-esegui_query("update $tableappartamenti set app_vicini = '".aggslashdb($n_app_vicini)."' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set app_vicini = '".aggslashdb($n_app_vicini)."' where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 } # fine if ($n_app_vicini != $comp_app_vicini)
 
 if ($n_numcasa != $comp_numcasa) {
 $modificato = "SI";
-esegui_query("update $tableappartamenti set numcasa = '$n_numcasa' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set numcasa = '".aggslashdb($n_numcasa)."' where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 } # fine if ($n_numcasa != $comp_)
 if ($n_numpiano != $comp_numpiano) {
 $modificato = "SI";
-esegui_query("update $tableappartamenti set numpiano = '$n_numpiano' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set numpiano = '".aggslashdb($n_numpiano)."' where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 } # fine if ($n_numpiano != $comp_numpiano)
 if ($n_maxoccupanti != $comp_maxoccupanti) {
+$letto = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' and letto = '1' ");
+if (!numlin_query($letto)) {
 $modificato = "SI";
 $n_maxoccupanti = (string) $n_maxoccupanti;
 if ($n_maxoccupanti == "") $n_maxoccupanti = "NULL";
-else $n_maxoccupanti = "'$n_maxoccupanti'";
-esegui_query("update $tableappartamenti set maxoccupanti = $n_maxoccupanti where idappartamenti = '$idappartamenti' ");
+else $n_maxoccupanti = "'".aggslashdb($n_maxoccupanti)."'";
+esegui_query("update $tableappartamenti set maxoccupanti = $n_maxoccupanti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
+} # fine if (!numlin_query($letto))
 } # fine if ($n_maxoccupanti != $comp_maxoccupanti)
 if ($n_priorita != $comp_priorita) {
 $modificato = "SI";
 $n_priorita = (string) $n_priorita;
 if ($n_priorita == "") $n_priorita = "NULL";
-else $n_priorita = "'$n_priorita'";
-esegui_query("update $tableappartamenti set priorita = $n_priorita where idappartamenti = '$idappartamenti' ");
+else $n_priorita = "'".aggslashdb($n_priorita)."'";
+esegui_query("update $tableappartamenti set priorita = $n_priorita where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 } # fine if ($n_priorita != $comp_priorita)
 if ($n_commento != $comp_commento) {
 $modificato = "SI";
 $n_commento = aggslashdb($n_commento);
-esegui_query("update $tableappartamenti set commento = '$n_commento' where idappartamenti = '$idappartamenti' ");
+esegui_query("update $tableappartamenti set commento = '".aggslashdb($n_commento)."' where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 } # fine if ($n_commento != $comp_commento)
-if ($modificato == "SI") echo mex("L'appartamento",'unit.php')." $idappartamenti ".mex("è stato modificato",'unit.php').".<br>";
+if ($modificato == "SI") echo mex($fr1."L'appartamento",'unit.php')." $idappartamenti ".mex("è stato modificato",'unit.php').".<br>";
 } # fine for $num1
 
 } # fine else if ($modificaappartamento != "Continua")
@@ -756,18 +768,22 @@ if ($mostra_form_modifica != "NO") {
 
 
 # Form per modificare l'appartamento.
-echo "<h3>".mex("Modifica l'appartamento",'unit.php')." $idappartamenti.</h3>";
-
 $appartamento = esegui_query("select * from $tableappartamenti where idappartamenti = '$idappartamenti'");
 if (numlin_query($appartamento)) {
 $d_numcasa = risul_query($appartamento,0,'numcasa');
 $d_numpiano = risul_query($appartamento,0,'numpiano');
 $d_maxoccupanti = risul_query($appartamento,0,'maxoccupanti');
 $d_priorita = risul_query($appartamento,0,'priorita');
+$d_letto = risul_query($appartamento,0,'letto');
 $d_app_vicini = risul_query($appartamento,0,'app_vicini');
 $d_commento = risul_query($appartamento,0,'commento');
 } # fine if (numlin_query($appartamento))
 
+if ($d_letto) $fr1 = "[1]";
+else $fr1 = "";
+
+echo "<h3>".mex($fr1."Modifica l'appartamento",'unit.php')." $idappartamenti.</h3>";
+
 echo "<br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_app.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -781,19 +797,23 @@ echo "<br>
 <td>".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_numcasa0\" size=\"10\"></td></tr>
 <tr><td>".mex("Piano",$pag).": <b>$d_numpiano</b></td>
 <td>".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_numpiano0\" size=\"10\" maxlength=\"10\"></td></tr>
-<tr><td>".mex("Capienza",$pag).": <b>$d_maxoccupanti</b> ".mex("Persone",$pag)."</td>
-<td>".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_maxoccupanti0\" size=\"2\" maxlength=\"2\"></td></tr>
+<tr><td>".mex("Capienza",$pag).": <b>$d_maxoccupanti</b> ";
+if ($d_maxoccupanti == 1) echo mex("Persona",$pag);
+else echo mex("Persone",$pag);
+echo "</td><td>";
+if (!$d_letto) echo "".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_maxoccupanti0\" size=\"2\" maxlength=\"2\">";
+echo "</td></tr>
 <tr><td>".mex("Priorità",$pag).": <b>$d_priorita</b></td>
 <td>".mex("Cambia in",$pag)." <input type=\"text\" name=\"n_priorita0\" size=\"5\" maxlength=\"5\"></td></tr>
-<tr><td>".mex("Appartamenti vicini",'unit.php').": </td>
-<td> <input type=\"text\" name=\"n_app_vicini0\" size=\"25\" value=\"$d_app_vicini\"> (".mex("lista di appartamenti separati da virgole",'unit.php').")</td></tr>
+<tr><td>".mex($fr1."Appartamenti vicini",'unit.php').": </td>
+<td> <input type=\"text\" name=\"n_app_vicini0\" size=\"25\" value=\"$d_app_vicini\"> (".mex($fr1."lista di appartamenti separati da virgole",'unit.php').")</td></tr>
 </table>
 ".mex("Commento",$pag).":<br>
 <textarea name=\"n_commento0\" rows=3 cols=60 style=\"white-space: pre; overflow: auto;\">$d_commento</textarea><br>
 <div style=\"text-align: center;\"><br>
-".mex("<b>Attenzione</b>: le prenotazioni già inserite in questo appartamento <b>non</b> verranno spostate",'unit.php').",<br>
+".mex($fr1."<b>Attenzione</b>: le prenotazioni già inserite in questo appartamento <b>non</b> verranno spostate",'unit.php').",<br>
 ".mex("anche se le loro caratteristiche non sono più compatibili",$pag).".<br>
-<input class=\"sbutton\" id=\"modi\" type=\"submit\" name=\"modificaappartamento\" value=\"".mex("Modifica l'appartamento",'unit.php')." $idappartamenti\">
+<input class=\"sbutton\" id=\"modi\" type=\"submit\" name=\"modificaappartamento\" value=\"".mex($fr1."Modifica l'appartamento",'unit.php')." $idappartamenti\">
 <input type=\"hidden\" name=\"d_numcasa0\" value=\"$d_numcasa\">
 <input type=\"hidden\" name=\"d_numpiano0\" value=\"$d_numpiano\">
 <input type=\"hidden\" name=\"d_maxoccupanti0\" value=\"$d_maxoccupanti\">
@@ -811,7 +831,7 @@ echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"".$idappartamenti."\">
 <input type=\"hidden\" name=\"modificadescr\" value=\"SI\">
-".ucfirst(mex("descrizione dell'appartamento",'unit.php'))." <em>$idappartamenti</em>:<br>
+".ucfirst(mex($fr1."descrizione dell'appartamento",'unit.php'))." <em>$idappartamenti</em>:<br>
 <table><tr><td>Italiano:<br>
 <textarea name=\"n_descrizione_ita\" rows=4 cols=60 style=\"white-space: pre; overflow: auto;\">$d_descrizione</textarea></td>";
 $col = 0;
@@ -843,7 +863,7 @@ echo "</tr></table>
 
 $foto = esegui_query("select * from $tabledescrizioni where nome = '".$idappartamenti."' and tipo = 'appfoto' order by numero ");
 $num_foto = numlin_query($foto);
-echo "".ucfirst(mex("foto dell'appartamento",'unit.php'))." <em>".$idappartamenti."</em>:<br>";
+echo "".ucfirst(mex($fr1."foto dell'appartamento",'unit.php'))." <em>".$idappartamenti."</em>:<br>";
 for ($num1 = 1 ; $num1 <= $num_foto ; $num1++) {
 $url_foto = risul_query($foto,($num1 - 1),'testo');
 $numfoto = risul_query($foto,($num1 - 1),'numero');
@@ -898,7 +918,7 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idappartamenti\" value=\"$idappartamenti\">
-<input class=\"sbutton\" id=\"canc\" type=\"submit\" name=\"cancella_app\" value=\"".mex("Cancella l'appartamento",'unit.php')." $idappartamenti\">
+<input class=\"sbutton\" id=\"canc\" type=\"submit\" name=\"cancella_app\" value=\"".mex($fr1."Cancella l'appartamento",'unit.php')." $idappartamenti\">
 </div><br></form></div>
 
 <hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
