@@ -143,12 +143,19 @@ else include("./includes/head.php");
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 
+$campi_pers = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_cliente' and idutente = '$id_utente'");
+if (numlin_query($campi_pers) == 1) {
+$campi_pers = explode(">",risul_query($campi_pers,0,'valpersonalizza'));
+$num_campi_pers = count($campi_pers);
+} # fine if (numlin_query($campi_pers) == 1)
+else $num_campi_pers = 0;
+
 
 
 if ($cancella_cliente == "SI") {
 $anni = esegui_query("select * from $tableanni order by idanni");
 $num_anni = numlin_query($anni);
-$altre_tab_lock = array("$tableanni");
+$altre_tab_lock = array($tableanni);
 $num_lock = 1;
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."prenota".risul_query($anni,$num1,'idanni');
@@ -499,7 +506,23 @@ if ($c_telefono2) echo mex("Il <b>2° telefono</b> verrà cancellato",$pag).".<b
 if ($c_telefono3) echo mex("Il <b>3° telefono</b> verrà cancellato",$pag).".<br>";
 if ($c_cod_fiscale) echo mex("Il <b>codice fiscale</b> verrà cancellato",$pag).".<br>";
 if ($c_partita_iva) echo mex("La <b>partita iva</b> verrà cancellata",$pag).".<br>";
-echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_cliente.php\"><div>
+
+unset($d_campi_pers);
+for ($num1 = 0 ; $num1 < $d_num_campi_pers ; $num1++) {
+if (!${"n_campo_pers".$num1}) echo mex("Il campo",$pag)." \"<b>".${"d_campo_pers_nome".$num1}."</b>\" ".mex("verrà tolto",$pag).".<br>";
+else {
+if (${"n_campo_pers".$num1} != ${"d_campo_pers".$num1}) echo mex("Il campo",$pag)." \"<b>".${"d_campo_pers_nome".$num1}."</b>\" ".mex("verrà modificato",$pag).".<br>";
+$d_campi_pers['esist'][${"d_campo_pers_nome".$num1}] = 1;
+} # fine else if (!${"d_campo_pers".$num1})
+} # fine for $num1
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) {
+if (${"campo_pers".$num1}) {
+$opt = explode("<",$campi_pers[$num1]);
+if (!$d_campi_pers['esist'][$opt[0]]) echo mex("Il campo",$pag)." \"<b>".$opt[0]."</b>\" ".mex("verrà aggiunto",$pag).".<br>";
+} # fine if (${"campo_pers".$num1})
+} # fine for $num1
+
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_cliente.php\"><div><br>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idclienti\" value=\"$idclienti\">
@@ -544,8 +567,15 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_cliente.p
 <input type=\"hidden\" name=\"n_partita_iva\" value=\"$n_partita_iva\">
 <input type=\"hidden\" name=\"n_commento\" value=\"$n_commento\">
 <input type=\"hidden\" name=\"d_commento\" value=\"$d_commento\">
+<input type=\"hidden\" name=\"d_num_campi_pers\" value=\"$d_num_campi_pers\">";
+for ($num1 = 0 ; $num1 < $d_num_campi_pers ; $num1++) {
+echo "<input type=\"hidden\" name=\"n_campo_pers$num1\" value=\"".${"n_campo_pers".$num1}."\">
+<input type=\"hidden\" name=\"d_campo_pers_nome$num1\" value=\"".${"d_campo_pers_nome".$num1}."\">";
+} # fine for for $num1
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) echo "<input type=\"hidden\" name=\"campo_pers$num1\" value=\"".${"campo_pers".$num1}."\">";
 
-<input type=\"hidden\" name=\"c_nome\" value=\"$c_nome\">
+
+echo "<input type=\"hidden\" name=\"c_nome\" value=\"$c_nome\">
 <input type=\"hidden\" name=\"c_soprannome\" value=\"$c_soprannome\">
 <input type=\"hidden\" name=\"c_titolo_cli\" value=\"$c_titolo_cli\">
 <input type=\"hidden\" name=\"c_datanascita\" value=\"$c_datanascita\">
@@ -580,8 +610,8 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"modifica_cliente.p
 
 
 else {
-$tabelle_lock = array("$tableclienti");
-$altre_tab_lock = array("$tablepersonalizza","$tableutenti");
+$tabelle_lock = array($tableclienti,$tablerelclienti);
+$altre_tab_lock = array($tablepersonalizza,$tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $cliente_esistente = esegui_query("select idclienti from $tableclienti where idclienti = '$idclienti' ");
 if (numlin_query($cliente_esistente) == 1) {
@@ -600,7 +630,38 @@ $n_numcivico = "";
 $n_cap = "";
 } # fine if ($priv_vedi_indirizzo != "s")
 
-inserisci_dati_cliente($n_cognome,$n_nome,$n_soprannome,$n_titolo_cli,$n_sesso,$n_mesenascita,$n_giornonascita,$n_annonascita,$n_nazionenascita,$n_cittanascita,$n_regionenascita,$n_documento,$n_tipodoc,$n_mesescaddoc,$n_giornoscaddoc,$n_annoscaddoc,$n_cittadoc,$n_regionedoc,$n_nazionedoc,$n_nazionalita,$n_lingua_cli,$n_nazione,$n_citta,$n_regione,$n_via,$n_nomevia,$n_numcivico,$n_cap,$n_telefono,$n_telefono2,$n_telefono3,$n_fax,$n_email,$n_cod_fiscale,$n_partita_iva,"",$id_utente,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti);
+unset($d_campi_pers);
+$d_cam_per = esegui_query("select * from $tablerelclienti where idclienti = '$idclienti' and tipo = 'campo_pers' ");
+$d_num_cam_per = numlin_query($d_cam_per);
+for ($num1 = 0 ; $num1 < $d_num_cam_per ; $num1++) {
+$nome_campo_pers = risul_query($d_cam_per,$num1,'testo1');
+$cancella_campo_pers = 1;
+for ($num2 = 0 ; $num2 < $d_num_campi_pers ; $num2++) {
+if ($nome_campo_pers == ${"d_campo_pers_nome".$num2}) {
+if (${"n_campo_pers".$num2}) {
+$cancella_campo_pers = 0;
+$tipo_campo_pers = risul_query($d_cam_per,$num1,'testo2');
+$val_campo_pers = risul_query($d_cam_per,$num1,'testo3');
+if ($tipo_campo_pers == "txt" and $val_campo_pers != ${"n_campo_pers".$num2}) esegui_query("update $tablerelclienti set testo3 = '".aggslashdb(${"n_campo_pers".$num2})."' where idclienti = '$idclienti' and testo1 = '".aggslashdb($nome_campo_pers)."' and tipo = 'campo_pers' ");
+} # fine if (${"n_campo_pers".$num2})
+break;
+} # fine if ($nome_campo_pers == ${"d_campo_pers_nome".$num2})
+} # fine for $num2
+if ($cancella_campo_pers) esegui_query("delete from $tablerelclienti where idclienti = '$idclienti' and testo1 = '".aggslashdb($nome_campo_pers)."' and tipo = 'campo_pers' ");
+else $d_campi_pers['esist'][$nome_campo_pers] = 1;
+} # fine for $num1
+
+$campi_pers_vett = array();
+$campi_pers_vett['num'] = $num_campi_pers;
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) {
+$opt = explode("<",$campi_pers[$num1]);
+$campi_pers_vett[$num1] = $opt[0];
+$campi_pers_vett['tipo'][$num1] = $opt[1];
+if ($d_campi_pers['esist'][$opt[0]]) ${"campo_pers".$num1} = "";
+$campi_pers_vett['val'][$num1] = ${"campo_pers".$num1};
+} # fine for $num1
+
+inserisci_dati_cliente($n_cognome,$n_nome,$n_soprannome,$n_titolo_cli,$n_sesso,$n_mesenascita,$n_giornonascita,$n_annonascita,$n_nazionenascita,$n_cittanascita,$n_regionenascita,$n_documento,$n_tipodoc,$n_mesescaddoc,$n_giornoscaddoc,$n_annoscaddoc,$n_cittadoc,$n_regionedoc,$n_nazionedoc,$n_nazionalita,$n_lingua_cli,$n_nazione,$n_citta,$n_regione,$n_via,$n_nomevia,$n_numcivico,$n_cap,$n_telefono,$n_telefono2,$n_telefono3,$n_fax,$n_email,$n_cod_fiscale,$n_partita_iva,"",$id_utente,$attiva_prefisso_clienti,$prefisso_clienti,$idclienti,"",$campi_pers_vett);
 
 if ($id_nuovo_utente_inserimento != "" and $id_utente == 1) {
 $id_nuovo_utente_inserimento = aggslashdb($id_nuovo_utente_inserimento);
@@ -727,6 +788,8 @@ echo "<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Tor
 
 if ($vedi_cc) {
 if (function_exists('openssl_pkey_new')) {
+if ($_SERVER["HTTPS"] == "on" or $_SERVER["SERVER_PORT"] == "443" or $_SERVER['SERVER_NAME'] == "localhost") {
+
 $cert_cc = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'cert_cc' and idutente = '1'");
 if (numlin_query($cert_cc)) {
 $mostra_form_modifica_cliente = "NO";
@@ -750,13 +813,14 @@ $errore = "SI";
 echo ucfirst(mex("il numero di carta di credito è <span class=\"colred\">sbagliato</span>",$pag));
 } # fine if (preg_replace("/[0-9]*/","",$n_num_cc) != "")
 } # fine if ($n_num_cc)
-if ($n_cvc_cc) {
-$n_cvc_cc = str_replace(" ","",$n_cvc_cc);
-if (preg_replace("/[0-9]*/","",$n_cvc_cc) != "") {
-$errore = "SI";
-echo ucfirst(mex("il numero CVC è <span class=\"colred\">sbagliato</span>",$pag));
-} # fine if (preg_replace("/[0-9]*/","",$n_cvc_cc) != "")
-} # fine if ($n_cvc_cc)
+#if ($n_cvc_cc) {
+#$n_cvc_cc = str_replace(" ","",$n_cvc_cc);
+#if (preg_replace("/[0-9]*/","",$n_cvc_cc) != "") {
+#$errore = "SI";
+#echo ucfirst(mex("il numero CVC è <span class=\"colred\">sbagliato</span>",$pag));
+#} # fine if (preg_replace("/[0-9]*/","",$n_cvc_cc) != "")
+#} # fine if ($n_cvc_cc)
+$n_cvc_cc = "";
 
 if ($errore != "SI") {
 $cert_cc = risul_query($cert_cc,0,'valpersonalizza');
@@ -776,11 +840,11 @@ esegui_query("update $tablerelclienti set testo2 = '".aggslashdb($val_crypt)."'
 } # fine if ($n_num_cc)
 if ($n_nome_cc) esegui_query("update $tablerelclienti set testo3 = '".aggslashdb($n_nome_cc)."' where idclienti = '$idclienti' and tipo = 'cc' ");
 if ($n_datascadcc) esegui_query("update $tablerelclienti set testo4 = '".aggslashdb($n_datascadcc)."' where idclienti = '$idclienti' and tipo = 'cc' ");
-if ($n_cvc_cc) {
+/*if ($n_cvc_cc) {
 openssl_public_encrypt($n_cvc_cc,$val_crypt,$pub_key);
 $val_crypt = base64_encode($val_crypt);
 esegui_query("update $tablerelclienti set testo5 = '".aggslashdb($val_crypt)."' where idclienti = '$idclienti' and tipo = 'cc' ");
-} # fine if ($n_cvc_cc)
+} # fine if ($n_cvc_cc)*/
 echo ucfirst(mex("i dati della carta di credito sono stati inseriti",$pag));
 } # fine if ($errore != "SI")
 
@@ -843,8 +907,8 @@ if ($d_num_cc) openssl_private_decrypt(base64_decode($d_num_cc),$d_num_cc,$res_p
 $d_nome_cc = risul_query($dati_carta,0,'testo3');
 $d_scad_cc = risul_query($dati_carta,0,'testo4');
 if ($d_scad_cc) $d_scad_cc_f = substr($d_scad_cc,5,2)."-".substr($d_scad_cc,0,4);
-$d_cvc_cc = risul_query($dati_carta,0,'testo5');
-if ($d_cvc_cc) openssl_private_decrypt(base64_decode($d_cvc_cc),$d_cvc_cc,$res_pk);
+#$d_cvc_cc = risul_query($dati_carta,0,'testo5');
+#if ($d_cvc_cc) openssl_private_decrypt(base64_decode($d_cvc_cc),$d_cvc_cc,$res_pk);
 } # fine if (numlin_query($dati_carta))
 $cliente = esegui_query("select * from $tableclienti where idclienti = '$idclienti'");
 if (numlin_query($cliente)) {
@@ -891,13 +955,14 @@ for ($num1 = 0; $num1 < 15; $num1++) {
 $num = $anno_corr + $num1;
 echo "<option value=\"$num\">$num</option>";
 } # fine for $num1
-echo "</select></td></tr>
+echo "</select></td></tr>";
 
-<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("CVC",$pag).": <b>$d_cvc_cc</b></td>
+/*echo "<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("CVC",$pag).": <b>$d_cvc_cc</b></td>
 <td>".mex("cambia in",$pag).": 
 <input type=\"text\" name=\"n_cvc_cc\" size=\"6\"></td></tr>
-<tr><td style=\"height: 1px;\"></td></tr></table>
+<tr><td style=\"height: 1px;\"></td></tr>";*/
 
+echo "</table>
 <div style=\"text-align: center;\">
 <input class=\"sbutton\" type=\"submit\" value=\"".ucfirst(mex("modifica i dati della carta di credito",$pag))."\">
 </div></div></form>";
@@ -931,6 +996,8 @@ echo "<br><br><div style=\"text-align: center;\">
 <input class=\"sbutton\" type=\"submit\" value=\"".mex("Torna indietro",$pag)."\">
 </div></div></form>";
 } # fine if (numlin_query($cert_cc))
+} # fine if ($_SERVER["HTTPS"] == "on" or $_SERVER["SERVER_PORT"] == "443" or...
+else echo "<span class=\"colred\">".mex("I dati della carta di credito possono essere visti solo su una connessione sicura",$pag)."</span>.<br><br>";
 } # fine if (function_exists('openssl_pkey_new'))
 } # fine if ($vedi_cc)
 
@@ -968,6 +1035,7 @@ $d_email = risul_query($cliente,0,'email');
 $d_telefono2 = risul_query($cliente,0,'telefono2');
 $d_telefono3 = risul_query($cliente,0,'telefono3');
 } # fine if ($priv_vedi_telefoni == "s")
+
 $d_datanascita = risul_query($cliente,0,'datanascita');
 if ($d_datanascita) $d_datanascita_f = formatta_data($d_datanascita,$stile_data);
 $d_documento = risul_query($cliente,0,'documento');
@@ -1002,6 +1070,15 @@ elseif ($d_cittadoc) $citta_def = $d_cittadoc;
 elseif ($d_cittanascita) $citta_def = $d_cittanascita;
 $citta_def = addslashes($citta_def);
 
+$d_cam_per = esegui_query("select * from $tablerelclienti where idclienti = '$idclienti' and tipo = 'campo_pers' ");
+$d_num_campi_pers = numlin_query($d_cam_per);
+for ($num1 = 0 ; $num1 < $d_num_campi_pers ; $num1++) {
+$d_campi_pers[$num1]['nome'] = risul_query($d_cam_per,$num1,'testo1');
+$d_campi_pers[$num1]['tipo'] = risul_query($d_cam_per,$num1,'testo2');
+$d_campi_pers[$num1]['val'] = risul_query($d_cam_per,$num1,'testo3');
+$d_campi_pers['esist'][$d_campi_pers[$num1]['nome']] = 1;
+} # fine for $num1
+
 echo "<table cellspacing=0 cellpadding=0 border=0 width=\"97%\">
 <tr><td align=\"right\" style=\"font-size: 80%;\">";
 $pass_cc = 0;
@@ -1287,8 +1364,42 @@ echo "<tr style=\"background-color: ".rowbgcolor().";\"><td>".mex("Codice fiscal
 <input type=\"text\" name=\"n_partita_iva\">
 <br><label><input type=\"checkbox\" name=\"c_partita_iva\" value=\"SI\">".mex("cancella",$pag)."</label></td></tr>
 </table>
+<div style=\"clear: both; padding: 6px 0 0 0;\">";
 
-<div style=\"clear: both; padding: 6px 0 0 0;\">".mex("Commento",$pag).":<div>
+if ($d_num_campi_pers or $num_campi_pers) {
+echo "<table cellspacing=0 cellpadding=0><tr>";
+$pari = 0;
+for ($num1 = 0 ; $num1 < $d_num_campi_pers ; $num1++) {
+if ($d_campi_pers[$num1]['tipo'] == "txt") echo "<td><b>".$d_campi_pers[$num1]['nome']."</b>: <input type=\"text\" name=\"n_campo_pers$num1\" value=\"".$d_campi_pers[$num1]['val']."\"></td>";
+else echo "<td><label><input type=\"checkbox\" name=\"n_campo_pers$num1\" value=\"1\" checked><b>".$d_campi_pers[$num1]['nome']."</b></label></td>";
+if ($pari) {
+$pari = 0;
+echo "</tr><tr>";
+} # fine if ($pari)
+else {
+$pari = 1;
+echo "<td style=\"width: 50px;\">&nbsp;</td>";
+} # fine else if ($pari)
+} # fine for $num1
+for ($num1 = 0 ; $num1 < $num_campi_pers ; $num1++) {
+$opt = explode("<",$campi_pers[$num1]);
+if (!$d_campi_pers['esist'][$opt[0]]) {
+if ($opt[1] == "txt") echo "<td>".$opt[0].": <input type=\"text\" name=\"campo_pers$num1\" value=\"".${"campo_pers".$num1}."\"></td>";
+else echo "<td><label><input type=\"checkbox\" name=\"campo_pers$num1\" value=\"1\">".$opt[0]."</label></td>";
+if ($pari) {
+$pari = 0;
+echo "</tr><tr>";
+} # fine if ($pari)
+else {
+$pari = 1;
+echo "<td style=\"width: 50px;\">&nbsp;</td>";
+} # fine else if ($pari)
+} # fine if (!$d_campi_pers['esist'][$opt[0]])
+} # fine for $num1
+echo "</tr></table><div style=\"height: 6px;\"></div>";
+} # fine if ($d_num_campi_pers or $num_campi_pers)
+
+echo "".mex("Commento",$pag).":<div>
 <textarea name=\"n_commento\" rows=3 cols=45 style=\"white-space: pre; overflow: auto;\">$d_commento</textarea><br>";
 
 
@@ -1325,8 +1436,14 @@ echo "<div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"d_email\" value=\"$d_email\">
 <input type=\"hidden\" name=\"d_nome_lingua\" value=\"$d_nome_lingua\">
 <input type=\"hidden\" name=\"d_commento\" value=\"$d_commento\">
+<input type=\"hidden\" name=\"d_num_campi_pers\" value=\"$d_num_campi_pers\">";
+for ($num1 = 0 ; $num1 < $d_num_campi_pers ; $num1++) {
+echo "<input type=\"hidden\" name=\"d_campo_pers$num1\" value=\"".$d_campi_pers[$num1]['val']."\">
+<input type=\"hidden\" name=\"d_campo_pers_nome$num1\" value=\"".$d_campi_pers[$num1]['nome']."\">";
+} # fine for $num1
 
-<input class=\"sbutton\" id=\"modi\" type=\"submit\" name=\"modifica_cliente\" value=\"".mex("Modifica i dati del cliente",$pag)."\">
+
+echo "<input class=\"sbutton\" id=\"modi\" type=\"submit\" name=\"modifica_cliente\" value=\"".mex("Modifica i dati del cliente",$pag)."\">
 </div></div></form>";
 
 if ($origine_vecchia) $origine = $origine_vecchia;
@@ -1367,9 +1484,12 @@ echo "<div style=\"text-align: center;\"><hr style=\"width: 95%\">
 <input type=\"hidden\" name=\"fax_1\" value=\"$d_fax\">
 <input type=\"hidden\" name=\"cap_1\" value=\"$d_cap\">
 <input type=\"hidden\" name=\"email_1\" value=\"$d_email\">
-<input type=\"hidden\" name=\"codice_lingua_1\" value=\"$d_lingua_cli\">
+<input type=\"hidden\" name=\"codice_lingua_1\" value=\"$d_lingua_cli\">";
+for ($num1 = 0 ; $num1 < $d_num_campi_pers ; $num1++) {
+echo "<input type=\"hidden\" name=\"campo_personalizzato_".$d_campi_pers[$num1]['nome']."_1\" value=\"".$d_campi_pers[$num1]['val']."\">";
+} # fine for $num1
 
-".ucfirst(mex("documento di tipo",$pag))."
+echo "".ucfirst(mex("documento di tipo",$pag))."
  <select id=\"lcon\" name=\"numero_contratto\">";
 $nomi_contratti = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'nomi_contratti' and idutente = '$id_utente'");
 $nomi_contratti = risul_query($nomi_contratti,0,'valpersonalizza');
