@@ -1131,6 +1131,13 @@ $linea_mod = "<tr><td><a name=\"contr_txtbox".$lingue[$num_lingua]."\"></a>
 ".mex("Variabili",$pag).":
  <select name=\"var_agg\">";
 
+$campi_pers_cliente = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'campi_pers_cliente' and idutente = '$id_utente' ");
+if (numlin_query($campi_pers_cliente)) {
+$campi_pers_cliente = explode(">",risul_query($campi_pers_cliente,0,'valpersonalizza'));
+$num_campi_pers_cliente = count($campi_pers_cliente);
+} # fine if (numlin_query($campi_pers_cliente))
+else $num_campi_pers_cliente = 0;
+$campo_personalizzato_ = mex2("campo_personalizzato")."_";
 include("./includes/variabili_contratto.php");
 $num_var_predef--;
 $num_int_contr = $num_contratto;
