@@ -260,7 +260,8 @@ if (strcmp($valore_f_ca,"") and controlla_soldi($valore_f_ca) == "NO") $errore =
 if (strcmp($valore_p_ca,"") and (controlla_soldi($valore_p_ca) == "NO" or !strcmp($arrotonda_ca,"") or controlla_soldi($arrotonda_ca,"SI") == "NO")) $errore = "SI";
 if ($valore_p_ca and $tipo_percentuale != "tariffa" and $tipo_percentuale != "tariffafissa" and $tipo_percentuale != "tariffapers" and $tipo_percentuale != "totale" and $tipo_percentuale != "caparra" and $tipo_percentuale != "resto") $errore = "SI";
 if ($valore_p_ca and $tipo_ca == "s" and substr($tipo_percentuale,0,7) != "tariffa") { $errore = "SI"; $conflitti .= "2-3;"; }
-if (($tasseperc_ca and controlla_soldi($tasseperc_ca) == "NO") or $tasseperc_ca > 100) $errore = "SI";
+if (($tasseperc_ca and controlla_soldi($tasseperc_ca) == "NO") or $tasseperc_ca > 100 or $tasseperc_ca < 0) $errore = "SI";
+if ($tipo_tasse != "p" and $tipo_tasse != "t") $errore = "SI";
 
 $associa_tariffe_prec = 0;
 if ($tipo_ca != "s") $associasett = "";
@@ -372,13 +373,13 @@ else {
 $file_date_int = implode("",file(C_DATI_PATH."/selectperiodi$anno.1.php"));
 $ultima_data = 0;
 for ($num1 = 1 ; $num1 <= $num_periodi_permessi_sel ; $num1++) {
-if (str_replace("\\\"".${"pp_dal".$num1}."\\\">","",$file_date_int) == $file_date_int) $errore = "SI";
-if (str_replace("\\\"".${"pp_al".$num1}."\\\">","",$file_date_int) == $file_date_int) $errore = "SI";
+if (str_replace("\\\"".${"pp_dal".$num1}."\\\">","",$file_date_int) == $file_date_int) { $errore = "SI"; $conflitti .= "13;"; }
+if (str_replace("\\\"".${"pp_al".$num1}."\\\">","",$file_date_int) == $file_date_int) { $errore = "SI"; $conflitti .= "13;"; }
 $nuova_ultima_data = str_replace("-","",${"pp_dal".$num1});
-if ($nuova_ultima_data <= $ultima_data) $errore = "SI";
+if ($nuova_ultima_data <= $ultima_data) { $errore = "SI"; $conflitti .= "13;"; }
 else $ultima_data = $nuova_ultima_data;
 $nuova_ultima_data = str_replace("-","",${"pp_al".$num1});
-if ($nuova_ultima_data <= $ultima_data) $errore = "SI";
+if ($nuova_ultima_data <= $ultima_data) { $errore = "SI"; $conflitti .= "13;"; }
 else $ultima_data = $nuova_ultima_data;
 } # fine for $num1
 } # fine else if (controlla_num_pos($num_periodi_permessi_sel) == "NO" or...
@@ -547,6 +548,7 @@ if ($tipo_valore_ca != "f" and $arrotonda_ca != $dati_ca[$num_costo]['arrotonda'
 esegui_query("update $tablenometariffe set arrotonda_ca = '$arrotonda_ca' where idntariffe = '$idntariffe'");
 $modificato = "SI";
 } # fine if ($tipo_valore_ca != "f" and $arrotonda_ca != $dati_ca[$num_costo]['arrotonda'])
+if ($tipo_tasse == "t") $tasseperc_ca = -1;
 if ($tasseperc_ca != $dati_ca[$num_costo]['tasseperc']) {
 if (!strcmp($tasseperc_ca,"")) esegui_query("update $tablenometariffe set tasseperc_ca = NULL where idntariffe = '$idntariffe'");
 else esegui_query("update $tablenometariffe set tasseperc_ca = '$tasseperc_ca' where idntariffe = '$idntariffe'");
@@ -675,8 +677,11 @@ if ($conflitti) {
 echo "<br>".mex("Opzioni in conflitto",$pag).":<br>";
 $conflitti = explode(";",substr($conflitti,0,-1));
 for ($num1 = 0 ; $num1 < count($conflitti) ; $num1++) {
+if (strstr($conflitti[$num1],"-")) {
 $opz = explode("-",$conflitti[$num1]);
 echo "&nbsp;<em>".$opz[0]."</em> ".mex("e",$pag)." <em>".$opz[1]."</em><br>";
+} # fine if (strstr($conflitti[$num1],"-"))
+else echo "&nbsp;<em>$conflitti[$num1]</em><br>";
 } # fine for $num1
 echo "<br>";
 } # fine if ($conflitti)
@@ -693,24 +698,11 @@ echo "<br><div style=\"text-align: center;\">
 unlock_tabelle($tabelle_lock);
 
 if ($modifica_costo and $errore != "SI" and $modificato == "SI") {
-$file_interconnessioni = C_DATI_PATH."/dati_interconnessioni.php";
-if (@is_file($file_interconnessioni)) {
-include($file_interconnessioni);
-if (@is_array($ic_present)) {
-$interconn_dir = opendir("./includes/interconnect/");
-while ($mod_ext = readdir($interconn_dir)) {
-if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) {
-include("./includes/interconnect/$mod_ext/name.php");
-if ($ic_present[$interconnection_name] == "SI") {
-$funz_update_rates = "update_rates_".$interconnection_name;
-if (!function_exists($funz_update_rates)) include("./includes/interconnect/$mod_ext/functions.php");
-$funz_update_rates($file_interconnessioni,$anno,$PHPR_TAB_PRE,1);
-} # fine if ($ic_present[$interconnection_name] == "SI")
-} # fine if ($modello_ext != "." and $modello_ext != ".." and...
-} # fine while ($mod_ext = readdir($interconn_dir))
-closedir($interconn_dir);
-} # fine if (@is_array($ic_present))
-} # fine if (@is_file($file_interconnessioni))
+$lock = 1;
+$aggiorna_disp = 0;
+$aggiorna_tar = 1;
+if (@function_exists('pcntl_fork')) include("./includes/interconnect/aggiorna_ic_fork.php");
+else include("./includes/interconnect/aggiorna_ic.php");
 } # fine if ($modifica_costo and $errore != "SI" and $modificato == "SI")
 
 
@@ -829,12 +821,17 @@ $d_arrotond = esegui_query("select valpersonalizza from $tablepersonalizza where
 $d_arrotond = risul_query($d_arrotond,0,'valpersonalizza');
 } # fine if (!strcmp($d_arrotond,""))
 echo "</select> ".mex("arrotondato a",$pag)."
- <input type=\"text\" name=\"arrotonda_ca\" value=\"$d_arrotond\" size=\"5\">$Euro</td></tr>
+ <input type=\"text\" name=\"arrotonda_ca\" value=\"$d_arrotond\" size=\"5\">$Euro</td></tr>";
 
-<tr><td style=\"height: 2px;\"></td></tr>
+if ($d_tasseperc == -1) { $checked_p = ""; $checked_t = " checked"; $d_tasseperc = 0; }
+else { $checked_p = " checked"; $checked_t = ""; }
+ echo "<tr><td style=\"height: 2px;\"></td></tr>
 <tr><td valign=\"top\"><small>4. </small>".mex("Tasse",$pag).":</td>
-<td><input type=\"text\" name=\"tasseperc_ca\" size=\"5\" maxlength=\"5\" value=\"$d_tasseperc\">%
- (".mex("il valore del costo si intente con tasse già incluse","creaprezzi.php").")
+<td><input type=\"radio\" id=\"t_tas\" name=\"tipo_tasse\" value=\"p\"$checked_p>
+<input type=\"text\" name=\"tasseperc_ca\" size=\"5\" maxlength=\"5\" value=\"$d_tasseperc\" onclick=\"document.getElementById('t_tas').checked='1';\"><label for=\"t_tas\">%
+ (".mex("il valore del costo si intente con tasse già incluse",'creaprezzi.php').")</label><br>
+ <label><input type=\"radio\" name=\"tipo_tasse\" value=\"t\"$checked_t>
+".mex("considerare l'intero costo come tasse",'creaprezzi.php')."</label>
 </td></tr>
 
 <tr><td style=\"height: 2px;\"></td></tr>
@@ -851,6 +848,8 @@ else elem_valminmax2.innerHTML = ' ".mex("e",$pag)." <input type=\"text\" name=\
 -->
 </script>
 ";
+$default_tipo_associa = "p";
+for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) if ($dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa]) $default_tipo_associa = $dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa];
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI") {
 $tariffa = "tariffa".$numtariffa;
@@ -902,13 +901,15 @@ echo "-->
 </td>";
 if ($dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa] == "p") { $checked = " checked"; $b2 = $b; $b_slash2 = $b_slash; }
 else { $checked = ""; $b2 = ""; $b_slash2 = ""; }
-if (!$dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa]) $checked = " checked";
+if (!$dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa] and $default_tipo_associa == "p") $checked = " checked";
 echo "<td>&nbsp;<label><input type=\"radio\" name=\"tipo_associa_tariffa$numtariffa\" value=\"p\"$checked> <small>$b2".mex("Se possibile",$pag)."$b_slash2</small></label></td>";
 if ($dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa] == "r") { $checked = " checked"; $b2 = $b; $b_slash2 = $b_slash; }
 else { $checked = ""; $b2 = ""; $b_slash2 = ""; }
+if (!$dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa] and $default_tipo_associa == "r") $checked = " checked";
 echo "<td>&nbsp;<label><input type=\"radio\" name=\"tipo_associa_tariffa$numtariffa\" value=\"r\"$checked> <small>$b2".mex("Sempre in periodi permessi",$pag)."$b_slash2</small></label></td>";
 if ($dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa] == "s") { $checked = " checked"; $b2 = $b; $b_slash2 = $b_slash; }
 else { $checked = ""; $b2 = ""; $b_slash2 = ""; }
+if (!$dati_ca[$num_costo]["tipo_associa_tariffa".$numtariffa] and $default_tipo_associa == "s") $checked = " checked";
 echo "<td>&nbsp;<label><input type=\"radio\" name=\"tipo_associa_tariffa$numtariffa\" value=\"s\"$checked> <small>$b2".mex("Sempre",$pag)."$b_slash2</small></label></td>";
 echo "</tr><tr><td style=\"height: 5px;\"></td></tr></table>";
 } # fine if ($attiva_tariffe_consentite == "n" or...
