@@ -48,6 +48,7 @@ $tableregioni = $PHPR_TAB_PRE."regioni";
 $tablecitta = $PHPR_TAB_PRE."citta";
 $tabledocumentiid = $PHPR_TAB_PRE."documentiid";
 $tableparentele = $PHPR_TAB_PRE."parentele";
+$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -193,6 +194,7 @@ $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 
 unset($num_persone_tot_idpr);
+unset($app_letto_idpr);
 for ($num_idpr = 0 ; $num_idpr < $num_id_prenota ; $num_idpr++) {
 $id_prenota = $id_prenota_idpr[$num_idpr];
 unset($num_letti_agg);
@@ -205,6 +207,10 @@ if ($d_num_persone) $num_persone_tot = $d_num_persone;
 else $num_persone_tot = 0;
 if ($num_letti_agg['max'] != 0) $num_persone_tot = $num_persone_tot + $num_letti_agg['max'];
 $num_persone_tot_idpr[$num_idpr] = $num_persone_tot;
+$d_idapp = risul_query($dati_prenota[$id_prenota],0,'idappartamenti');
+$d_idapp = esegui_query("select idappartamenti from $tableappartamenti where idappartamenti = '".aggslashdb($d_idapp)."' and letto = '1' ");
+if (numlin_query($d_idapp)) $app_letto_idpr[$num_idpr] = 1;
+else $app_letto_idpr[$num_idpr] = 0;
 } # fine for $num_idpr
 
 
@@ -261,12 +267,16 @@ $d_num_ospiti = numlin_query($ospiti);
 for ($num1 = 0 ; $num1 < $d_num_ospiti ; $num1++) $osp_presente[risul_query($ospiti,$num1,'idclienti')] = ($num1 + 1);
 
 if ($principale != $idclienti) {
-if ($osp_presente[$principale]) {
+if ($osp_presente[$principale] and ${"ospite".$id_prenota."_".$principale} == "SI") {
+if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0) $mess_letto = 1;
+else {
 $num_ospiti++;
 $lista_ospiti[$num_ospiti] = $principale;
 $lista_ospiti['lista'] .= $principale.",";
 $presente_id[$principale] = "SI";
-} # fine if ($osp_presente[$principale])
+} # fine else if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0)
+} # fine if ($osp_presente[$principale] and ${"ospite".$id_prenota."_".$principale} == "SI")
+else $principale = "";
 } # fine if ($principale != $idclienti)
 
 unset($n_parentela);
@@ -277,7 +287,13 @@ if ($id_clienti_osp and $id_clienti_osp != $principale) {
 if ($osp_presente[$id_clienti_osp]) {
 $dati_ospite = esegui_query("select idclienti_compagni from $tableclienti where idclienti = '$id_clienti_osp' ");
 $idclienti_compagni .= substr(risul_query($dati_ospite,0,'idclienti_compagni'),1);
+$canc_ospite = 0;
 if (${"ospite".$id_prenota."_".$id_clienti_osp} == "SI") {
+if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0) {
+$mess_letto = 1;
+$canc_ospite = 1;
+} # fine if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0)
+else {
 $num_ospiti++;
 $lista_ospiti[$num_ospiti] = $id_clienti_osp;
 $lista_ospiti['lista'] .= $id_clienti_osp.",";
@@ -290,11 +306,15 @@ if ($parentela != $d_parentela) {
 esegui_query("update $tablerclientiprenota set parentela = '".aggslashdb($parentela)."' where idprenota = '$id_prenota' and idclienti = '$id_clienti_osp' ");
 $lista_parentela_cambiata .= " and idclienti != '$id_clienti_osp'";
 } # fine if ($parentela != $d_parentela)
+} # fine else if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0)
 } # fine if (${"ospite".$id_prenota."_".$id_clienti_osp} == "SI")
-else esegui_query("delete from $tablerclientiprenota where idprenota = '$id_prenota' and idclienti = '$id_clienti_osp' ");
+else $canc_ospite = 1;
+if ($canc_ospite) esegui_query("delete from $tablerclientiprenota where idprenota = '$id_prenota' and idclienti = '$id_clienti_osp' ");
 } # fine if ($osp_presente[$id_clienti_osp])
 } # fine if ($id_clienti_osp and...
 if (!$id_clienti_osp and ${"cognome".$id_prenota."_".$num1} and $inserimento_nuovi_clienti == "SI") {
+if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0) $mess_letto = 1;
+else {
 $cognome_aux = ${"cognome".$id_prenota."_".$num1};
 $nome_aux = ${"nome".$id_prenota."_".$num1};
 $titolo_cli_aux = ${"titolo_cli".$id_prenota."_".$num1};
@@ -333,6 +353,7 @@ $lista_ospiti[$num_ospiti] = $id_clienti_ins;
 $n_parentela[$num_ospiti] = ${"parentela".$id_prenota."_".$num1};
 $lista_ospiti['lista'] .= $id_clienti_ins.",";
 $presente_id[$id_clienti_ins] = "SI";
+} # fine else if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0)
 } # fine if (!$id_clienti_osp and ${"cognome".$id_prenota."_".$num1} and...
 } # fine for $num1
 
@@ -384,6 +405,7 @@ if ($n_idclienti_compagni != $d_idclienti_compagni) esegui_query("update $tablec
 } # fine for $num_idpr
 unlock_tabelle($tabelle_lock);
 
+if ($mess_letto) echo "".mex("[1]Ogni appartamento può contenere al <span class=\"colred\">massimo un ospite</span>",'unit.php').".<br><br>";
 if ($num_id_prenota == 1) echo "".mex("Gli ospiti della prenotazione",$pag)." $id_prenota";
 else echo "".mex("Gli ospiti delle prenotazioni",$pag)." ".str_replace(",",", ",$id_prenota_int);
 echo " ".mex("sono stati modificati",$pag).".<br><br>
@@ -479,9 +501,10 @@ $dati_ospite = esegui_query("select * from $tableclienti where idclienti = '$id_
 $utente_ospite = risul_query($dati_ospite,0,'utente_inserimento');
 if (($modifica_clienti == "PROPRI" and $utente_ospite != $id_utente) or ($modifica_clienti == "GRUPPI" and !$utenti_gruppi[$utente_ospite])) echo "<br>".($num1 + $agg_num).".";
 else echo "<br><a$stile href=\"$url_mod_cli\">".($num1 + $agg_num).".</a>";
-echo " <input name=\"ospite$id_prenota"."_".$id_clienti_osp."\" value=\"SI\" type=\"checkbox\" checked>";
+echo " <label><input name=\"ospite$id_prenota"."_".$id_clienti_osp."\" value=\"SI\" type=\"checkbox\" checked>";
 if (($vedi_clienti == "PROPRI" and $utente_ospite != $id_utente) or ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_ospite])) echo "".mex("Cliente",$pag)." $id_clienti_osp";
 else mostra_dati_cliente($dati_ospite,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
+echo "</label>";
 if ($num1 == 0) {
 $checked = " checked";
 $cognome_def = $dcognome;
