@@ -96,8 +96,16 @@ if ($trad_var[$mess_vett[1]]) $messaggio = $mess_vett[0]."(".$trad_var[$mess_vet
 return $messaggio;
 } # fine function mex2
 
+$campi_pers_cliente = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'campi_pers_cliente' and idutente = '$id_utente' ");
+if (numlin_query($campi_pers_cliente)) {
+$campi_pers_cliente = explode(">",risul_query($campi_pers_cliente,0,'valpersonalizza'));
+$num_campi_pers_cliente = count($campi_pers_cliente);
+} # fine if (numlin_query($campi_pers_cliente))
+else $num_campi_pers_cliente = 0;
+$campo_personalizzato_ = mex2("campo_personalizzato")."_";
 include("./includes/variabili_contratto.php");
 
+
 if ($canc_se and $num_se > 1) {
 $cambia_qualcosa = "";
 $num_se--;
@@ -175,7 +183,7 @@ if (preg_replace("/[A-Za-z0-9_]/","",$nuova_var_pers) != "") $continua = "NO";
 $ultima_parte = explode("_",$nuova_var_pers);
 $ultima_parte = (string) $ultima_parte[(count($ultima_parte) - 1)];
 if ($ultima_parte != "" and preg_replace("/[0-9]/","",$ultima_parte) == "") $continua = "NO";
-if ($var_riserv[$nuova_var_pers]) $continua = "NO";
+if ($var_riserv[$nuova_var_pers] or substr($nuova_var_pers,0,20) == "campo_personalizzato") $continua = "NO";
 if ($continua == "SI") {
 $tabelle_lock = array("$tablecontratti");
 $tabelle_lock = lock_tabelle($tabelle_lock);
