@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -49,6 +49,7 @@ $tablecosti = $PHPR_TAB_PRE."costi".$anno;
 $tablerclientiprenota = $PHPR_TAB_PRE."rclientiprenota".$anno;
 $tablerelinventario = $PHPR_TAB_PRE."relinventario";
 $tablecasse = $PHPR_TAB_PRE."casse";
+$tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -162,7 +163,7 @@ $stile_data = stile_data();
 
 
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
-$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num']);
+$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO","",$tableappartamenti);
 $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 $attiva_checkin = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'attiva_checkin' and idutente = '$id_utente'");
 $attiva_checkin = risul_query($attiva_checkin,0,'valpersonalizza');
