@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -34,6 +34,7 @@ $tablenometariffe = $PHPR_TAB_PRE."ntariffe".$anno;
 $tableprenota = $PHPR_TAB_PRE."prenota".$anno;
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tabledescrizioni = $PHPR_TAB_PRE."descrizioni";
+$tableregole = $PHPR_TAB_PRE."regole".$anno;
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -78,20 +79,21 @@ if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$t
 else include("./includes/head.php");
 
 
+include("./includes/funzioni_tariffe.php");
 $Euro = nome_valuta();
 $stile_soldi = stile_soldi();
 $stile_data = stile_data();
 
 unset($tabelle_lock);
-#$tabelle_lock = array($tableprenota);
-$altre_tab_lock = array($tableperiodi,$tablenometariffe);
+$tabelle_lock = array();
+$altre_tab_lock = array($tableperiodi,$tablenometariffe,$tableregole);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 $periodi = esegui_query("select * from $tableperiodi order by idperiodi");
-$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
+$dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
 unlock_tabelle($tabelle_lock);
 
-$numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
+$numero_tariffe = $dati_tariffe['num'];
 if (!$num_tariffe_mostra) $num_tariffe_mostra = 1;
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if (${"numtariffa".$num1} < 1 or ${"numtariffa".$num1} > $numero_tariffe) {
@@ -232,7 +234,7 @@ else $datafine_periodi = "1970-01-01";
 
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 $tariffa[$num1] = "tariffa".${"numtariffa".$num1};
-$nometariffa[$num1] = risul_query($rigatariffe,0,$tariffa[$num1]);
+$nometariffa[$num1] = $dati_tariffe[$tariffa[$num1]]['nome'];
 if (!strcmp($nometariffa[$num1],"")) {
 $nometariffa_vedi[$num1] = mex("tariffa",$pag).${"numtariffa".$num1};
 $nometariffa[$num1] = $nometariffa_vedi[$num1];
@@ -247,6 +249,7 @@ $num_colonne_periodi = 0;
 $nuova_colonna = "NO";
 unset($tariffa_colonna_periodo);
 unset($tariffap_colonna_periodo);
+unset($chiusa_colonna_periodo);
 $ini_colonna_periodo[0] = risul_query($periodi,0,'datainizio');
 $ini_colonna_periodo[0] = formatta_data($ini_colonna_periodo[0],$stile_data);
 $sett_in_per = 0;
@@ -257,9 +260,10 @@ $sett_in_per++;
 $datafine = risul_query($periodi,($sett_in_per - 1),'datafine');
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
-$tar_corr = (string) risul_query($periodi,0,$tariffa[$num1]);
-$tarp_corr = (string) risul_query($periodi,0,$tariffa[$num1]."p");
+$tar_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]);
+$tarp_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]."p");
 if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,""))) {
+if ($sett_in_per == 1) $chiusa_colonna_periodo[$num1][0] = "";
 $tariffa_colonna_periodo[$num1][0] = $tar_corr;
 $tariffap_colonna_periodo[$num1][0] = $tarp_corr;
 } # fine if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,"")))
@@ -269,6 +273,7 @@ if (!strcmp($tariffap_colonna_periodo[$num1][0],"")) $tariffap_colonna_periodo[$
 $tariffa_colonna_periodo[$num1][0] += (double) $tar_corr;
 $tariffap_colonna_periodo[$num1][0] += (double) $tarp_corr;
 } # fine elseif (strcmp($tariffa_colonna_periodo[$num1][0],"") or strcmp($tariffap_colonna_periodo[$num1][0],""))
+if ($dati_tariffe[$tariffa[$num1]]['chiusa'][risul_query($periodi,($sett_in_per - 1),'idperiodi')]) $chiusa_colonna_periodo[$num1][0] = 1;
 } # fine if ($attiva_tariffe_consentite == "n" or...
 } # fine for $num1
 } # fine while ($sett_in_per == 0 or...
@@ -289,6 +294,7 @@ $tarp_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]."p");
 if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,""))) {
 ${$tariffa[$num2]} = $tar_corr;
 ${$tariffa[$num2]."p"} = $tarp_corr;
+if ($sett_in_per == 1) ${$tariffa[$num2]."c"} = "";
 } # fine if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,"")))
 elseif (strcmp(${$tariffa[$num2]},"") or strcmp(${$tariffa[$num2]."p"},"")) {
 if (!strcmp(${$tariffa[$num2]},"")) ${$tariffa[$num2]} = 0;
@@ -296,6 +302,7 @@ if (!strcmp(${$tariffa[$num2]."p"},"")) ${$tariffa[$num2]."p"} = 0;
 ${$tariffa[$num2]} += (double) $tar_corr;
 ${$tariffa[$num2]."p"} += (double) $tarp_corr;
 } # fine elseif (strcmp(${$tariffa[$num2]},"") or strcmp(${$tariffa[$num2]."p"},""))
+if ($dati_tariffe[$tariffa[$num2]]['chiusa'][risul_query($periodi,$num1,'idperiodi')]) ${$tariffa[$num2]."c"} = 1;
 } # fine if ($attiva_tariffe_consentite == "n" or...
 } # fine for $num2
 } # fine while ($sett_in_per == 0 or...
@@ -304,6 +311,7 @@ for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI") {
 if ((string) ${$tariffa[$num2]} != (string) $tariffa_colonna_periodo[$num2][$num_colonne_periodi]) $nuova_colonna = "SI";
 if ((string) ${$tariffa[$num2]."p"} != (string) $tariffap_colonna_periodo[$num2][$num_colonne_periodi]) $nuova_colonna = "SI";
+if (${$tariffa[$num2]."c"} != $chiusa_colonna_periodo[$num2][$num_colonne_periodi]) $nuova_colonna = "SI";
 } # fine if ($attiva_tariffe_consentite == "n" or...
 } # fine for $num2
 
@@ -318,6 +326,7 @@ for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI") {
 $tariffa_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]};
 $tariffap_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]."p"};
+$chiusa_colonna_periodo[$num2][$num_colonne_periodi] = ${$tariffa[$num2]."c"};
 } # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num2}] == "SI")
 } # fine for $num2
 $nuova_colonna = "NO";
@@ -340,16 +349,18 @@ for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
 echo "<tr><td align=\"center\">".$nometariffa_vedi[$num1]."</td>";
 for ($num2 = 0 ; $num2 <= $num_colonne_periodi ; $num2++) {
-if (!strcmp($tariffa_colonna_periodo[$num1][$num2],"") and !strcmp($tariffap_colonna_periodo[$num1][$num2],"")) $tariffa_vedi = "&nbsp;";
+if (!$tariffa_colonna_periodo[$num1][$num2] and !$tariffap_colonna_periodo[$num1][$num2]) $tariffa_vedi = "&nbsp;";
 else {
-if (strcmp($tariffa_colonna_periodo[$num1][$num2],"")) $tariffa_vedi = punti_in_num($tariffa_colonna_periodo[$num1][$num2],$stile_soldi);
+if ($tariffa_colonna_periodo[$num1][$num2]) $tariffa_vedi = punti_in_num($tariffa_colonna_periodo[$num1][$num2],$stile_soldi);
 else $tariffa_vedi = "";
-if (strcmp($tariffap_colonna_periodo[$num1][$num2],"")) {
-if (strcmp($tariffa_colonna_periodo[$num1][$num2],"")) $tariffa_vedi .= " + ";
+if ($tariffap_colonna_periodo[$num1][$num2]) {
+if ($tariffa_colonna_periodo[$num1][$num2]) $tariffa_vedi .= " + ";
 $tariffa_vedi .= punti_in_num($tariffap_colonna_periodo[$num1][$num2],$stile_soldi)."*$p_pers";
-} # fine if (strcmp($tariffap_colonna_periodo[$num1][$num2],""))
-} # fine else if (!strcmp($tariffa_colonna_periodo[$num1][$num2],"") and...
-echo "<td align=\"center\">$tariffa_vedi</td>";
+} # fine if ($tariffap_colonna_periodo[$num1][$num2])
+} # fine else if (!$tariffa_colonna_periodo[$num1][$num2] and...
+if ($chiusa_colonna_periodo[$num1][$num2]) $style = " style=\"background-color: #777777;\"";
+else $style = "";
+echo "<td align=\"center\"$style>$tariffa_vedi</td>";
 } # fine for $num2
 echo "</tr>";
 } # fine if ($attiva_tariffe_consentite == "n" or...
@@ -363,7 +374,7 @@ $presente = "NO";
 for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) if (${"numtariffa".$num2} == $numtariffa) $presente = "SI";
 if ($presente == "NO") {
 $tariffa = "tariffa".$numtariffa;
-$nometariffa_vedi = risul_query($rigatariffe,0,$tariffa);
+$nometariffa_vedi = $dati_tariffe[$tariffa]['nome'];
 if (!strcmp($nometariffa_vedi,"")) $nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
 else $nometariffa_vedi = mex("tariffa",$pag)."$numtariffa ($nometariffa_vedi)";
 $select_tariffe .= "<option value=\"$numtariffa\">$nometariffa_vedi</option>";
