@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -218,6 +218,13 @@ $tipo_periodi = risul_query($tipo_periodi,0,'tipo_periodi');
 $attiva_checkin = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'attiva_checkin' and idutente = '$id_utente'");
 $attiva_checkin = risul_query($attiva_checkin,0,'valpersonalizza');
 
+$colori_tab_mesi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'colori_tab_mesi' and idutente = '$id_utente'");
+$colori_tab_mesi = explode(",",risul_query($colori_tab_mesi,0,'valpersonalizza'));
+$colore_trasp = $colori_tab_mesi[0];
+$colore_giallo = $colori_tab_mesi[1];
+$colore_arancione = $colori_tab_mesi[2];
+$colore_rosso = $colori_tab_mesi[3];
+
 $mostra_giorni_tab_mesi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'mostra_giorni_tab_mesi' and idutente = '$id_utente'");
 $mostra_giorni_tab_mesi = risul_query($mostra_giorni_tab_mesi,0,'valpersonalizza');
 if ($tipo_periodi == "g") {
@@ -276,7 +283,7 @@ else $d_inizio_settimana = 0;
 } # fine function crea_data_per_linea
 
 function colore_prenotazione ($prenota,$num_pren) {
-global $tableprenota;
+global $tableprenota,$colore_trasp,$colore_giallo,$colore_arancione,$colore_rosso;
 $pagato = risul_query($prenota,$num_pren,'pagato',$tableprenota);
 $confermato = risul_query($prenota,$num_pren,'conferma',$tableprenota);
 $confermato = substr($confermato,0,1);
@@ -284,11 +291,11 @@ if (!$pagato) $pagato = 0;
 $caparra = risul_query($prenota,$num_pren,'caparra',$tableprenota);
 if (!$caparra) $caparra = 0;
 $costo_tot = risul_query($prenota,$num_pren,'tariffa_tot',$tableprenota);
-$colore = "#99ccd4"; #celeste
+$colore = $colore_trasp; #celeste
 if ($pagato < $costo_tot) {
-$colore = "#FFEE22"; #giallo
-if ($pagato < $caparra) $colore = "#FF9900"; # arancione
-if ($confermato != "S") $colore = "#CC0000"; # rosso
+$colore = $colore_giallo; #giallo
+if ($pagato < $caparra) $colore = $colore_arancione; # arancione
+if ($confermato != "S") $colore = $colore_rosso; # rosso
 } # fine if ($pagato < $costo_tot)
 return $colore;
 } # fine function colore_prenotazione
@@ -301,13 +308,13 @@ $dati_xml = "";
 if ($idg_agg and controlla_num_pos(substr($idg_agg,2)) == "SI") {
 $manda_xml = 1;
 $tabelle_lock = "";
-if ($priv_vedi_tab_mesi != "p") $altre_tab_lock = array($tableprenota,$tableperiodi,$tableclienti,$tablepersonalizza);
+if ($priv_vedi_tab_mesi != "p") $altre_tab_lock = array($tableprenota,$tableperiodi,$tableappartamenti,$tableclienti,$tableregole,$tablepersonalizza);
 else $altre_tab_lock = array($tableprenota,$tablenometariffe,$tableperiodi,$tableappartamenti,$tableclienti,$tableregole,$tablepersonalizza);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
-if ($priv_vedi_tab_mesi == "p") {
 $appartamenti = esegui_query("select * from $tableappartamenti order by idappartamenti");
 $num_appartamenti = numlin_query($appartamenti);
+if ($priv_vedi_tab_mesi == "p") {
 include("./includes/funzioni_appartamenti.php");
 if ($priv_app_gruppi != "SI") $appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartamenti,$attiva_regole1_consentite,$regole1_consentite,$priv_mod_assegnazione_app,$priv_mod_prenotazioni,$priv_ins_assegnazione_app,$priv_ins_nuove_prenota,$attiva_tariffe_consentite,$tariffe_consentite_vett,$id_utente,$tableregole,$tablenometariffe);
 else $appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartamenti,$attiva_regole1_consentite_gr,$regole1_consentite_gr,$priv_mod_assegnazione_app_gr,$priv_mod_prenotazioni_gr,$priv_ins_assegnazione_app_gr,$priv_ins_nuove_prenota_gr,$attiva_tariffe_consentite_gr,$tariffe_consentite_vett_gr,$id_utente,$tableregole,$tablenometariffe);
@@ -321,6 +328,25 @@ if (substr($idg_agg,0,1) == "d") $direz = "dx";
 else $direz = "sx";
 $idg_agg = (substr($idg_agg,1));
 if ($priv_mod_prenota_iniziate != "s" or $priv_oscura_tab_mesi == "f") $id_periodo_corrente = calcola_id_periodo_corrente($anno);
+
+if ($direz == "dx") {
+$idg_ini = $idg_agg;
+$idg_fine = $idg_agg + $loop - 1;
+} # fine if ($direz == "dx")
+else {
+$idg_ini = $idg_agg - $loop + 1;
+$idg_fine = $idg_agg;
+} # fine else if ($direz == "dx")
+unset($reg1_chiuso);
+$app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and motivazione2 = 'x' and iddatainizio <= '$idg_fine' and iddatafine >= '$idg_ini' ");
+$num_app_agenzia = numlin_query($app_agenzia);
+for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
+$ini_chiuso = risul_query($app_agenzia,$num1,'iddatainizio');
+$fine_chiuso = risul_query($app_agenzia,$num1,'iddatafine');
+$app_chiuso = risul_query($app_agenzia,$num1,'app_agenzia');
+for ($num2 = $ini_chiuso ; $num2 <= $fine_chiuso ; $num2++) $reg1_chiuso[$app_chiuso][$num2] = 1;
+} # fine for $num1
+
 for ($ncol = 1 ; $ncol <= $loop ; $ncol++) {
 
 if ($ncol > 1) {
@@ -442,6 +468,24 @@ if ($ut_ins_succ != $id_utente and ($priv_prenota_gruppi != "SI" or !$utenti_gru
 $dati_prenota .= "<app id=\"$id_appartamento\">$dati_prenota_extra</app>";
 } # fine if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO")
 } # fine for $num1
+
+for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
+$id_appartamento = risul_query($appartamenti,$num1,'idappartamenti');
+if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO") {
+if (!strstr($dati_prenota,"<app id=\"$id_appartamento\">")) {
+if ($reg1_chiuso and $reg1_chiuso[$id_appartamento][$idg_agg]) {
+$dati_prenota .= "<app id=\"$id_appartamento\">
+<ln>1</ln><idpr>-1</idpr>
+<cogn>&amp;nbsp;</cogn>
+<clr>#777777</clr>
+<apas>k</apas>
+<dain>1</dain>
+</app>";
+} # fine if ($reg1_chiuso and $reg1_chiuso[$id_appartamento][$idg_agg])
+} # fine if (!strstr($dati_prenota,"<app id=\"$id_appartamento\">"))
+} # fine if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO")
+} # fine for $num1
+
 $dati_xml .= "<col num=\"$idg_agg\">
 <dini>$d_inizio_settimana</dini>
 <dfine>$d_fine_settimana</dfine>
@@ -493,7 +537,7 @@ include_once("./includes/funzioni_clienti.php");
 $txt_cli = mostra_dati_cliente($dati_cliente,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti,"1");
 $txt_cli = str_replace("<br>"," \n",$txt_cli);
 $txt_cli = preg_replace("/<[^<]*>/","",$txt_cli);
-$dati_xml .= $txt_cli." ";
+$dati_xml .= "$id_prn - ".$txt_cli." ";
 } # fine else if (($vedi_clienti == "PROPRI" and $utente_inserimento != $id_utente) or...
 $num_persone = risul_query($dati_prn,0,'num_persone');
 include_once("./includes/funzioni_costi_agg.php");
@@ -712,6 +756,17 @@ if ($priv_app_gruppi != "SI") $appartamenti_consentiti = trova_app_consentiti($a
 else $appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartamenti,$attiva_regole1_consentite_gr,$regole1_consentite_gr,$priv_mod_assegnazione_app_gr,$priv_mod_prenotazioni_gr,$priv_ins_assegnazione_app_gr,$priv_ins_nuove_prenota_gr,$attiva_tariffe_consentite_gr,$tariffe_consentite_vett_gr,$id_utente,$tableregole,$tablenometariffe);
 } # fine if ($priv_vedi_tab_mesi == "p")
 
+# regole 1 di chiusura
+unset($reg1_chiuso);
+$app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and motivazione2 = 'x' ");
+$num_app_agenzia = numlin_query($app_agenzia);
+for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
+$ini_chiuso = risul_query($app_agenzia,$num1,'iddatainizio');
+$fine_chiuso = risul_query($app_agenzia,$num1,'iddatafine');
+$app_chiuso = risul_query($app_agenzia,$num1,'app_agenzia');
+for ($num2 = $ini_chiuso ; $num2 <= $fine_chiuso ; $num2++) $reg1_chiuso[$app_chiuso][$num2] = 1;
+} # fine for $num1
+
 # controllo se vi sono prenotazioni in appartamenti cancellati o non mostrati
 $num_appartamenti_cancellati = 0;
 $cond_app_canc = "";
@@ -721,7 +776,7 @@ $app_query = " and ($tableprenota.idappartamenti is NULL or (";
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
 $id_appartamento = risul_query($appartamenti,$num1,'idappartamenti');
 $app_query .= "$tableprenota.idappartamenti != '$id_appartamento' and ";
-if ($priv_vedi_tab_mesi == "p" and $appartamenti_consentiti[$id_appartamento] == "NO") $cond_app_perm .= " and $tableprenota.idappartamenti != '$id_appartamento'";
+if ($priv_vedi_tab_mesi == "p" and $appartamenti_consentiti[$id_appartamento] == "NO") $cond_app_perm .= " and $tableprenota.idappartamenti NOT $LIKE '$id_appartamento'";
 } # fine for $num1
 if (substr($app_query,-5) == " and ") $app_query = substr($app_query,0,-5);
 else $app_query = " and (($tableprenota.idappartamenti is NULL ";
@@ -732,8 +787,9 @@ if ($priv_prenota_gruppi == "SI") {
 reset($utenti_gruppi);
 while (list($idut_gr,$val) = each($utenti_gruppi)) if ($idut_gr != $id_utente) $query_prenota_app_canc .= " or $tableprenota.utente_inserimento = '$idut_gr'";
 } # fine if ($priv_prenota_gruppi == "SI")
-$query_prenota_app_canc .= " ) order by $tableprenota.idappartamenti,$tableprenota.iddatainizio";
+$query_prenota_app_canc .= ")";
 } # fine if ($priv_vedi_tab_mesi == "p")
+$query_prenota_app_canc .= " order by $tableprenota.idappartamenti,$tableprenota.iddatainizio";
 $prenota_app_canc = esegui_query($query_prenota_app_canc);
 $num_prenota_app_canc = numlin_query($prenota_app_canc);
 $num_app_canc = 0;
@@ -1082,7 +1138,10 @@ if ($riduci_font) echo "</small></small>";
 echo "</td><td></td></tr></table></td>";
 $num2 = $num2 + $colonne - 1;
 } # fine if ($esiste == 1)
+else {
+if ($reg1_chiuso and $reg1_chiuso[$id_appartamento][$id_settimana]) echo "<td style=\"background-color: #777777;\" colspan=\"2\">&nbsp;</td>";
 else echo "<td colspan=\"2\">&nbsp;</td>";
+} # fine else if ($esiste == 1)
 
 } # fine else if ($priv_vedi_tab_mesi == "p" and ($utente_inserimento != $id_utente or...
 } # fine for $num2
@@ -1230,13 +1289,13 @@ echo "</td></tr><tr><td style=\"height: 12px;\"></td></tr></table>";
 
 if ($show_bar != "NO") {
 echo "<table style=\"margin-left: auto; margin-right: auto;\" cellspacing=\"0\" cellpadding=\"1\"><tr>
-<td>&nbsp;</td><td style=\"background-color: #CC0000; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
+<td>&nbsp;</td><td style=\"background-color: $colore_rosso; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
 <td style=\"width: 50px;\"></td>
-<td>&nbsp;</td><td style=\"background-color: #FF9900; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
+<td>&nbsp;</td><td style=\"background-color: $colore_arancione; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
 <td style=\"width: 50px;\"></td>
-<td>&nbsp;</td><td style=\"background-color: #FFEE22; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
+<td>&nbsp;</td><td style=\"background-color: $colore_giallo; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
 <td style=\"width: 50px;\"></td>
-<td>&nbsp;</td><td style=\"background-color: #99ccd4; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
+<td>&nbsp;</td><td style=\"background-color: $colore_trasp; width: 60px; border: solid black 1px; border-radius: 10px;\">&nbsp;</td><td>&nbsp;</td>
 </tr><tr><td colspan=\"3\" align=\"center\" style=\"font-size: x-small; max-width: 180px; vertical-align: top;\">
 ".mex("Prenotazione non confermata",$pag)."</td>
 <td></td><td colspan=\"3\" align=\"center\" style=\"font-size: x-small; max-width: 180px; vertical-align: top;\">
