@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -421,7 +421,7 @@ if ($id_settimana >= $ini_prenota_succ) {
 $esiste = 1;
 $prenota_corr = $prenota_succ;
 $prenota_succ++;
-if ($num_prenotazione_presente > $prenota_succ) $ini_prenota_succ = risul_query($prenotazione_presente,$prenota_succ,iddatainizio);
+if ($num_prenotazione_presente > $prenota_succ) $ini_prenota_succ = risul_query($prenotazione_presente,$prenota_succ,'iddatainizio');
 else {
 $ini_prenota_succ = (risul_query($prenotazione_presente,$prenota_corr,'iddatafine') + 1);
 if (($id_data_inizio_tab + $num_colonne + 1) > $ini_prenota_succ) $ini_prenota_succ = $id_data_inizio_tab + $num_colonne + 1;
@@ -464,7 +464,7 @@ $fatto = "SI";
 $colonne = $id_fine - $id_inizio + 1;
 $prenota_corr = $prenota_succ;
 $prenota_succ++;
-if ($num_prenotazione_presente > $prenota_succ) $ini_prenota_succ = risul_query($prenotazione_presente,$prenota_succ,iddatainizio);
+if ($num_prenotazione_presente > $prenota_succ) $ini_prenota_succ = risul_query($prenotazione_presente,$prenota_succ,'iddatainizio');
 else {
 $ini_prenota_succ = (risul_query($prenotazione_presente,$prenota_corr,'iddatafine') + 1);
 if (($id_data_inizio_tab + $num_colonne + 1) > $ini_prenota_succ) $ini_prenota_succ = $id_data_inizio_tab + $num_colonne + 1;
@@ -567,6 +567,7 @@ $lung_non_ridotta = (3+$aggiunta_tronca)*$colonne - $lung_freccia;
 if ($lung_cognome > $lung_non_ridotta) $riduci_font = "SI";
 $lung_non_tronca = (3+$aggiunta_tronca)*$colonne;
 if ($lung_freccia == 3) $lung_non_tronca = $lung_non_tronca - 1;
+if ($lung_non_tronca < 1) $lung_non_tronca = 1;
 if ($lung_cognome > ($lung_non_tronca+1) and $cognome != "&nbsp;") {
 $link_modifica_inizio = str_replace("<a href","<a title=\"".htmlspecialchars($cognome)."\" href",$link_modifica_inizio);
 $cognome = tronca_testo($cognome,0,$lung_non_tronca).".";
