@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -49,6 +49,7 @@ $tableparentele = $PHPR_TAB_PRE."parentele";
 $tableanni = $PHPR_TAB_PRE."anni";
 $tableutenti = $PHPR_TAB_PRE."utenti";
 $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
+$tablerelclienti = $PHPR_TAB_PRE."relclienti";
 
 
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
@@ -331,6 +332,13 @@ if ($mostra_contratto == "SI") {
 
 
 define(C_ID_UTENTE,$id_utente);
+$campi_pers_cliente = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'campi_pers_cliente' and idutente = '$id_utente' ");
+if (numlin_query($campi_pers_cliente)) {
+$campi_pers_cliente = explode(">",risul_query($campi_pers_cliente,0,'valpersonalizza'));
+$num_campi_pers_cliente = count($campi_pers_cliente);
+} # fine if (numlin_query($campi_pers_cliente))
+else $num_campi_pers_cliente = 0;
+$campo_personalizzato_ = "campo_personalizzato_";
 include("./includes/variabili_contratto.php");
 
 if (!$num_ripeti or controlla_num_pos($num_ripeti) == "NO") $num_ripeti = 1;
@@ -346,7 +354,7 @@ if ($lista_prenota) {
 $lista_clienti = "";
 if ($priv_vedi_tab_prenotazioni != "n" or ($priv_vedi_tab_mesi != "n" and $priv_mod_prenotazioni != "n")) {
 $tabelle_lock = "";
-$altre_tab_lock = array($tableanni,$tableprenota,$tablecostiprenota,$tableperiodi,$tableclienti,$tablesoldi,$tableutenti);
+$altre_tab_lock = array($tableanni,$tableprenota,$tablecostiprenota,$tableperiodi,$tableclienti,$tablerelclienti,$tablesoldi,$tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 include("./includes/funzioni_costi_agg.php");
 $lista_prenota = explode(",",$lista_prenota);
@@ -368,7 +376,7 @@ ${"utente_inserimento_prenotazione_".$num1} = $utente_inserimento;
 ${"data_inserimento_prenotazione_".$num1} = substr(risul_query($dati_prenota,0,'datainserimento'),0,16);
 if ($vedi_clienti != "NO") {
 $id_clienti = risul_query($dati_prenota,0,'idclienti');
-$dati_cliente = esegui_query("select * from $tableclienti where idclienti = $id_clienti ");
+$dati_cliente = esegui_query("select * from $tableclienti where idclienti = '$id_clienti' ");
 if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI") {
 $mostra_cliente = "SI";
 $utente_inserimento = risul_query($dati_cliente,0,'utente_inserimento');
@@ -377,39 +385,45 @@ if ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_inserimento]) $mostra_
 } # fine if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI")
 if (($vedi_clienti != "PROPRI" and $vedi_clienti != "GRUPPI") or $mostra_cliente != "NO") {
 ${"cognome_".$num1} = risul_query($dati_cliente,0,'cognome');
-${"nome_".$num1} = risul_query($dati_cliente,0,'nome');
-${"soprannome_".$num1} = risul_query($dati_cliente,0,'soprannome');
-${"titolo_".$num1} = risul_query($dati_cliente,0,'titolo');
-${"sesso_".$num1} = risul_query($dati_cliente,0,'sesso');
-${"data_nascita_".$num1} = risul_query($dati_cliente,0,'datanascita');
-${"citta_nascita_".$num1} = risul_query($dati_cliente,0,'cittanascita');
-${"regione_nascita_".$num1} = risul_query($dati_cliente,0,'regionenascita');
-${"nazione_nascita_".$num1} = risul_query($dati_cliente,0,'nazionenascita');
-${"cittadinanza_".$num1} = risul_query($dati_cliente,0,'nazionalita');
-${"codice_lingua_".$num1} = risul_query($dati_cliente,0,'lingua');
-${"nazione_".$num1} = risul_query($dati_cliente,0,'nazione');
-${"regione_".$num1} = risul_query($dati_cliente,0,'regione');
-${"citta_".$num1} = risul_query($dati_cliente,0,'citta');
+# I controlli di non vuoto servono a risparmiare memoria, creando solo le variabili necessarie
+if (strcmp(risul_query($dati_cliente,0,'nome'),"")) ${"nome_".$num1} = risul_query($dati_cliente,0,'nome');
+if (strcmp(risul_query($dati_cliente,0,'soprannome'),"")) ${"soprannome_".$num1} = risul_query($dati_cliente,0,'soprannome');
+if (strcmp(risul_query($dati_cliente,0,'titolo'),"")) ${"titolo_".$num1} = risul_query($dati_cliente,0,'titolo');
+if (strcmp(risul_query($dati_cliente,0,'sesso'),"")) ${"sesso_".$num1} = risul_query($dati_cliente,0,'sesso');
+if (strcmp(risul_query($dati_cliente,0,'datanascita'),"")) ${"data_nascita_".$num1} = risul_query($dati_cliente,0,'datanascita');
+if (strcmp(risul_query($dati_cliente,0,'cittanascita'),"")) ${"citta_nascita_".$num1} = risul_query($dati_cliente,0,'cittanascita');
+if (strcmp(risul_query($dati_cliente,0,'regionenascita'),"")) ${"regione_nascita_".$num1} = risul_query($dati_cliente,0,'regionenascita');
+if (strcmp(risul_query($dati_cliente,0,'nazionenascita'),"")) ${"nazione_nascita_".$num1} = risul_query($dati_cliente,0,'nazionenascita');
+if (strcmp(risul_query($dati_cliente,0,'nazionalita'),"")) ${"cittadinanza_".$num1} = risul_query($dati_cliente,0,'nazionalita');
+if (strcmp(risul_query($dati_cliente,0,'lingua'),"")) ${"codice_lingua_".$num1} = risul_query($dati_cliente,0,'lingua');
+if (strcmp(risul_query($dati_cliente,0,'nazione'),"")) ${"nazione_".$num1} = risul_query($dati_cliente,0,'nazione');
+if (strcmp(risul_query($dati_cliente,0,'regione'),"")) ${"regione_".$num1} = risul_query($dati_cliente,0,'regione');
+if (strcmp(risul_query($dati_cliente,0,'citta'),"")) ${"citta_".$num1} = risul_query($dati_cliente,0,'citta');
 if ($priv_vedi_indirizzo == "s") {
-${"via_".$num1} = risul_query($dati_cliente,0,'via');
-${"numcivico_".$num1} = risul_query($dati_cliente,0,'numcivico');
-${"cap_".$num1} = risul_query($dati_cliente,0,'cap');
+if (strcmp(risul_query($dati_cliente,0,'via'),"")) ${"via_".$num1} = risul_query($dati_cliente,0,'via');
+if (strcmp(risul_query($dati_cliente,0,'numcivico'),"")) ${"numcivico_".$num1} = risul_query($dati_cliente,0,'numcivico');
+if (strcmp(risul_query($dati_cliente,0,'cap'),"")) ${"cap_".$num1} = risul_query($dati_cliente,0,'cap');
 } # fine if ($priv_vedi_indirizzo == "s")
-${"documento_".$num1} = risul_query($dati_cliente,0,'documento');
-${"tipo_documento_".$num1} = risul_query($dati_cliente,0,'tipodoc');
-${"citta_documento_".$num1} = risul_query($dati_cliente,0,'cittadoc');
-${"regione_documento_".$num1} = risul_query($dati_cliente,0,'regionedoc');
-${"nazione_documento_".$num1} = risul_query($dati_cliente,0,'nazionedoc');
-${"scadenza_documento_".$num1} = risul_query($dati_cliente,0,'scadenzadoc');
+if (strcmp(risul_query($dati_cliente,0,'documento'),"")) ${"documento_".$num1} = risul_query($dati_cliente,0,'documento');
+if (strcmp(risul_query($dati_cliente,0,'tipodoc'),"")) ${"tipo_documento_".$num1} = risul_query($dati_cliente,0,'tipodoc');
+if (strcmp(risul_query($dati_cliente,0,'cittadoc'),"")) ${"citta_documento_".$num1} = risul_query($dati_cliente,0,'cittadoc');
+if (strcmp(risul_query($dati_cliente,0,'regionedoc'),"")) ${"regione_documento_".$num1} = risul_query($dati_cliente,0,'regionedoc');
+if (strcmp(risul_query($dati_cliente,0,'nazionedoc'),"")) ${"nazione_documento_".$num1} = risul_query($dati_cliente,0,'nazionedoc');
+if (strcmp(risul_query($dati_cliente,0,'scadenzadoc'),"")) ${"scadenza_documento_".$num1} = risul_query($dati_cliente,0,'scadenzadoc');
 if ($priv_vedi_telefoni == "s") {
-${"telefono_".$num1} = risul_query($dati_cliente,0,'telefono');
-${"telefono2_".$num1} = risul_query($dati_cliente,0,'telefono2');
-${"telefono3_".$num1} = risul_query($dati_cliente,0,'telefono3');
-${"fax_".$num1} = risul_query($dati_cliente,0,'fax');
-${"email_".$num1} = risul_query($dati_cliente,0,'email');
+if (strcmp(risul_query($dati_cliente,0,'telefono'),"")) ${"telefono_".$num1} = risul_query($dati_cliente,0,'telefono');
+if (strcmp(risul_query($dati_cliente,0,'telefono2'),"")) ${"telefono2_".$num1} = risul_query($dati_cliente,0,'telefono2');
+if (strcmp(risul_query($dati_cliente,0,'telefono3'),"")) ${"telefono3_".$num1} = risul_query($dati_cliente,0,'telefono3');
+if (strcmp(risul_query($dati_cliente,0,'fax'),"")) ${"fax_".$num1} = risul_query($dati_cliente,0,'fax');
+if (strcmp(risul_query($dati_cliente,0,'email'),"")) ${"email_".$num1} = risul_query($dati_cliente,0,'email');
 } # fine if ($priv_vedi_telefoni == "s")
-${"codice_fiscale_".$num1} = risul_query($dati_cliente,0,'cod_fiscale');
-${"partita_iva_".$num1} = risul_query($dati_cliente,0,'partita_iva');
+if (strcmp(risul_query($dati_cliente,0,'cod_fiscale'),"")) ${"codice_fiscale_".$num1} = risul_query($dati_cliente,0,'cod_fiscale');
+if (strcmp(risul_query($dati_cliente,0,'partita_iva'),"")) ${"partita_iva_".$num1} = risul_query($dati_cliente,0,'partita_iva');
+$dati_relcliente = esegui_query("select * from $tablerelclienti where idclienti = '$id_clienti' and tipo = 'campo_pers' ");
+$num_dati_relcliente = numlin_query($dati_relcliente);
+for ($num2 = 0 ; $num2 < $num_dati_relcliente ; $num2++) {
+${"campo_personalizzato_".risul_query($dati_relcliente,$num2,'testo1')."_".$num1} = risul_query($dati_relcliente,$num2,'testo3');
+} # fine for $num2
 } # fine if (($vedi_clienti != "PROPRI" and...
 } # fine if ($vedi_clienti != "NO")
 ${"numero_prenotazione_".$num1} = $id_prenota;
@@ -431,19 +445,19 @@ ${"nome_tariffa_".$num1} = $tariffa[0];
 $costo_tariffa = (double) $tariffa[1];
 ${"costo_tariffa_".$num1} = $costo_tariffa;
 $sconto = (double) risul_query($dati_prenota,0,'sconto');
-${"sconto_".$num1} = $sconto;
-${"percentuale_tasse_tariffa_".$num1} = risul_query($dati_prenota,0,'tasseperc');
-${"commento_".$num1} = risul_query($dati_prenota,0,'commento');
+if (strcmp($sconto,"")) ${"sconto_".$num1} = $sconto;
+if (strcmp(risul_query($dati_prenota,0,'tasseperc'),"")) ${"percentuale_tasse_tariffa_".$num1} = risul_query($dati_prenota,0,'tasseperc');
+if (strcmp(risul_query($dati_prenota,0,'commento'),"")) ${"commento_".$num1} = risul_query($dati_prenota,0,'commento');
 if (strstr(${"commento_".$num1},">")) {
 ${"commento_".$num1} = explode(">",${"commento_".$num1});
 ${"commento_".$num1} = ${"commento_".$num1}[0];
 } # fine if (strstr(${"commento_".$num1},">"))
-${"origine_prenotazione_".$num1} = risul_query($dati_prenota,0,'origine');
+if (strcmp(risul_query($dati_prenota,0,'origine'),"")) ${"origine_prenotazione_".$num1} = risul_query($dati_prenota,0,'origine');
 $caparra = risul_query($dati_prenota,0,'caparra');
-${"caparra_".$num1} = $caparra;
-${"commissioni_".$num1} = risul_query($dati_prenota,0,'commissioni');
+if (strcmp($caparra,"")) ${"caparra_".$num1} = $caparra;
+if (strcmp(risul_query($dati_prenota,0,'commissioni'),"")) ${"commissioni_".$num1} = risul_query($dati_prenota,0,'commissioni');
 $numpersone = risul_query($dati_prenota,0,'num_persone');
-${"num_persone_".$num1} = $numpersone;
+if (strcmp($numpersone,"")) ${"num_persone_".$num1} = $numpersone;
 ${"unita_occupata_".$num1} = risul_query($dati_prenota,0,'idappartamenti');
 ${"unita_assegnabili_".$num1} = risul_query($dati_prenota,0,'app_assegnabili');
 ${"pagato_".$num1} = risul_query($dati_prenota,0,'pagato');
@@ -458,7 +472,7 @@ $costo_agg_parziale = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$id_
 $costo_agg_tot = (double) $costo_agg_tot + $costo_agg_parziale;
 ${"nome_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['nome'];
 ${"val_costo_agg".$numca."_".$num1} = $costo_agg_parziale;
-${"percentuale_tasse_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['tasseperc'];
+if (strcmp($dati_cap[$numca]['tasseperc'],"")) ${"percentuale_tasse_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['tasseperc'];
 ${"moltiplica_max_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['moltiplica_costo'];
 ${"data_inserimento_costo_agg".$numca."_".$num1} = substr($dati_cap[$numca]['datainserimento'],0,10);
 ${"utente_inserimento_costo_agg".$numca."_".$num1} = $dati_cap[$numca]['utente_inserimento'];
@@ -487,7 +501,7 @@ $num_pagamenti2 = numlin_query($pagamenti);
 for ($num3 = 0 ; $num3 < $num_pagamenti2 ; $num3++) {
 ${"data_paga".$num_pagamenti."_".$num1} = substr(risul_query($pagamenti,$num3,'data_inserimento'),0,10);
 ${"utente_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num3,'utente_inserimento');
-${"metodo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num3,'metodo_pagamento');
+if (strcmp(risul_query($pagamenti,$num3,'metodo_pagamento'),"")) ${"metodo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num3,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num3,'saldo_prenota');
 $num_pagamenti++;
 } # fine for $num3
@@ -499,7 +513,7 @@ $num_pagamenti2 = numlin_query($pagamenti);
 for ($num2 = 0 ; $num2 < $num_pagamenti2 ; $num2++) {
 ${"data_paga".$num_pagamenti."_".$num1} = substr(risul_query($pagamenti,$num2,'data_inserimento'),0,10);
 ${"utente_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num2,'utente_inserimento');
-${"metodo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num2,'metodo_pagamento');
+if (strcmp(risul_query($pagamenti,$num2,'metodo_pagamento'),"")) ${"metodo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num2,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num1} = risul_query($pagamenti,$num2,'saldo_prenota');
 $num_pagamenti++;
 } # fine for $num2
@@ -528,35 +542,45 @@ if ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_inserimento]) $mostra_
 } # fine if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI")
 if (($vedi_clienti != "PROPRI" and $vedi_clienti != "GRUPPI") or $mostra_cliente != "NO") {
 ${"cognome_".$num1} = risul_query($dati_cliente,0,'cognome');
-${"nome_".$num1} = risul_query($dati_cliente,0,'nome');
-${"soprannome_".$num1} = risul_query($dati_cliente,0,'soprannome');
-${"titolo_".$num1} = risul_query($dati_cliente,0,'titolo');
-${"sesso_".$num1} = risul_query($dati_cliente,0,'sesso');
-${"data_nascita_".$num1} = risul_query($dati_cliente,0,'datanascita');
-${"citta_nascita_".$num1} = risul_query($dati_cliente,0,'cittanascita');
-${"regione_nascita_".$num1} = risul_query($dati_cliente,0,'regionenascita');
-${"nazione_nascita_".$num1} = risul_query($dati_cliente,0,'nazionenascita');
-${"cittadinanza_".$num1} = risul_query($dati_cliente,0,'nazionalita');
-${"codice_lingua_".$num1} = risul_query($dati_cliente,0,'lingua');
-${"nazione_".$num1} = risul_query($dati_cliente,0,'nazione');
-${"regione_".$num1} = risul_query($dati_cliente,0,'regione');
-${"citta_".$num1} = risul_query($dati_cliente,0,'citta');
-${"via_".$num1} = risul_query($dati_cliente,0,'via');
-${"numcivico_".$num1} = risul_query($dati_cliente,0,'numcivico');
-${"cap_".$num1} = risul_query($dati_cliente,0,'cap');
-${"documento_".$num1} = risul_query($dati_cliente,0,'documento');
-${"tipo_documento_".$num1} = risul_query($dati_cliente,0,'tipodoc');
-${"citta_documento_".$num1} = risul_query($dati_cliente,0,'cittadoc');
-${"regione_documento_".$num1} = risul_query($dati_cliente,0,'regionedoc');
-${"nazione_documento_".$num1} = risul_query($dati_cliente,0,'nazionedoc');
-${"scadenza_documento_".$num1} = risul_query($dati_cliente,0,'scadenzadoc');
-${"telefono_".$num1} = risul_query($dati_cliente,0,'telefono');
-${"telefono2_".$num1} = risul_query($dati_cliente,0,'telefono2');
-${"telefono3_".$num1} = risul_query($dati_cliente,0,'telefono3');
-${"fax_".$num1} = risul_query($dati_cliente,0,'fax');
-${"email_".$num1} = risul_query($dati_cliente,0,'email');
-${"codice_fiscale_".$num1} = risul_query($dati_cliente,0,'cod_fiscale');
-${"partita_iva_".$num1} = risul_query($dati_cliente,0,'partita_iva');
+# I controlli di non vuoto servono a risparmiare memoria, creando solo le variabili necessarie
+if (strcmp(risul_query($dati_cliente,0,'nome'),"")) ${"nome_".$num1} = risul_query($dati_cliente,0,'nome');
+if (strcmp(risul_query($dati_cliente,0,'soprannome'),"")) ${"soprannome_".$num1} = risul_query($dati_cliente,0,'soprannome');
+if (strcmp(risul_query($dati_cliente,0,'titolo'),"")) ${"titolo_".$num1} = risul_query($dati_cliente,0,'titolo');
+if (strcmp(risul_query($dati_cliente,0,'sesso'),"")) ${"sesso_".$num1} = risul_query($dati_cliente,0,'sesso');
+if (strcmp(risul_query($dati_cliente,0,'datanascita'),"")) ${"data_nascita_".$num1} = risul_query($dati_cliente,0,'datanascita');
+if (strcmp(risul_query($dati_cliente,0,'cittanascita'),"")) ${"citta_nascita_".$num1} = risul_query($dati_cliente,0,'cittanascita');
+if (strcmp(risul_query($dati_cliente,0,'regionenascita'),"")) ${"regione_nascita_".$num1} = risul_query($dati_cliente,0,'regionenascita');
+if (strcmp(risul_query($dati_cliente,0,'nazionenascita'),"")) ${"nazione_nascita_".$num1} = risul_query($dati_cliente,0,'nazionenascita');
+if (strcmp(risul_query($dati_cliente,0,'nazionalita'),"")) ${"cittadinanza_".$num1} = risul_query($dati_cliente,0,'nazionalita');
+if (strcmp(risul_query($dati_cliente,0,'lingua'),"")) ${"codice_lingua_".$num1} = risul_query($dati_cliente,0,'lingua');
+if (strcmp(risul_query($dati_cliente,0,'nazione'),"")) ${"nazione_".$num1} = risul_query($dati_cliente,0,'nazione');
+if (strcmp(risul_query($dati_cliente,0,'regione'),"")) ${"regione_".$num1} = risul_query($dati_cliente,0,'regione');
+if (strcmp(risul_query($dati_cliente,0,'citta'),"")) ${"citta_".$num1} = risul_query($dati_cliente,0,'citta');
+if ($priv_vedi_indirizzo == "s") {
+if (strcmp(risul_query($dati_cliente,0,'via'),"")) ${"via_".$num1} = risul_query($dati_cliente,0,'via');
+if (strcmp(risul_query($dati_cliente,0,'numcivico'),"")) ${"numcivico_".$num1} = risul_query($dati_cliente,0,'numcivico');
+if (strcmp(risul_query($dati_cliente,0,'cap'),"")) ${"cap_".$num1} = risul_query($dati_cliente,0,'cap');
+} # fine if ($priv_vedi_indirizzo == "s")
+if (strcmp(risul_query($dati_cliente,0,'documento'),"")) ${"documento_".$num1} = risul_query($dati_cliente,0,'documento');
+if (strcmp(risul_query($dati_cliente,0,'tipodoc'),"")) ${"tipo_documento_".$num1} = risul_query($dati_cliente,0,'tipodoc');
+if (strcmp(risul_query($dati_cliente,0,'cittadoc'),"")) ${"citta_documento_".$num1} = risul_query($dati_cliente,0,'cittadoc');
+if (strcmp(risul_query($dati_cliente,0,'regionedoc'),"")) ${"regione_documento_".$num1} = risul_query($dati_cliente,0,'regionedoc');
+if (strcmp(risul_query($dati_cliente,0,'nazionedoc'),"")) ${"nazione_documento_".$num1} = risul_query($dati_cliente,0,'nazionedoc');
+if (strcmp(risul_query($dati_cliente,0,'scadenzadoc'),"")) ${"scadenza_documento_".$num1} = risul_query($dati_cliente,0,'scadenzadoc');
+if ($priv_vedi_telefoni == "s") {
+if (strcmp(risul_query($dati_cliente,0,'telefono'),"")) ${"telefono_".$num1} = risul_query($dati_cliente,0,'telefono');
+if (strcmp(risul_query($dati_cliente,0,'telefono2'),"")) ${"telefono2_".$num1} = risul_query($dati_cliente,0,'telefono2');
+if (strcmp(risul_query($dati_cliente,0,'telefono3'),"")) ${"telefono3_".$num1} = risul_query($dati_cliente,0,'telefono3');
+if (strcmp(risul_query($dati_cliente,0,'fax'),"")) ${"fax_".$num1} = risul_query($dati_cliente,0,'fax');
+if (strcmp(risul_query($dati_cliente,0,'email'),"")) ${"email_".$num1} = risul_query($dati_cliente,0,'email');
+} # fine if ($priv_vedi_telefoni == "s")
+if (strcmp(risul_query($dati_cliente,0,'cod_fiscale'),"")) ${"codice_fiscale_".$num1} = risul_query($dati_cliente,0,'cod_fiscale');
+if (strcmp(risul_query($dati_cliente,0,'partita_iva'),"")) ${"partita_iva_".$num1} = risul_query($dati_cliente,0,'partita_iva');
+$dati_relcliente = esegui_query("select * from $tablerelclienti where idclienti = '$id_clienti' and tipo = 'campo_pers' ");
+$num_dati_relcliente = numlin_query($dati_relcliente);
+for ($num2 = 0 ; $num2 < $num_dati_relcliente ; $num2++) {
+${"campo_personalizzato_".risul_query($dati_relcliente,$num2,'testo1')."_".$num1} = risul_query($dati_relcliente,$num2,'testo3');
+} # fine for $num2
 } # fine if (($vedi_clienti != "PROPRI" and...
 } # fine for $num1
 } # fine if ($vedi_clienti != "NO")
